@@ -56,17 +56,17 @@
  ** Description: generates naive cgi search form for search of sisu database (pgsql sqlite)
 
 =end
-module  SiSU_CGI_sqlite                                                            #% database building documents
+module  SiSU_CGI_SQLite                                                            #% database building documents
   require_relative 'sysenv'                             # sysenv.rb
   require_relative 'cgi_sql_common'                     # cgi_sql_common.rb
-    include SiSU_CGI_sql
-  class SiSU_search_sqlite < SiSU_CGI_common
+    include SiSU_CGI_SQL
+  class SearchSQLite < CGI_Common
     def initialize(opt,webserv)
       @opt,@webserv=opt,webserv
-      @env=SiSU_Env::Info_env.new('',opt)
+      @env=SiSU_Env::InfoEnv.new('',opt)
       @image_src="#{@env.url.webserv_cgi}/_sisu/image_sys"
-      @common=SiSU_CGI_sql::SiSU_CGI_common.new(@webserv,@opt,@image_src,@env)
-      @cgi_file_name="#{Db[:name_prefix_db]}by_#{opt.dir_structure_by}_sqlite.cgi"
+      @common=SiSU_CGI_SQL::CGI_Common.new(@webserv,@opt,@image_src,@env)
+      @cgi_file_name="#{Db[:name_prefix_db]}by_#{opt.dir_structure_by.to_s}_sqlite.cgi"
     end
     def sqlite
       serve=[]
@@ -78,7 +78,7 @@ module  SiSU_CGI_sqlite
           end
         end
       end
-      serve.sort!
+      serve=serve.sort
       f1,f2,f3='','',''
       serve.each do |x|
         f1 << %{              <option value="#{Db[:name_prefix]}#{x}">#{x}</option>\n}
@@ -137,7 +137,7 @@ module  SiSU_CGI_sqlite
     end
     def search_statement
       <<-'WOK_SQL'
-      class Dbi_search_string
+      class DBI_SearchString
         def initialize(l,t,q,cse=false)
           @l,@t,@q=l,t,q
         end
@@ -148,8 +148,8 @@ module  SiSU_CGI_sqlite
             elsif @q =~/\S+/;  unescaped_search=CGI.unescape(@q)
             end
             search_construct=[]
-            unescaped_search.gsub!(/\s*(AND|OR)\s*/,"%' \) \\1 #{@l} LIKE \( '%")
-            unescaped_search.gsub!(/(.+)/,"#{@l} LIKE \( '%\\1%' \)")
+            unescaped_search=unescaped_search.gsub(/\s*(AND|OR)\s*/,"%' \) \\1 #{@l} LIKE \( '%").
+              gsub(/(.+)/,"#{@l} LIKE \( '%\\1%' \)")
             search_construct << unescaped_search
             search_construct=search_construct.join(' ')
             search[:search]                    << search_construct
@@ -165,11 +165,11 @@ module  SiSU_CGI_sqlite
       <<-'WOK_SQL'
           @search_text,@search_endnotes='',''
           search[:text].flatten.each {|x| @search_text << "#{x} AND " }
-          @search_text=@search_text.gsub!(/AND\s+$/m,'')
-          @search_text.gsub!(/(doc_objects\.clean\s+LIKE\s+\(\s*'%[^']+%'\s*\)\s+(?:(?:AND|OR)\s+doc_objects\.clean\s+LIKE\s+\(\s*'%[^']+%'\s*\))+)/,'(\1)')
+          @search_text=@search_text.gsub(/AND\s+$/m,'').
+            gsub(/(doc_objects\.clean\s+LIKE\s+\(\s*'%[^']+%'\s*\)\s+(?:(?:AND|OR)\s+doc_objects\.clean\s+LIKE\s+\(\s*'%[^']+%'\s*\))+)/,'(\1)')
           search[:endnotes].flatten.each {|x| @search_endnotes << "#{x} AND " }
-          @search_endnotes=@search_endnotes.gsub!(/AND\s+$/m,'')
-          @search_endnotes.gsub!(/(endnotes\.clean\s+LIKE\s+\(\s*'%[^']+%'\s*\)\s+(?:(?:AND|OR)\s+endnotes\.clean\s+LIKE\s+\(\s*'%[^']+%'\s*\))+)/,'(\1)')
+          @search_endnotes=@search_endnotes.gsub(/AND\s+$/m,'').
+            gsub(/(endnotes\.clean\s+LIKE\s+\(\s*'%[^']+%'\s*\)\s+(?:(?:AND|OR)\s+endnotes\.clean\s+LIKE\s+\(\s*'%[^']+%'\s*\))+)/,'(\1)')
         end
       WOK_SQL
     end
