@@ -61,7 +61,7 @@ module SiSU_Initialize
     include SiSU_Env
     include SiSU_Screen
   require_relative 'relaxng'                            # relaxng.rb
-    include SiSU_relaxng
+    include SiSU_Relaxng
   require_relative 'css'                                # css.rb
     include SiSU_Style
   class Source
@@ -69,19 +69,19 @@ module SiSU_Initialize
       @opt=opt
     end
     def read
-      SiSU_Config.new(@opt).make_homepage
-      SiSU_Config.new(@opt).css
-      SiSU_Config.new(@opt).dtd
-      SiSU_Config.new(@opt).cp_local_images
-      SiSU_Config.new(@opt).cp_external_images
-      SiSU_Config.new(@opt).cp_webserver_images #if @opt.mod.inspect =~/--init(?:ialize)?=site/
+      ConfigSite.new(@opt).make_homepage
+      ConfigSite.new(@opt).css
+      ConfigSite.new(@opt).dtd
+      ConfigSite.new(@opt).cp_local_images
+      ConfigSite.new(@opt).cp_external_images
+      ConfigSite.new(@opt).cp_webserver_images #if @opt.mod.inspect =~/--init(?:ialize)?=site/
     end
   end
-  class SiSU_Config #config files such as css are not updated if they already exist unless forced using the --init=site modifier
+  class ConfigSite #config files such as css are not updated if they already exist unless forced using the --init=site modifier
     require_relative 'sysenv'                           # sysenv.rb
     def initialize(opt)
       @opt=opt
-      @env=SiSU_Env::Info_env.new(@opt.fns)
+      @env=SiSU_Env::InfoEnv.new(@opt.fns)
       @suffix,@path={},{}
       @suffix[:rnc]='rnc'
       @suffix[:rng]='rng'
@@ -94,30 +94,30 @@ module SiSU_Initialize
     end
     def make_homepage
       SiSU_Screen::Ansi.new(@opt.cmd,'invert','Make homepage','').colorize unless @opt.cmd =~/q/
-      SiSU_Env::Create_site.new(@opt.cmd).homepage
+      SiSU_Env::CreateSite.new(@opt.cmd).homepage
     end
     def cp_local_images
       SiSU_Screen::Ansi.new(@opt.cmd,'invert','Copy images','').colorize unless @opt.cmd =~/q/
-      SiSU_Env::Create_site.new(@opt.cmd).cp_local_images
-      SiSU_Env::Create_site.new(@opt.cmd).cp_webserver_images_local #this should not have been necessary
-      SiSU_Env::Create_site.new(@opt.cmd).cp_base_images #base images (nav etc.) used by all html
+      SiSU_Env::CreateSite.new(@opt.cmd).cp_local_images
+      SiSU_Env::CreateSite.new(@opt.cmd).cp_webserver_images_local #this should not have been necessary
+      SiSU_Env::CreateSite.new(@opt.cmd).cp_base_images #base images (nav etc.) used by all html
     end
     def cp_external_images
       SiSU_Screen::Ansi.new(@opt.cmd,'invert','Copy external images','').colorize if @opt.cmd =~/V/
-      SiSU_Env::Create_site.new(@opt.cmd).cp_external_images
+      SiSU_Env::CreateSite.new(@opt.cmd).cp_external_images
     end
     def cp_webserver_images
       SiSU_Screen::Ansi.new(@opt.cmd,'invert','Copy webserver/output file images','').colorize unless @opt.cmd =~/q/
-      SiSU_Env::Create_site.new(@opt.cmd).cp_webserver_images
-      SiSU_Env::Create_system_link.new.images
+      SiSU_Env::CreateSite.new(@opt.cmd).cp_webserver_images
+      SiSU_Env::CreateSystemLink.new.images
     end
     def css
       SiSU_Screen::Ansi.new(@opt.cmd,'invert','Configuring CSSs','').colorize unless @opt.cmd =~/q/
-      SiSU_Env::Create_site.new(@opt.cmd).cp_css
+      SiSU_Env::CreateSite.new(@opt.cmd).cp_css
     end
     def dtd
       SiSU_Screen::Ansi.new(@opt.cmd,'invert','Configuring DTDs','').colorize unless @opt.cmd =~/q/
-      @rxng=SiSU_relaxng::RelaxNG.new
+      @rxng=SiSU_Relaxng::RelaxNG.new
       @path.each { |d| FileUtils::mkdir_p(d[1]) unless FileTest.directory?(d[1]) }
       #ugly code, sort later
       if @rxng.methods.join =~/[^_]dtd_sax\b/
@@ -167,10 +167,10 @@ module SiSU_Initialize
       rnc << @rxng.rnc_model_output_sax
       rnc.close
       #xsd
-      schema=SiSU_Env::System_call.new(rnc_src,xsd_file)
+      schema=SiSU_Env::SystemCall.new(rnc_src,xsd_file)
       schema.relaxng(@opt.cmd)
       #rng
-      schema=SiSU_Env::System_call.new(rnc_src,rng_file)
+      schema=SiSU_Env::SystemCall.new(rnc_src,rng_file)
       schema.relaxng(@opt.cmd)
       #rnc
       FileUtils::cp(rnc_src,rnc_file)
@@ -186,10 +186,10 @@ module SiSU_Initialize
       rnc << @rxng.rnc_model_output_dom
       rnc.close
       #xsd
-      schema=SiSU_Env::System_call.new(rnc_src,xsd_file)
+      schema=SiSU_Env::SystemCall.new(rnc_src,xsd_file)
       schema.relaxng(@opt.cmd)
       #rng
-      schema=SiSU_Env::System_call.new(rnc_src,rng_file)
+      schema=SiSU_Env::SystemCall.new(rnc_src,rng_file)
       schema.relaxng(@opt.cmd)
       #rnc
       FileUtils::cp(rnc_src,rnc_file)
@@ -205,10 +205,10 @@ module SiSU_Initialize
       rnc << @rxng.rnc_model_output_xhtml
       rnc.close
       #xsd
-      schema=SiSU_Env::System_call.new(rnc_src,xsd_file)
+      schema=SiSU_Env::SystemCall.new(rnc_src,xsd_file)
       schema.relaxng(@opt.cmd)
       #rng
-      schema=SiSU_Env::System_call.new(rnc_src,rng_file)
+      schema=SiSU_Env::SystemCall.new(rnc_src,rng_file)
       schema.relaxng(@opt.cmd)
       #rnc
       FileUtils::cp(rnc_src,rnc_file)
@@ -220,7 +220,7 @@ module SiSU_Initialize
       rnc=File.new(rnc_file,'w')
       rnc << @rxng.rnc_model_output_sax
       rnc.close
-      schema=SiSU_Env::System_call.new(rnc_file,dtd_file)
+      schema=SiSU_Env::SystemCall.new(rnc_file,dtd_file)
       schema.relaxng(@opt.cmd)
     end
     def trang_rnc_model_input_dom
@@ -229,7 +229,7 @@ module SiSU_Initialize
       rnc=File.new(rnc_file,'w')
       rnc << @rxng.rnc_model_output_dom
       rnc.close
-      schema=SiSU_Env::System_call.new(rnc_file,dtd_file)
+      schema=SiSU_Env::SystemCall.new(rnc_file,dtd_file)
       schema.relaxng(@opt.cmd)
     end
     def trang_rnc_model_input_node
@@ -239,7 +239,7 @@ module SiSU_Initialize
       rnc=File.new(rnc_file,'w')
       rnc << @rxng.rnc_model_input_node
       rnc.close
-      schema=SiSU_Env::System_call.new(rnc_file,dtd_file)
+      schema=SiSU_Env::SystemCall.new(rnc_file,dtd_file)
       schema.relaxng(@opt.cmd)
     end
   end
