@@ -56,21 +56,21 @@
  ** Description: system environment, resource control and configuration details
 
 =end
-module SiSU_metadata
+module SiSU_DAL_Metadata
   class Metadata
     def initialize(md,metad)
       @md,@metadata=md,metad
-      l=SiSU_Env::Standardise_language.new(@md.opt.lng).language
+      l=SiSU_Env::StandardiseLanguage.new(@md.opt.lng).language
       language=l[:n]
       @tr=SiSU_Translate::Source.new(md,language)
     end
     def make_para(obj,ocn)
       h={ obj: obj, ocn: 0 }
-      SiSU_document_structure::Object_para.new.paragraph(h)
+      SiSU_DAL_DocumentStructure::ObjectPara.new.paragraph(h)
     end
     def make_heading(obj,ocn,name,lv,ln)
       h={ lv: lv, ln: ln, name: name, obj: obj, ocn: 0 }
-      SiSU_document_structure::Object_heading.new.heading(h)
+      SiSU_DAL_DocumentStructure::ObjectHeading.new.heading(h)
     end
     def metadata
     end
