@@ -56,22 +56,22 @@
  ** Description: system environment, resource control and configuration details
 
 =end
-module SiSU_substitute_and_insert
+module SiSU_DAL_SubstituteAndInsert
   class SI
     def initialize(md,data)
       @md,@data=md,data
-      @skin=SiSU_Env::Info_skin.new(@md)
+      @skin=SiSU_Env::InfoSkin.new(@md)
     end
     def substitutions_and_insertions?
       data=@data
       data_expand=[]
       if data[0] =~ /^#!\s*(?:\/usr\/bin\/env sisu|\/usr\/bin\/sisu)/ # remove bang from top #! (however file is stripped, so will be removed provided no content precedes it)
-        data[0].gsub!(/^#!\s*\/usr\/bin\/sisu/,'')
-        data[0].gsub!(/^#!\s*\/usr\/bin\/env sisu/,'')
+        data[0]=data[0].gsub(/^#!\s*\/usr\/bin\/sisu/,'').
+          gsub(/^#!\s*\/usr\/bin\/env sisu/,'')
       end
       if data[0] =~ /^(SiSU\s+[\d.]*|sisu-[\d.]+)$/ # SiSU identifier
-        data[0].gsub!(/^(SiSU\s*[\d.]*)$/,'% \1')
-        data[0].gsub!(/^(sisu-[\d.]+)$/,'% \1')
+        data[0]=data[0].gsub(/^(SiSU\s*[\d.]*)$/,'% \1').
+          gsub(/^(sisu-[\d.]+)$/,'% \1')
       end
       data.each do |para|
         if para =~/<:(insert\d+)!?>/ \
@@ -132,22 +132,24 @@ module SiSU_substitute_and_insert
           para.each {|x| data_expand << x }
         else data_expand << para
         end
-        data_expand.flatten!
-        data_expand.compact!
+        data_expand=data_expand.flatten.compact
       end
+      data_new=[]
       data_expand.each do |para|
         para=if @md.markup_version.determined >= 0.38
-          SiSU_document_structure_extract::Structure.new(@md,para).structure_markup_normalize
+          SiSU_DAL_DocumentStructureExtract::Structure.new(@md,para).structure_markup_normalize
         else
-          SiSU_document_structure_extract::Structure.new(@md,para).structure_marks
+          SiSU_DAL_DocumentStructureExtract::Structure.new(@md,para).structure_marks
         end
-        para.gsub!(/^(:?A~)\s*$/,'\1~ @title @author')                                    #conditional header
-        para.gsub!(/^((?:[1-9]|:?[A-C])~\S*)\s*$/,'\1~ [Note: heading marker::required title missing]~#')    #conditional header for incorporated document 2004w12
+        para=para.gsub(/^(:?A~)\s*$/,'\1~ @title @author').                                    #conditional header
+          gsub(/^((?:[1-9]|:?[A-C])~\S*)\s*$/,'\1~ [Note: heading marker::required title missing]~#')    #conditional header for incorporated document 2004w12
         if para =~/^@\S+?:/
-          para.gsub!(/^@(\S+?):(\s+|$)/,"#{Mx[:meta_o]}\\1#{Mx[:meta_c]}\\2")
-          para.gsub!(/^@(\S+?):([+-])(\s+|$)/,"#{Mx[:meta_o]}\\1\\2#{Mx[:meta_c]}\\3")
+          para=para.gsub(/^@(\S+?):(\s+|$)/,"#{Mx[:meta_o]}\\1#{Mx[:meta_c]}\\2").
+            gsub(/^@(\S+?):([+-])(\s+|$)/,"#{Mx[:meta_o]}\\1\\2#{Mx[:meta_c]}\\3")
         end
+        data_new << para
       end
+      data_new
     end
   end
 end
