@@ -57,13 +57,13 @@
     sqlite
 
 =end
-module SiSU_DB_columns
+module SiSU_DbColumns
   require_relative 'sysenv'                            # sysenv.rb
   require_relative 'db_sqltxt'                         # db_sqltxt.rb
-  class Columns < SiSU_DB_text::Prepare
+  class Columns < SiSU_DbText::Prepare
     def initialize(md=nil)
       @md=md
-      @db=SiSU_Env::Info_db.new #watch
+      @db=SiSU_Env::InfoDb.new #watch
       @lang ||=SiSU_i18n::Languages.new
       if defined? md.opt.mod \
       and md.opt.mod.inspect=~/import|update/ \
@@ -109,7 +109,7 @@ module SiSU_DB_columns
           t=if defined? @md.title.full \
           and @md.title.full=~/\S+/
             txt=@md.title.full
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -131,7 +131,7 @@ module SiSU_DB_columns
           t=if defined? @md.title.main \
           and @md.title.main=~/\S+/
             txt=@md.title.main
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -153,7 +153,7 @@ module SiSU_DB_columns
           t=if defined? @md.title.sub \
           and @md.title.sub=~/\S+/
             txt=@md.title.sub
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -175,7 +175,7 @@ module SiSU_DB_columns
           t=if defined? @md.title.short \
           and @md.title.short=~/\S+/
             txt=@md.title.short
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -197,7 +197,7 @@ module SiSU_DB_columns
           t=if defined? @md.title.edition \
           and @md.title.edition=~/\S+/
             txt=@md.title.edition
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -219,7 +219,7 @@ module SiSU_DB_columns
           t=if defined? @md.title.note \
           and @md.title.note=~/\S+/
             txt=@md.title.note
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -240,7 +240,7 @@ module SiSU_DB_columns
         def tuple
           t=if @lang.list[@md.opt.lng][:n]
             txt=@lang.list[@md.opt.lng][:n]
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -262,7 +262,7 @@ module SiSU_DB_columns
           t=if defined? @md.opt.lng \
           and @md.opt.lng=~/\S+/
             txt=@md.opt.lng
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -302,8 +302,8 @@ module SiSU_DB_columns
             @md.creator.author_detail.each do |h|
               txt=txt + %{#{h[:the]}, #{h[:others]}; }
             end
-            txt.gsub!(/[;, ]+\s*$/,'')
-            special_character_escape(txt)
+            txt=txt.gsub(/[;, ]+\s*$/,'')
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -325,7 +325,7 @@ module SiSU_DB_columns
           t=if defined? @md.creator.author_hon \
           and @md.creator.author_hon=~/\S+/
             txt=@md.creator.author_hon
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -347,7 +347,7 @@ module SiSU_DB_columns
           t=if defined? @md.creator.author_nationality_detail \
           and @md.creator.author_nationality=~/\S+/
             txt=@md.creator.author_nationality_detail
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -374,8 +374,8 @@ module SiSU_DB_columns
             @md.creator.editor_detail.each do |h|
               txt=txt + %{#{h[:the]}, #{h[:others]}; }
             end
-            txt.gsub!(/[;, ]+\s*$/,'')
-            special_character_escape(txt)
+            txt=txt.gsub(/[;, ]+\s*$/,'')
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -402,8 +402,8 @@ module SiSU_DB_columns
             @md.creator.contributor_detail.each do |h|
               txt=txt + %{#{h[:the]}, #{h[:others]}; }
             end
-            txt.gsub!(/[;, ]+\s*$/,'')
-            special_character_escape(txt)
+            txt=txt.gsub(/[;, ]+\s*$/,'')
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -430,8 +430,8 @@ module SiSU_DB_columns
             @md.creator.illustrator_detail.each do |h|
               txt=txt + %{#{h[:the]}, #{h[:others]}; }
             end
-            txt.gsub!(/[;, ]+\s*$/,'')
-            special_character_escape(txt)
+            txt=txt.gsub(/[;, ]+\s*$/,'')
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -458,8 +458,8 @@ module SiSU_DB_columns
             @md.creator.photographer_detail.each do |h|
               txt=txt + %{#{h[:the]}, #{h[:others]}; }
             end
-            txt.gsub!(/[;, ]+\s*$/,'')
-            special_character_escape(txt)
+            txt=txt.gsub(/[;, ]+\s*$/,'')
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -485,8 +485,8 @@ module SiSU_DB_columns
             @md.creator.translator_detail.each do |h|
               txt=txt + %{#{h[:the]}, #{h[:others]}; }
             end
-            txt.gsub!(/[;, ]+\s*$/,'')
-            special_character_escape(txt)
+            txt=txt.gsub(/[;, ]+\s*$/,'')
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -513,8 +513,8 @@ module SiSU_DB_columns
             @md.creator.prepared_by_detail.each do |h|
               txt=txt + %{#{h[:the]}, #{h[:others]}; }
             end
-            txt.gsub!(/[;, ]+\s*$/,'')
-            special_character_escape(txt)
+            txt=txt.gsub(/[;, ]+\s*$/,'')
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -541,8 +541,8 @@ module SiSU_DB_columns
             @md.creator.digitized_by_detail.each do |h|
               txt=txt + %{#{h[:the]}, #{h[:others]}; }
             end
-            txt.gsub!(/[;, ]+\s*$/,'')
-            special_character_escape(txt)
+            txt=txt.gsub(/[;, ]+\s*$/,'')
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -569,8 +569,8 @@ module SiSU_DB_columns
             @md.creator.audio_detail.each do |h|
               txt=txt + %{#{h[:the]}, #{h[:others]}; }
             end
-            txt.gsub!(/[;, ]+\s*$/,'')
-            special_character_escape(txt)
+            txt=txt.gsub(/[;, ]+\s*$/,'')
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -596,8 +596,8 @@ module SiSU_DB_columns
             @md.creator.video_detail.each do |h|
               txt=txt + %{#{h[:the]}, #{h[:others]}; }
             end
-            txt.gsub!(/[;, ]+\s*$/,'')
-            special_character_escape(txt)
+            txt=txt.gsub(/[;, ]+\s*$/,'')
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -630,7 +630,7 @@ module SiSU_DB_columns
         def tuple
           t=if @lang.list[@md.opt.lng][:n]
             txt=@lang.list[@md.opt.lng][:n]
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -653,7 +653,7 @@ module SiSU_DB_columns
           t=if defined? @md.opt.lng \
           and @md.opt.lng=~/\S+/
             txt=@md.opt.lng
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -675,7 +675,7 @@ module SiSU_DB_columns
           t=if defined? @md.language.original \
           and @md.language.original=~/\S+/
             txt=@md.language.original
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -697,7 +697,7 @@ module SiSU_DB_columns
           t=if defined? @md.language.original_char \
           and @md.language.original_char=~/\S+/
             txt=@md.language.original_char
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -733,7 +733,7 @@ module SiSU_DB_columns
           t=if defined? @md.date.added_to_site \
           and @md.date.added_to_site=~/\S+/
             txt=@md.date.added_to_site
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -755,7 +755,7 @@ module SiSU_DB_columns
           t=if defined? @md.date.available \
           and @md.date.available=~/\S+/
             txt=@md.date.available
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -777,7 +777,7 @@ module SiSU_DB_columns
           t=if defined? @md.date.created \
           and @md.date.created=~/\S+/
             txt=@md.date.created
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -799,7 +799,7 @@ module SiSU_DB_columns
           t=if defined? @md.date.issued \
           and @md.date.issued=~/\S+/
             txt=@md.date.issued
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -821,7 +821,7 @@ module SiSU_DB_columns
           t=if defined? @md.date.modified \
           and @md.date.modified=~/\S+/
             txt=@md.date.modified
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -843,7 +843,7 @@ module SiSU_DB_columns
           t=if defined? @md.date.published \
           and @md.date.published=~/\S+/
             txt=@md.date.published
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -865,7 +865,7 @@ module SiSU_DB_columns
           t=if defined? @md.date.valid \
           and @md.date.valid=~/\S+/
             txt=@md.date.valid
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -887,7 +887,7 @@ module SiSU_DB_columns
           t=if defined? @md.date.translated \
           and @md.date.translated=~/\S+/
             txt=@md.date.translated
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -909,7 +909,7 @@ module SiSU_DB_columns
           t=if defined? @md.date.original_publication \
           and @md.date.original_publication=~/\S+/
             txt=@md.date.original_publication
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -932,7 +932,7 @@ module SiSU_DB_columns
           t=if defined? @md.generated \
           and @md.generated.to_s=~/\S+/
             txt=@md.generated.to_s
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -958,7 +958,7 @@ module SiSU_DB_columns
           t=if defined? @md.publisher \
           and @md.publisher=~/\S+/
             txt=@md.publisher
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -980,7 +980,7 @@ module SiSU_DB_columns
 #        t=if defined? @md.current.publisher \
 #        and @md.current.publisher=~/\S+/
 #          txt=@md.current.publisher
-#          special_character_escape(txt)
+#          txt=special_character_escape(txt)
 #          "'#{txt}', "
 #        end
 #      end
@@ -1011,7 +1011,7 @@ module SiSU_DB_columns
           t=if defined? @md.original.publisher \
           and @md.original.publisher=~/\S+/
             txt=@md.original.publisher
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1033,7 +1033,7 @@ module SiSU_DB_columns
           t=if defined? @md.original.language \
           and @md.original.language=~/\S+/
             txt=@md.original.language
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1055,7 +1055,7 @@ module SiSU_DB_columns
           t=if defined? @md.original.language_char \
           and @md.original.language_char=~/\S+/
             txt=@md.original.language_char
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1077,7 +1077,7 @@ module SiSU_DB_columns
           t=if defined? @md.original.source \
           and @md.original.source=~/\S+/
             txt=@md.original.source
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1099,7 +1099,7 @@ module SiSU_DB_columns
           t=if defined? @md.original.institution \
           and @md.original.institution=~/\S+/
             txt=@md.original.institution
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1121,7 +1121,7 @@ module SiSU_DB_columns
           t=if defined? @md.original.nationality \
           and @md.original.nationality=~/\S+/
             txt=@md.original.nationality
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1158,7 +1158,7 @@ module SiSU_DB_columns
           t=if defined? @md.rights.all \
           and @md.rights.all=~/\S+/
             txt=@md.rights.all
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1180,7 +1180,7 @@ module SiSU_DB_columns
           t=if defined? @md.rights.copyright_text \
           and @md.rights.copyright_text=~/\S+/
             txt=@md.rights.copyright_text
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1202,7 +1202,7 @@ module SiSU_DB_columns
           t=if defined? @md.rights.copyright_translation \
           and @md.rights.copyright_translation=~/\S+/
             txt=@md.rights.copyright_translation
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1224,7 +1224,7 @@ module SiSU_DB_columns
           t=if defined? @md.rights.copyright_illustrations \
           and @md.rights.copyright_illustrations=~/\S+/
             txt=@md.rights.copyright_illustrations
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1246,7 +1246,7 @@ module SiSU_DB_columns
           t=if defined? @md.rights.copyright_photographs \
           and @md.rights.copyright_photographs=~/\S+/
             txt=@md.rights.copyright_photographs
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1268,7 +1268,7 @@ module SiSU_DB_columns
           t=if defined? @md.rights.copyright_preparation \
           and @md.rights.copyright_preparation=~/\S+/
             txt=@md.rights.copyright_preparation
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1290,7 +1290,7 @@ module SiSU_DB_columns
           t=if defined? @md.rights.copyright_digitization \
           and @md.rights.copyright_digitization=~/\S+/
             txt=@md.rights.copyright_digitization
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1312,7 +1312,7 @@ module SiSU_DB_columns
           t=if defined? @md.rights.copyright_audio \
           and @md.rights.copyright_audio=~/\S+/
             txt=@md.rights.copyright_audio
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1334,7 +1334,7 @@ module SiSU_DB_columns
           t=if defined? @md.rights.copyright_video \
           and @md.rights.copyright_video=~/\S+/
             txt=@md.rights.copyright_video
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1356,7 +1356,7 @@ module SiSU_DB_columns
           t=if defined? @md.rights.license \
           and @md.rights.license=~/\S+/
             txt=@md.rights.license
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1394,7 +1394,7 @@ module SiSU_DB_columns
           t=if defined? @md.classify.topic_register \
           and @md.classify.topic_register=~/\S+/
             txt=@md.classify.topic_register
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1416,7 +1416,7 @@ module SiSU_DB_columns
           t=if defined? @md.classify.subject \
           and @md.classify.subject=~/\S+/
             txt=@md.classify.subject
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1438,7 +1438,7 @@ module SiSU_DB_columns
           t=if defined? @md.classify.type \
           and @md.classify.type=~/\S+/
             txt=@md.classify.type
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1460,7 +1460,7 @@ module SiSU_DB_columns
           t=if defined? @md.classify.loc \
           and @md.classify.loc=~/\S+/
             txt=@md.classify.loc
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1482,7 +1482,7 @@ module SiSU_DB_columns
           t=if defined? @md.classify.dewey \
           and @md.classify.dewey=~/\S+/
             txt=@md.classify.dewey
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1504,7 +1504,7 @@ module SiSU_DB_columns
           t=if defined? @md.classify.oclc \
           and @md.classify.oclc=~/\S+/
             txt=@md.classify.oclc
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1526,7 +1526,7 @@ module SiSU_DB_columns
           t=if defined? @md.classify.pg \
           and @md.classify.pg=~/\S+/
             txt=@md.classify.pg
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1548,7 +1548,7 @@ module SiSU_DB_columns
           t=if defined? @md.classify.isbn \
           and @md.classify.isbn=~/\S+/
             txt=@md.classify.isbn
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1570,7 +1570,7 @@ module SiSU_DB_columns
           t=if defined? @md.classify.format \
           and @md.classify.format=~/\S+/
             txt=@md.classify.format
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1592,7 +1592,7 @@ module SiSU_DB_columns
           t=if defined? @md.classify.identifier \
           and @md.classify.identifier=~/\S+/
             txt=@md.classify.identifier
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1614,7 +1614,7 @@ module SiSU_DB_columns
           t=if defined? @md.classify.relation \
           and @md.classify.relation=~/\S+/
             txt=@md.classify.relation
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1636,7 +1636,7 @@ module SiSU_DB_columns
           t=if defined? @md.classify.coverage \
           and @md.classify.coverage=~/\S+/
             txt=@md.classify.coverage
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1658,7 +1658,7 @@ module SiSU_DB_columns
           t=if defined? @md.classify.keywords \
           and @md.classify.keywords=~/\S+/
             txt=@md.classify.keywords
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1692,7 +1692,7 @@ module SiSU_DB_columns
           t=if defined? @md.notes.abstract \
           and @md.notes.abstract=~/\S+/
             txt=@md.notes.abstract
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1714,7 +1714,7 @@ module SiSU_DB_columns
           t=if defined? @md.notes.comment \
           and @md.notes.comment=~/\S+/
             txt=@md.notes.comment
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1736,7 +1736,7 @@ module SiSU_DB_columns
           t=if defined? @md.notes.description \
           and @md.notes.description=~/\S+/
             txt=@md.notes.description
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1758,7 +1758,7 @@ module SiSU_DB_columns
           t=if defined? @md.notes.history \
           and @md.notes.history=~/\S+/
             txt=@md.notes.history
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1780,7 +1780,7 @@ module SiSU_DB_columns
           t=if defined? @md.notes.prefix \
           and @md.notes.prefix=~/\S+/
             txt=@md.notes.prefix
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1802,7 +1802,7 @@ module SiSU_DB_columns
           t=if defined? @md.notes.prefix_a \
           and @md.notes.prefix_a=~/\S+/
             txt=@md.notes.prefix_a
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1824,7 +1824,7 @@ module SiSU_DB_columns
           t=if defined? @md.notes.prefix_b \
           and @md.notes.prefix_b=~/\S+/
             txt=@md.notes.prefix_b
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1846,7 +1846,7 @@ module SiSU_DB_columns
           t=if defined? @md.notes.suffix \
           and @md.notes.suffix=~/\S+/
             txt=@md.notes.suffix
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1871,7 +1871,7 @@ module SiSU_DB_columns
           t=if defined? @md.fns \
           and @md.fns=~/\S+/
             txt=@md.fns
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -1916,7 +1916,7 @@ module SiSU_DB_columns
          t=if defined? @md.filesize \
          and @md.filesize=~/\S+/
            txt=@md.filesize
-           special_character_escape(txt)
+           txt=special_character_escape(txt)
            ["#{name}, ","'#{txt}', "]
          else ['','']
          end
@@ -1938,7 +1938,7 @@ module SiSU_DB_columns
           t=if defined? @md.wc_words \
           and @md.wc_words=~/\S+/
             txt=@md.wc_words
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -2006,7 +2006,7 @@ module SiSU_DB_columns
           t=if defined? @md.skin_name \
           and @md.skin_name=~/\S+/
             txt=@md.skin_name
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -2029,7 +2029,7 @@ module SiSU_DB_columns
           and @md.dgst_skin.class==Array \
           and @md.dgst_skin[1]=~/\S+/
             txt=@md.dgst_skin[1]
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -2051,7 +2051,7 @@ module SiSU_DB_columns
           t=if defined? @md.skin \
           and @md.skin=~/\S+/
             txt=@md.skin
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -2074,7 +2074,7 @@ module SiSU_DB_columns
           t=if defined? @md.links \
           and @md.links=~/\S+/
             txt=@md.links
-            special_character_escape(txt)
+            txt=special_character_escape(txt)
             ["#{name}, ","'#{txt}', "]
           else ['','']
           end
@@ -2084,7 +2084,7 @@ module SiSU_DB_columns
       self
     end
   end
-  class Column_size
+  class ColumnSize
     def document_clean # restriction not necessary
       60000
     end
