@@ -57,7 +57,7 @@
     sqlite
 
 =end
-module SiSU_DB_drop
+module SiSU_DbDrop
   class Drop
     require_relative 'response'                          # response.rb
     def initialize(opt,conn,db_info,sql_type='')
@@ -90,10 +90,10 @@ module SiSU_DB_drop
             and File.exist?(@db_info.sqlite.db)
               @conn.close
               File.unlink(@db_info.sqlite.db)
-              db=SiSU_Env::Info_db.new
+              db=SiSU_Env::InfoDb.new
               conn=db.sqlite.conn_sqlite3
-              sdb=SiSU_DB_DBI::Create.new(@opt,conn,@db_info,@sql_type)
-              sdb_index=SiSU_DB_DBI::Index.new(@opt,conn,@db_info,@sql_type)
+              sdb=SiSU_DbDBI::Create.new(@opt,conn,@db_info,@sql_type)
+              sdb_index=SiSU_DbDBI::Index.new(@opt,conn,@db_info,@sql_type)
               sdb.output_dir?
               begin
                 sdb.create_db
@@ -104,7 +104,7 @@ module SiSU_DB_drop
                 sdb.create_table.endnotes_plus
                 sdb.create_table.urls
                 sdb_index.create_indexes
-              rescue;  SiSU_Errors::Info_error.new($!,$@,'-D').error; @sdb.output_dir?
+              rescue;  SiSU_Errors::InfoError.new($!,$@,'-D').error; sdb.output_dir?
               end
               exit
             else
