@@ -57,7 +57,7 @@
    sqlite
 
 =end
-module SiSU_DB_index
+module SiSU_DbIndex
   class Index                                           # create documents Indexes def initialize(opt,conn='',sql_type='')
     def initialize(opt,conn,file,sql_type='')
       @opt,@conn,@file,@sql_type=opt,conn,file,sql_type
@@ -71,7 +71,7 @@ module SiSU_DB_index
         end
       end
       def base
-        print "\n          create documents common indexes\n" unless @opt.cmd =~/q/
+        print "\n          create documents common indexes\n" if @opt.cmd =~/[VM]/
         sql_arr=[
           %{CREATE INDEX idx_ocn ON doc_objects(ocn);},
           %{CREATE INDEX idx_digest_clean ON doc_objects(digest_clean);},
@@ -99,7 +99,7 @@ module SiSU_DB_index
         conn_execute_array(sql_arr)
       end
       def text
-        print "\n          create documents TEXT indexes\n" unless @opt.cmd =~/q/
+        print "\n          create documents TEXT indexes\n" if @opt.cmd =~/[VM]/
         sql_arr=[
           %{CREATE INDEX idx_clean ON doc_objects(clean);},
           %{CREATE INDEX idx_endnote ON endnotes(clean);}
