@@ -57,20 +57,20 @@
     sqlite
 
 =end
-module SiSU_DB_select
+module SiSU_DbSelect
   class Case
     def initialize(opt,conn='',sql_type='pg')
       @opt,@conn,@sql_type=opt,conn,sql_type
-      @db=SiSU_Env::Info_db.new
-      @file=sql_maintenance_file
-      @sdb=SiSU_DB_DBI::Create.new(@opt,@conn,@file,@sql_type)      # db_dbi.rb
-      @sdb_index=SiSU_DB_DBI::Index.new(@opt,@conn,@file,@sql_type) # db_dbi.rb
-      @sdb_no=SiSU_DB_DBI::Drop.new(@opt,@conn,@db,@sql_type)       # db_dbi.rb
+      @db=SiSU_Env::InfoDb.new
+      @file_maint=sql_maintenance_file
+      @sdb=SiSU_DbDBI::Create.new(@opt,@conn,@file_maint,@sql_type)      # db_dbi.rb
+      @sdb_index=SiSU_DbDBI::Index.new(@opt,@conn,@file_maint,@sql_type) # db_dbi.rb
+      @sdb_no=SiSU_DbDBI::Drop.new(@opt,@conn,@db,@sql_type)       # db_dbi.rb
       if @opt.mod.inspect =~/update|import/
-        @sdb_import=SiSU_DB_DBI::Import.new(@opt,@conn,@file,@sql_type)
-        @sdb_remove_doc=SiSU_DB_DBI::Remove.new(@opt,@conn,@file,@sql_type)
+        @sdb_import=SiSU_DbDBI::Import.new(@opt,@conn,@file_maint,@sql_type)
+        @sdb_remove_doc=SiSU_DbDBI::Remove.new(@opt,@conn,@file_maint,@sql_type)
       elsif @opt.mod.inspect =~/remove/
-        @sdb_remove_doc=SiSU_DB_DBI::Remove.new(@opt,@conn,@file,@sql_type)
+        @sdb_remove_doc=SiSU_DbDBI::Remove.new(@opt,@conn,@file_maint,@sql_type)
       end
     end
     def db_exist?
@@ -90,9 +90,9 @@ module SiSU_DB_select
     def sql_maintenance_file
       file=if @opt.inspect =~/M/
         x=if @opt.fns and not @opt.fns.empty?
-          @env=SiSU_Env::Info_env.new(@opt.fns) if @opt.fns
+          @env=SiSU_Env::InfoEnv.new(@opt.fns) if @opt.fns
           puts "\n#{@env.processing_path.sqlite}/#{@opt.fns}.sql" if @sql_type =~/sqlite/ and @opt.cmd =~/M/
-          @db=SiSU_Env::Info_db.new
+          @db=SiSU_Env::InfoDb.new
           @job="sqlite3 #{@db.sqlite.db} < #{@env.processing_path.sqlite}/#{@opt.fns}.sql"
           File.new("#{@env.processing_path.sqlite}/#{@opt.fns}.sql",'w+')
         elsif @opt.fns and @opt.fns.inspect =~/create/; nil #sort variations later
@@ -108,56 +108,56 @@ module SiSU_DB_select
         when /^--createdb$/
           @sdb.output_dir?
           begin
-          @sdb.create_db
+            @sdb.create_db
           rescue; @sdb.output_dir?
           end
         when /^--(?:init(?:ialize)?|create(?:all)?)$/
           @sdb.output_dir?
           begin
-          @sdb.create_table.metadata_and_text
-          @sdb.create_table.doc_objects
-          @sdb.create_table.endnotes
-          @sdb.create_table.endnotes_asterisk
-          @sdb.create_table.endnotes_plus
-          @sdb.create_table.urls
-          @sdb_index.create_indexes
-          rescue;  SiSU_Errors::Info_error.new($!,$@,'-D').error; @sdb.output_dir?
+            @sdb.create_table.metadata_and_text
+            @sdb.create_table.doc_objects
+            @sdb.create_table.endnotes
+            @sdb.create_table.endnotes_asterisk
+            @sdb.create_table.endnotes_plus
+            @sdb.create_table.urls
+            @sdb_index.create_indexes
+          rescue;  SiSU_Errors::InfoError.new($!,$@,'-D').error; @sdb.output_dir?
           end
         when /^--createtables?$/
           @sdb.output_dir?
           begin
-          @sdb.create_table.metadata_and_text
-          @sdb.create_table.doc_objects
-          @sdb.create_table.endnotes
-          @sdb.create_table.endnotes_asterisk
-          @sdb.create_table.endnotes_plus
-          @sdb.create_table.urls
-          @sdb_index.create_indexes
+            @sdb.create_table.metadata_and_text
+            @sdb.create_table.doc_objects
+            @sdb.create_table.endnotes
+            @sdb.create_table.endnotes_asterisk
+            @sdb.create_table.endnotes_plus
+            @sdb.create_table.urls
+            @sdb_index.create_indexes
           rescue; @sdb.output_dir?
           end
         when /^--recreate$/
           @sdb.output_dir?
           begin
-          @sdb_no.drop.tables
-          @sdb.create_table.metadata_and_text
-          @sdb.create_table.doc_objects
-          @sdb.create_table.endnotes
-          @sdb.create_table.endnotes_asterisk
-          @sdb.create_table.endnotes_plus
-          @sdb.create_table.urls
-          @sdb_index.create_indexes
+            @sdb_no.drop.tables
+            @sdb.create_table.metadata_and_text
+            @sdb.create_table.doc_objects
+            @sdb.create_table.endnotes
+            @sdb.create_table.endnotes_asterisk
+            @sdb.create_table.endnotes_plus
+            @sdb.create_table.urls
+            @sdb_index.create_indexes
           rescue; @sdb.output_dir?
           end
         when /^--cr(eate)?lex$/
           @sdb.output_dir?
           begin
-          @sdb.create_table.doc_objects
+            @sdb.create_table.doc_objects
           rescue; @sdb.output_dir?
           end
         when /^--cr(eate)?metadata$/
           @sdb.output_dir?
           begin
-          @sdb.create_table.metadata_and_text
+            @sdb.create_table.metadata_and_text
           rescue; @sdb.output_dir?
           end
         when /^--import$/
@@ -196,6 +196,7 @@ module SiSU_DB_select
           db_exist?
           @sdb_no.drop.tables
         when /^--(?:db=)?(?:(?:sq)?lite|pg(?:sql)?|my(?:sql)?)$/
+        when /^--(?:v\d+|dev)$/
         else
           help=SiSU_Help::Help.new
           help.summary
