@@ -56,7 +56,7 @@
  ** Description: document digests (md5|sha256) and structure processing
 
 =end
-module SiSU_Digest_view
+module SiSU_DigestView
   require_relative 'particulars'                        # particulars.rb
   require_relative 'prog_text_translation'              # prog_text_translation.rb
   require_relative 'shared_markup_alt.rb'               # shared_markup_alt.rb
@@ -68,8 +68,8 @@ module SiSU_Digest_view
       @fnb=@opt.fnb
       @@endnotes_para=[]
       @@dg=nil
-      @dg=@@dg ||=SiSU_Env::Info_env.new.digest.type
-      @particulars=SiSU_Particulars::Combined_singleton.instance.get_all(opt)
+      @dg=@@dg ||=SiSU_Env::InfoEnv.new.digest.type
+      @particulars=SiSU_Particulars::CombinedSingleton.instance.get_all(opt)
     end
     def read
       begin
@@ -83,9 +83,9 @@ module SiSU_Digest_view
           : SiSU_Screen::Ansi.new(@opt.cmd,"Document #{@dg} Digests",tool).green_title_hi
           SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"file://#{@md.file.output_path.hash_digest.dir}/#{@md.file.base_filename.hash_digest}").flow if @opt.cmd =~/[MV]/
         end
-        SiSU_Digest_view::Source::Scroll.new(@particulars).songsheet
-        SiSU_Env::Info_skin.new(@md).select
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+        SiSU_DigestView::Source::Scroll.new(@particulars).songsheet
+        SiSU_Env::InfoSkin.new(@md).select
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
       end
     end
@@ -97,11 +97,11 @@ module SiSU_Digest_view
       def initialize(particulars) #data='',md='')
         @particulars=particulars
         @data,@env,@md=@particulars.dal_array,@particulars.env,@particulars.md
-        SiSU_Env::SiSU_file.new(@md).mkdir
+        SiSU_Env::FileOp.new(@md).mkdir
         @@dg ||=@env.digest.type
         @@dl ||=@env.digest.length
         @dg,@dl=@@dg,@@dl
-        l=SiSU_Env::Standardise_language.new(@md.opt.lng).language
+        l=SiSU_Env::StandardiseLanguage.new(@md.opt.lng).language
         @language=l[:n]
         @tr=SiSU_Translate::Source.new(@md,@language)
         @sp=' '
@@ -134,7 +134,7 @@ module SiSU_Digest_view
         @@sc_info << f << e
       end
       def output
-        file=SiSU_Env::SiSU_file.new(@md)
+        file=SiSU_Env::FileOp.new(@md)
         filename_digest=file.write_file.hash_digest
         filename_digest << @@description.join << @@ds[:digests].join << @@ds[:tree].join << @@ds[:summary].join << @@sc_info.join
       end
@@ -143,7 +143,7 @@ module SiSU_Digest_view
       end
       def message_digest
         data=@data
-        sys=SiSU_Env::System_call.new
+        sys=SiSU_Env::SystemCall.new
         l=Hash.new(0)
         @p=[]
         @g,@v,@r='','',''
@@ -153,9 +153,9 @@ module SiSU_Digest_view
           if para =~/#{Mx[:id_o]}~(\d+);((?:\w|[0-6]:)\d+);(\w\d+)#{Mx[:id_c]}#{Mx[:id_o]}([0-9a-f]{#{@dl}}):([0-9a-f]{#{@dl}})#{Mx[:id_c]}/
             ocn,h1,h2,d_clean,d_all=$1,$2,$3,$4,$5
             @ocn=ocn unless ocn.to_i==0
-            para.gsub!(/#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}/,'<b>\1</b>')
-            para.gsub!(/#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}/,'<i>\1</i>')
-            para.gsub!(/#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}/,'<u>\1</u>')
+            para=para.gsub(/#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}/,'<b>\1</b>').
+              gsub(/#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}/,'<i>\1</i>').
+              gsub(/#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}/,'<u>\1</u>')
             if para=~/#{Mx[:en_a_o]}[\d*+]+.+?#{Mx[:id_o]}[0-9a-f]{#{@dl}}#{Mx[:id_c]}#{Mx[:en_a_c]}/
               para_endnotes << para.scan(/(?:#{Mx[:en_a_o]}|#{Mx[:en_b_o]})([\d*+]+).+?#{Mx[:id_o]}([0-9a-f]{#{@dl}})#{Mx[:id_c]}(?:#{Mx[:en_a_c]}|#{Mx[:en_b_c]})/)
             end
@@ -298,11 +298,11 @@ module SiSU_Digest_view
         data=@data
         endnotes=nil
         data.each do |t_o|
-          dgst=SiSU_text_representation::Modified_text_plus_Hash_digest.new(@md,t_o).composite.dgst
+          dgst=SiSU_TextRepresentation::ModifiedTextPlusHashDigest.new(@md,t_o).composite.dgst
           if dgst
-            if t_o.is=='heading'
+            if t_o.is==:heading
               digests("#{@sp*0}#{dgst[:ocn]}#{@sp*(8-dgst[:ocn].to_s.length)}#{dgst[:dgst_stripped_txt]} #{dgst[:dgst_markedup_txt]} #{dgst[:is]} #{t_o.lv}")
-            elsif t_o.is=='heading_insert'
+            elsif t_o.is==:heading_insert
               digests("#{@sp*0}[#{dgst[:ocn]}]#{@sp*(6-dgst[:ocn].to_s.length)}#{dgst[:dgst_stripped_txt]} #{dgst[:dgst_markedup_txt]} #{dgst[:is]} #{t_o.lv}")
             else
               digests("#{@sp*0}#{dgst[:ocn]}#{@sp*(8-dgst[:ocn].to_s.length)}#{dgst[:dgst_stripped_txt]} #{dgst[:dgst_markedup_txt]} #{dgst[:is]}")
@@ -325,7 +325,7 @@ module SiSU_Digest_view
         dal_structure_tree("------------\n")
         dal_structure_tree("document structure[*]\n")
         data.each do |t_o|
-          if t_o.is=='heading'
+          if t_o.is==:heading
             x=case t_o.ln
             when 1; l[1] +=1 #fix Mx[:lv_o]
               '  '*0 +':A'
@@ -342,7 +342,7 @@ module SiSU_Digest_view
             else nil
             end
           end
-          ocn=t_o.ocn if defined? t_o.ocn and t_o.is !='heading_insert'
+          ocn=t_o.ocn if defined? t_o.ocn and t_o.is !=:heading_insert
           dal_structure_tree("#{x}\n") if x and not x.empty?
         end
         dal_structure_tree("  [*] heading levels\n")
