@@ -56,45 +56,38 @@
  ** Description: epub segment generation, processing
 
 =end
-module SiSU_EPUB_seg
+module SiSU_EPUB_Seg
   require_relative 'shared_xhtml'                       # shared_xhtml.rb
   require_relative 'epub'                               # epub.rb
   require_relative 'shared_metadata'                    # shared_metadata.rb
-  class Seg_output
-    def initialize(md,outputfile,seg,minitoc,type='')
-      @md,@output_epub_cont_seg,@seg,@minitoc,@type=md,outputfile,seg,minitoc,type
+  class Output
+    def initialize(md,outputfile,seg,type='')
+      @md,@output_epub_cont_seg,@seg,@type=md,outputfile,seg,type
     end
     def output #CONSIDER
       if @seg[:title] =~/\S/
         filename_seg=[]
         filename_seg << @seg[:title] << @seg[:nav]
         if @type=='endnotes'
-          @seg[:headings]=[]
-          format_head_seg=SiSU_EPUB_Format::Head_seg.new(@md)
-          @seg[:headings] << format_head_seg.title_banner(@md.title.main,@md.title.sub,@author)
+          @seg[:headings]=[] #watch
           txt_obj={ txt: 'Endnotes', ocn_display: ''}
-          format_seg=SiSU_EPUB_Format::Format_seg.new(@md,txt_obj)
+          format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,txt_obj)
           @seg[:headings] << format_seg.title_heading1
           filename_seg << @seg[:heading_endnotes] << @seg[:headings] << %{\n<div class="content">\n} << @seg[:endnote_all] << '</div>'
         elsif @type=='idx'
           @seg[:headings]=[]
-          format_head_seg=SiSU_EPUB_Format::Head_seg.new(@md)
-          @seg[:headings] << format_head_seg.title_banner(@md.title.main,@md.title.sub,@author)
-          txt_obj={ txt: 'Index', ocn_display: ''}
-          format_seg=SiSU_EPUB_Format::Format_seg.new(@md,txt_obj)
+          format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,txt_obj)
           @seg[:headings] << format_seg.title_heading1
           filename_seg << @seg[:heading_idx] << @seg[:headings] << %{\n<div class="content">\n} << @seg[:idx] << '</div>'
         elsif @type=='metadata'
-          metadata=Metadata::Summary.new(@md).xhtml_display.metadata
+          metadata=SiSU_Metadata::Summary.new(@md).xhtml_display.metadata
           @seg[:headings]=[]
-          format_head_seg=SiSU_EPUB_Format::Head_seg.new(@md)
-          @seg[:headings] << format_head_seg.title_banner(@md.title.main,@md.title.sub,@author)
           txt_obj={ txt: 'Metadata', ocn_display: ''}
-          format_seg=SiSU_EPUB_Format::Format_seg.new(@md,txt_obj)
+          format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,txt_obj)
           @seg[:headings] << format_seg.title_heading1
           filename_seg << @seg[:heading_idx] << @seg[:headings] << %{\n<div class="content">\n} << metadata << '</div>'
         elsif @type=='sisu_manifest'
-          env=SiSU_Env::Info_env.new(@md.fns)
+          env=SiSU_Env::InfoEnv.new(@md.fns)
           path_and_name,url_and_name="#{env.path.output}/#{@md.fnb}/sisu_manifest.html","#{env.url.root}/#{@md.fnb}/sisu_manifest.html"
           manifest=if FileTest.file?("#{path_and_name}")==true
             <<WOK
@@ -104,21 +97,18 @@ WOK
           else ''
           end
           @seg[:headings]=[]
-          format_head_seg=SiSU_EPUB_Format::Head_seg.new(@md)
-          @seg[:headings] << format_head_seg.title_banner(@md.title.main,@md.title.sub,@author)
           txt_obj={ txt: 'Manifest', ocn_display: ''}
-          format_seg=SiSU_EPUB_Format::Format_seg.new(@md,txt_obj)
+          format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,txt_obj)
           @seg[:headings] << format_seg.title_heading1
           filename_seg << @seg[:heading_idx] << @seg[:headings] << %{\n<div class="content">\n} << manifest << '</div>'
         else
           filename_seg << @seg[:headings] << @seg[:main] << "\n</div>\n"
         end
         filename_seg << @seg[:tail] << @seg[:nav] << @seg[:close]
-        filename_seg.flatten!.compact!
+        filename_seg=filename_seg.flatten.compact #watch
         filename_seg.each do |str|
           unless str =~/\A\s*\Z/
-            str.strip!
-            @output_epub_cont_seg << str
+            @output_epub_cont_seg << str.strip
           end
         end
         @output_epub_cont_seg.close
@@ -132,26 +122,25 @@ WOK
     @@loop_count=@@seg_total=@@tracker=0
     @@is4=@@is3=@@is2=@@is1=0
     @@heading1=@@heading2=@@heading3=@@heading4=0
-    @@seg[:nav],@@seg[:title],@@seg[:headings],@@seg[:main],@@seg[:idx],@@seg[:tail],@@seg_subtoc_array,@@seg_endnotes_array,@@seg[:endnote_all]=Array.new(10){[]}
+    @@seg[:headings],@@seg[:main],@@seg[:idx],@@seg[:tail],@@seg_subtoc_array,@@seg_endnotes_array,@@seg[:endnote_all]=Array.new(7){[]}
     @@seg[:heading_endnotes]=''
     @@tablehead,@@number_of_cols=0,0
-    @@segtocband=nil
     @@fns_previous=''
     attr_reader :seg_name_xhtml,:seg_name_xhtml_tracker
     def initialize(md='',data='')
       @md,@data=md,data
-      @vz=SiSU_Env::Get_init.instance.skin
+      @vz=SiSU_Env::GetInit.instance.skin
       @seg_name_xhtml=@@seg_name_xhtml || nil
       @seg_name_xhtml_tracker=@@tracker || nil
+      @make=SiSU_Env::ProcessingSettings.new(@md) if @md
     end
     def songsheet
       begin
-        @minitoc=SiSU_EPUB::Source::Toc.new(@md,@data).minitoc
         data=get_subtoc_endnotes(@data)
         data=articles(data)
-        Seg.new.cleanup # (((( added ))))
+        SiSU_EPUB_Seg::Seg.new.cleanup # (((( added ))))
         #### (((( END )))) ####
-      rescue; SiSU_Errors::Info_error.new($!,$@,@md.opt.cmd,@md.fns).error
+      rescue; SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error
       ensure
         @@seg_name=[]
       end
@@ -163,13 +152,13 @@ WOK
       printed_endnote_seg='n'
       idx_xhtml=nil
       if @md.book_idx
-        idx_xhtml=SiSU_Particulars::Combined_singleton.instance.get_idx_xhtml(@md).xhtml_idx
+        idx_xhtml=SiSU_Particulars::CombinedSingleton.instance.get_idx_xhtml(@md).xhtml_idx
         idx_xhtml.each {|x| @@seg[:idx] << x }
         @@seg[:heading_idx]=''
       end
       data.each do |dob|
-        if (dob.is=='heading' \
-        || dob.is=='heading_insert') \
+        if (dob.is==:heading \
+        || dob.is==:heading_insert) \
         and dob.ln==4
           @@seg_name << dob.name
           seg_name=dob.name
@@ -179,7 +168,7 @@ WOK
       @@seg_total=@@seg_name.length
       testforartnum=@@seg_name_xhtml
       SiSU_Screen::Ansi.new(@md.opt.cmd,@@seg_name.length) if @md.opt.cmd =~/[MVv]/
-      map_nametags=SiSU_Particulars::Combined_singleton.instance.get_map_nametags(@md).nametags_map #p map_nametags
+      map_nametags=SiSU_Particulars::CombinedSingleton.instance.get_map_nametags(@md).nametags_map #p map_nametags
       data.each do |dob|
         #if defined? dob.obj \
         #and dob.obj =~/href="#{Xx[:segment]}#+\S+?"/
@@ -187,15 +176,15 @@ WOK
         #  #while dob.obj =~/href="#{Xx[:segment]}#+(\S+?)"/
         #  #  m=$1
         #  #  if map_nametags[m][:segname]
-        #  #    dob.obj.sub!(/href="#{Xx[:segment]}#+(\S+?)"/,%{href="#{map_nametags[m][:segname]}#{Sfx[:html]}#\\1"})
+        #  #    dob.obj=dob.obj.sub(/href="#{Xx[:segment]}#+(\S+?)"/,%{href="#{map_nametags[m][:segname]}#{Sfx[:html]}#\\1"})
         #  #  else
         #  #    p "NOT FOUND name_tags: #{m}"
-        #  #    dob.obj.sub!(/href="#{Xx[:segment]}#+(\S+?)"/,%{href="#\\1"}) # not satisfactory
+        #  #    dob.obj=dob.obj.sub(/href="#{Xx[:segment]}#+(\S+?)"/,%{href="#\\1"}) # not satisfactory
         #  #  end
         #  #end
         #end
-        if (dob.is=='heading' \
-        || dob.is=='heading_insert') \
+        if (dob.is==:heading \
+        || dob.is==:heading_insert) \
         and dob.ln==4
           if dob.ocn==0
             @@heading4=dob.obj
@@ -203,27 +192,27 @@ WOK
           end
           @@is4=newfile=1
         end
-        if (dob.is=='heading' \
-        || dob.is=='heading_insert') \
+        if (dob.is==:heading \
+        || dob.is==:heading_insert) \
         and dob.ln==3
           @@heading3=dob.obj
           @@is4,@@is3=0,1
         end
-        if (dob.is=='heading' \
-        || dob.is=='heading_insert') \
+        if (dob.is==:heading \
+        || dob.is==:heading_insert) \
         and dob.ln==2
           @@heading2=dob.obj
           @@is4,@@is3,@@is2=0,0,1
         end
-        if (dob.is=='heading' \
-        || dob.is=='heading_insert') \
+        if (dob.is==:heading \
+        || dob.is==:heading_insert) \
         and dob.ln==1
           @@heading1=dob.obj
           @@is4,@@is3,@@is2,@@is1=0,0,0,1
         end
         if (@@is1 && !@@is2 && !@@is3 && !@@is4)
-          if not (dob.is=='heading' \
-          || dob.is=='heading_insert') \
+          if not (dob.is==:heading \
+          || dob.is==:heading_insert) \
           and dob.ln==1
             head1=$_ #; check
           end
@@ -233,36 +222,36 @@ WOK
           if newfile==1 \
           or dob.obj =~/^#{Mx[:br_endnotes]}|^#{Mx[:br_eof]}/
             newfile=0
-            if (dob.is=='heading' \
-            || dob.is=='heading_insert') \
+            if (dob.is==:heading \
+            || dob.is==:heading_insert) \
             and dob.ln==4
               if tracking != 0
-                Seg.new(@md).tail
+                SiSU_EPUB_Seg::Seg.new(@md).tail
                 segfilename="#{dir_epub_cont}/#{@@seg_name_xhtml[tracking-1]}#{Sfx[:epub_xhtml]}"
                 output_epub_cont_seg=File.new(segfilename,'w') if @@seg_name_xhtml[tracking-1]
-                if dob.is=='heading' \
+                if dob.is==:heading \
                 or @@seg_name_xhtml[tracking-1] !~/endnotes|book_index|metadata/
-                  Seg_output.new(@md,output_epub_cont_seg,@@seg,@minitoc).output
-                elsif dob.is=='heading_insert'
+                  SiSU_EPUB_Seg::Output.new(@md,output_epub_cont_seg,@@seg).output
+                elsif dob.is==:heading_insert
                   if @@seg_name_xhtml[tracking-1]=='endnotes'
-                    Seg_output.new(@md,output_epub_cont_seg,@@seg,@minitoc,'endnotes').output
+                    SiSU_EPUB_Seg::Output.new(@md,output_epub_cont_seg,@@seg,'endnotes').output
                   elsif @@seg_name_xhtml[tracking-1]=='book_index'
-                    Seg_output.new(@md,output_epub_cont_seg,@@seg,@minitoc,'idx').output
+                    SiSU_EPUB_Seg::Output.new(@md,output_epub_cont_seg,@@seg,'idx').output
                     @@seg[:idx]=[]
                   elsif @@seg_name_xhtml[tracking-1]=='metadata' # navigation bug FIX
-                    Seg_output.new(@md,output_epub_cont_seg,@@seg,@minitoc,'metadata').output
+                    SiSU_EPUB_Seg::Output.new(@md,output_epub_cont_seg,@@seg,'metadata').output
                   else puts "#{__FILE__}::#{__LINE__}"
                   end
                 else puts "#{__FILE__}::#{__LINE__}"
                 end
-                Seg.new.reinitialise
+                SiSU_EPUB_Seg::Seg.new.reinitialise
                 heading_art(dob)
                 head(dob)
-                if @@seg_name_xhtml[tracking]=='sisu_manifest' # this is for manifest, includes navigation bug
+                if @@seg_name_xhtml[tracking] =='metadata'
                   segfilename="#{dir_epub_cont}/#{@@seg_name_xhtml[tracking]}#{Sfx[:epub_xhtml]}"
                   output_epub_cont_seg=File.new(segfilename,'w')
-                  Seg_output.new(@md,output_epub_cont_seg,@@seg,@minitoc,'sisu_manifest').output
-                  Seg.new.reinitialise #BUG navigation bug with items following metadata, and occurring before manifest, this becomes a bug ... work area for book index, FIX
+                  SiSU_EPUB_Seg::Output.new(@md,output_epub_cont_seg,@@seg,'metadata').output
+                  SiSU_EPUB_Seg::Seg.new.reinitialise #BUG navigation bug with items following metadata, and occurring before manifest, this becomes a bug ... work area for book index, FIX
                 end
                #@output_epub_cont_seg.close                                         #%(((( EOF )))) -->
               end
@@ -273,8 +262,8 @@ WOK
             end
             tracking=tracking+1
           end
-          if (dob.is=='heading' \
-          || dob.is=='heading_insert') \
+          if (dob.is==:heading \
+          || dob.is==:heading_insert) \
           and dob.ln==4 \
           and dob.name
             @@get_hash_to=dob.name
@@ -297,93 +286,80 @@ WOK
       data
     end
     def heading_art(dob)
-      format_head_seg=SiSU_EPUB_Format::Head_seg.new(@md)
-      if dob.is=='heading' \
-      and dob.ln =~/^[1-6]/
-        @@seg[:dot_nav]= (@@tracker < @@seg_total-1) \
-        ? format_head_seg.dot_control_pre_next
-        : format_head_seg.dot_control_pre
-      end
-      @@seg[:title]=format_head_seg.head
+      @@seg[:title]=SiSU_EPUB_Format::HeadSeg.new(@md).head
     end
     def head(dob)
       clean=/<!.*?!>|<:.*?>$/
-      format_head_seg=SiSU_EPUB_Format::Head_seg.new(@md)
-      if @@tracker < @@seg_total-1
-        @@segtocband=(@@tracker==0) \
-        ? format_head_seg.toc_next2
-        : format_head_seg.toc_pre_next2
-      else @@segtocband=format_head_seg.toc_pre2 #if format_head_seg.toc_pre2
-      end
       @p_num ||= ''
       if @@is1==1
         if defined? @md.creator.author \
         and @md.creator.author
           @author=%{<b>#{@md.creator.author}</b>\n}
         end
-        @@seg[:nav] << format_head_seg.navigation_band(@@segtocband)
         ocn=if @@heading1[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]; $1 #fix
         else ''
         end
-        @p_num=SiSU_EPUB_Format::Paragraph_number.new(@md,ocn)
+        @p_num=SiSU_EPUB_Format::ParagraphNumber.new(@md,ocn)
         txt_obj={ txt: @@heading1, ocn_display: @p_num.ocn_display }
-        format_seg=SiSU_EPUB_Format::Format_seg.new(@md,txt_obj)
+        format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,txt_obj)
         @@seg[:headings] << format_seg.title_heading1.gsub(clean,'')
-        @@heading1.gsub!(/&nbsp;<a name="-[\d*+]+" href="#_[\d*+]+">&nbsp;<sup>[\d*+]+<\/sup>&nbsp;<\/a>/,'')
+        @@heading1=@@heading1.gsub(/&nbsp;<a name="-[\d*+]+" href="#_[\d*+]+">&nbsp;<sup>[\d*+]+<\/sup>&nbsp;<\/a>/,'')
       end
       if @@is2==1
         heading2=@@heading2
         ocn=if heading2[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]; $1 #fix
         else ''
         end
-        @p_num=SiSU_EPUB_Format::Paragraph_number.new(@md,ocn)
+        @p_num=SiSU_EPUB_Format::ParagraphNumber.new(@md,ocn)
         txt_obj={ txt: heading2, ocn_display: @p_num.ocn_display }
-        format_seg=SiSU_EPUB_Format::Format_seg.new(@md,txt_obj)
+        format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,txt_obj)
         @@seg[:headings] << format_seg.title_heading2.gsub(clean,'')
-        @@heading2.gsub!(/&nbsp;<a name="-[\d*+]+" href="#_[\d*+]+">&nbsp;<sup>[\d*+]+<\/sup>&nbsp;<\/a>/,'')
+        @@heading2=@@heading2.gsub(/&nbsp;<a name="-[\d*+]+" href="#_[\d*+]+">&nbsp;<sup>[\d*+]+<\/sup>&nbsp;<\/a>/,'')
       end
       if @@is3==1
         heading3=@@heading3
         ocn=if heading3[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]; $1 #fix
         else ''
         end
-        @p_num=SiSU_EPUB_Format::Paragraph_number.new(@md,ocn)
+        @p_num=SiSU_EPUB_Format::ParagraphNumber.new(@md,ocn)
         txt_obj={ txt: heading3, ocn_display: @p_num.ocn_display }
-        format_seg=SiSU_EPUB_Format::Format_seg.new(@md,txt_obj)
+        format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,txt_obj)
         @@seg[:headings] << format_seg.title_heading3.gsub(clean,'')
-        @@heading3.gsub!(/&nbsp;<a name="-[\d*+]+" href="#_[\d*+]+">&nbsp;<sup>[\d*+]+<\/sup>&nbsp;<\/a>/,'')
+        @@heading3=@@heading3.gsub(/&nbsp;<a name="-[\d*+]+" href="#_[\d*+]+">&nbsp;<sup>[\d*+]+<\/sup>&nbsp;<\/a>/,'')
       end
       if @@is4==1
         heading4=@@heading4
         ocn=if heading4[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#{@dp}:#{@dp}#{Mx[:id_c]}$/]; $1 #fix
         else ''
         end
-        @p_num=SiSU_EPUB_Format::Paragraph_number.new(@md,ocn)
+        @p_num=SiSU_EPUB_Format::ParagraphNumber.new(@md,ocn)
         txt_obj={ txt: heading4, ocn_display: @p_num.ocn_display }
-        format_seg=SiSU_EPUB_Format::Format_seg.new(@md,txt_obj)
+        format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,txt_obj)
         @@seg[:headings] << format_seg.title_heading4.gsub(clean,'')
       end
       @@tracker=@@tracker+1
     end
     def markup(dob)
       @debug=[]
-      format_head_seg=SiSU_EPUB_Format::Head_seg.new(@md)
-      if dob.is =~/(?:heading|para)/ #extend as necessary FIX
-        @p_num=SiSU_EPUB_Format::Paragraph_number.new(@md,dob.ocn)
+      if dob.is ==:heading \
+      || dob.is ==:heading_insert \
+      || dob.is ==:para
+        #extend as necessary FIX
+        @p_num=SiSU_EPUB_Format::ParagraphNumber.new(@md,dob.ocn)
       end
-      sto=SiSU_EPUB_Format::Format_text_object.new(@md,dob)
-      dob_xhtml=if dob.is=='heading' \
-      or dob.is=='heading_insert' \
-      or dob.is=='para'
-        dob_xhtml=if dob.is=='heading' \
-        or dob.is=='heading_insert'
+      sto=SiSU_EPUB_Format::FormatTextObject.new(@md,dob)
+      dob_xhtml=if dob.is==:heading \
+      || dob.is==:heading_insert \
+      || dob.is==:para
+        dob_xhtml=if dob.is==:heading \
+        or dob.is==:heading_insert
           if dob.ln==4
-            sto.seg_heading4 # work on see Split_text_object
+            sto.seg_heading4 # work on see SplitTextObject
           elsif dob.ln==5
             sto.seg_heading5
           elsif dob.ln==6; sto.seg_heading6
           end
-        elsif dob.is=='para'
+        elsif dob.is==:para
           if dob.indent \
           and dob.hang \
           and dob.indent =~/[0-9]/ \
@@ -401,43 +377,49 @@ WOK
           else sto.para
           end
         end
-        elsif dob.is =~/^(?:block|group|alt)$/
+        elsif dob.is ==:block \
+        || dob.is ==:group \
+        || dob.is ==:alt
           sto.para #fix this should be block type specific #FIX
-        elsif dob.is=='verse'
+        elsif dob.is==:verse
           sto.verse
-        elsif dob.is=='code'
+        elsif dob.is==:code
           sto.code
-        elsif dob.is=='table'
+        elsif dob.is==:table
           sto.table
-        elsif dob.is=='break'
+        elsif dob.is==:break
           sto.break
       end
       if @md.flag_separate_endnotes # may need to revisit, check
-        dob.obj.gsub!(/"\s+href="#note_ref(\d+)">/,%{" href=\"endnotes#{Sfx[:epub_xhtml]}#note_ref\\1">})       #endnote- twice #removed file type
+        dob.obj=dob.obj.gsub(/"\s+href="#note_ref(\d+)">/,%{" href=\"endnotes#{Sfx[:epub_xhtml]}#note_ref\\1">})       #endnote- twice #removed file type
       end
-      if dob.is =~/heading|para/ \
-      and (not dob.ocn or dob.ocn.to_s.empty?)
-        format_seg=SiSU_EPUB_Format::Format_seg.new(@md,dob)
+      if (dob.is ==:heading \
+      || dob.is==:heading_insert \
+      || dob.is==:para) \
+      && (not dob.ocn or dob.ocn.to_s.empty?)
+        format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,dob)
       end
-      if (dob.is=='heading' \
-      || dob.is=='heading_insert' \
-      || dob.is=='para') \
+      if (dob.is==:heading \
+      || dob.is==:heading_insert \
+      || dob.is==:para) \
       and dob.note_ #dob.obj =~/<a href="#note_ref\d+">&nbsp;<sup id=/                #endnote- note-
-        format_seg=SiSU_EPUB_Format::Format_seg.new(@md,dob)
+        format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,dob)
         dob.obj=format_seg.no_paranum
       end
-      if (dob.is=='heading' \
-      || dob.is=='heading_insert') \
+      if (dob.is==:heading \
+      || dob.is==:heading_insert) \
       and dob.ln==4
         @@seg[:main] <<  %{\n<div class="content">\n}
         @@seg[:main] << dob_xhtml
-        @@seg[:main] << @@seg_subtoc[@@get_hash_fn]                       #% insertion of sub-toc
+        if @make.build.segsubtoc?
+          @@seg[:main] << @@seg_subtoc[@@get_hash_fn]                       #% insertion of sub-toc
+        end
       else
         @@seg[:main] << dob_xhtml
       end
     end
     def tail
-      format_head_seg=SiSU_EPUB_Format::Head_seg.new(@md)
+      format_head_seg=SiSU_EPUB_Format::HeadSeg.new(@md)
       if @md.flag_auto_endnotes \
       and @@seg_endnotes[@@get_hash_fn]
         @@seg[:tail] <<  %{\n<div class="content">\n<div class="endnote">\n}
@@ -452,8 +434,7 @@ WOK
       @@seg[:close] << format_head_seg.xhtml_close
     end
     def reinitialise
-      @@seg[:title],@@seg[:dot_nav],@@seg[:nav],@@seg[:headings],@@seg[:main],@@seg[:tail],@@seg[:credits]=Array.new(8){[]}
-      @@segtocband=nil
+      @@seg[:headings],@@seg[:main],@@seg[:tail],@@seg[:credits]=Array.new(4){[]}
     end
     def cleanup
       reinitialise
@@ -464,10 +445,10 @@ WOK
     end
     def get_subtoc_endnotes(data) #get endnotes & sub-table of contents subtoc
       data.each do |dob|
-        dob.obj.gsub!(/<a name=\"h\d.*?\">(.+?)<\/a>/mi,'\1')
+        dob.obj=dob.obj.gsub(/<a name=\"h\d.*?\">(.+?)<\/a>/mi,'\1')
         if @md.flag_auto_endnotes
-          if (dob.is=='heading' \
-          || dob.is=='heading_insert') \
+          if (dob.is==:heading \
+          || dob.is==:heading_insert) \
           and dob.ln.to_s =~/^[1234]/ \
           and not @@fn.to_s.empty?
             @@seg_endnotes[@@fn]=[]
@@ -475,8 +456,8 @@ WOK
             @@seg_endnotes_array=[] if dob.ln==4
             @@fns_previous=@md.fns if dob.ln==4 and dob.name =~/^meta/
           end
-          if (dob.is=='heading' \
-          || dob.is=='heading_insert') \
+          if (dob.is==:heading \
+          || dob.is==:heading_insert) \
           and dob.ln==4                                              #%  EXTRACTION OF SUB-TOCs & SEGMENT NAME, after EXTRACTION OF ENDNOTES & SUB-TOCs
             @@seg_subtoc[@@fn]=@@seg_subtoc_array
             @@seg_subtoc_array=[]
@@ -490,14 +471,14 @@ WOK
             end
           end
         end
-        if dob.is=='heading' \
+        if dob.is==:heading \
         and dob.ln.to_s =~/^[56]/
           case dob.ln
           when 5
-            format_seg=SiSU_EPUB_Format::Format_seg.new(@md,dob)
+            format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,dob)
             subtoc=format_seg.subtoc_lev5 #keep and make available, this is the subtoc
           when 6
-            format_seg=SiSU_EPUB_Format::Format_seg.new(@md,dob)
+            format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,dob)
             subtoc=format_seg.subtoc_lev6 #keep and make available, this is the subtoc
           end
           @@seg_subtoc_array << subtoc
@@ -505,7 +486,7 @@ WOK
         if @md.flag_auto_endnotes
           ast,pls='&#042;','&#043;'
           if dob.obj =~/(?:#{Mx[:en_a_o]}|#{Mx[:en_b_o]})(?:\d|#{ast}|#{pls})+ / \
-          and dob.is !~/^code/ # endnote-
+          and dob.is !=:code # endnote-
             endnote_array=[]
             if dob.obj=~/#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}/m
               endnote_array << dob.obj.scan(/#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}/m)
@@ -516,7 +497,7 @@ WOK
             if dob.obj=~/#{Mx[:en_b_o]}#{pls}\d+\s.+?#{Mx[:en_b_c]}/m
               endnote_array << dob.obj.scan(/#{Mx[:en_b_o]}#{pls}\d+\s.+?#{Mx[:en_b_c]}/m)
             end
-            endnote_array.flatten! #.compact! #check compacting
+            endnote_array=endnote_array.flatten #.compact #check compacting
             endnote_array.each do |note|
               note_match=note.dup
               note_match_seg=note.dup
@@ -524,7 +505,7 @@ WOK
               try=e_n.split(/<br \/>/)
               try.each do |e|
                 txt_obj={ txt: e }
-                format_seg=SiSU_EPUB_Format::Format_seg.new(@md,txt_obj)
+                format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,txt_obj)
                 note_match=if e =~/#{Mx[:pa_o]}i[1-9]#{Mx[:pa_c]}/
                   format_seg.endnote_body_indent
                 else format_seg.endnote_body
@@ -537,11 +518,11 @@ WOK
               endnote_part_a=note_match_seg[m,1]
               endnote_part_b=note_match_seg[m,2]
               txt_obj={ endnote_part_a: endnote_part_a, endnote_part_b: endnote_part_b }
-              format_seg=SiSU_EPUB_Format::Format_seg.new(@md,txt_obj)
+              format_seg=SiSU_EPUB_Format::FormatSeg.new(@md,txt_obj)
               note_match_all_seg=format_seg.endnote_seg_body(@@fn) #BUG WATCH 200408
               @@seg[:endnote_all] << note_match_all_seg
             end
-            dob.obj.gsub!(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
+            dob.obj=dob.obj.gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
           end
         end
       end
