@@ -59,21 +59,26 @@
 module SiSU_Errors
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env; include SiSU_Screen
-  class Info_error <Create_file
+  class InfoError <CreateFile
     def initialize(error,errorlist,cmd,fns='')
       @fns,@cmd,@error,@errorlist=fns,cmd,error,errorlist
-      @cmd=if cmd and cmd =~/c/; 'Vc'
-      else                       'V'
-      end
+      @cmd=(cmd \
+      && (cmd =~/c/)) \
+      ?  'Vc'
+      : 'V'
     end
-    def error                                                                    #creates file errorlog.sisu in pwd of last error reported
-      file=if @fns; SiSU_Env::Create_file.new(@fns).file_error
-      else          File.new('/tmp/errorlog.sisu','w+')
-      end
+    def error
+      file=@fns \
+      ? (SiSU_Env::CreateFile.new(@fns).file_error)
+      : (File.new('/tmp/errorlog.sisu','w+'))
       file << @fns << "\n" << @error << "\n" << @errorlist
       file.close
-      if @cmd=~/[vVM]/; STDERR.puts SiSU_Screen::Ansi.new('',$!,$@).rescue
-      else             SiSU_Screen::Ansi.new('',"rescued, exception reaised, silenced").puts_grey
+      if @cmd=~/[vVM]/
+        SiSU_Screen::Ansi.new('',$!,$@).rescue do
+          __LINE__.to_s + ':' + __FILE__
+        end
+      else
+        SiSU_Screen::Ansi.new('',"rescued, exception raised, silenced").puts_grey
       end
     end
   end
