@@ -68,7 +68,7 @@ module SiSU_Harvest
       include SiSU_Env
     def initialize(opt)
       @opt=opt
-      @env=SiSU_Env::Info_env.new
+      @env=SiSU_Env::InfoEnv.new
     end
     def read
       harvest_pth="#{@env.path.webserv}/#{@opt.base_stub}"
@@ -78,13 +78,13 @@ module SiSU_Harvest
     def help
       puts <<WOK
       harvest --harvest   extracts document index metadata
-    
+
 WOK
     end
     def css(opt)
       require_relative 'css'                                # css.rb
       css=SiSU_Style::CSS.new
-      fn_css=SiSU_Env::CSS_default.new
+      fn_css=SiSU_Env::CSS_Default.new
       style=File.new("#{@env.path.pwd}/#{fn_css.harvest}",'w')
       style << css.harvest
       style.close
@@ -93,8 +93,8 @@ WOK
       case opt.mod.inspect
       when/--harvest/i
         css(opt) if opt.cmd.inspect =~/M/
-        HARVEST_authors::Songsheet.new(opt,env).songsheet
-        HARVEST_topics::Songsheet.new(opt,env).songsheet
+        SiSU_Harvest_Authors::Songsheet.new(opt,env).songsheet
+        SiSU_Harvest_Topics::Songsheet.new(opt,env).songsheet
         if opt.cmd.inspect =~/R/
           require_relative 'remote'                         # remote.rb
           SiSU_Remote::Put.new(opt).rsync_harvest
