@@ -58,31 +58,26 @@
 =end
 module SiSU_HTML_Format
   include SiSU_Viz
-  class Paragraph_number
+  class ParagraphNumber
     def initialize(md,ocn)
       @md,@ocn=md,ocn.to_s
       @ocn ||=''
-      vz=SiSU_Env::Get_init.instance.skin
-      @skin_no_ocn=if defined? vz.ocn_display_off \
-      and vz.ocn_display_off==true
-        true
-      else false
-      end
     end
     def ocn_display
-      if @md.markup.inspect =~/no_ocn/ \
-      or @md.opt.mod.inspect =~/--no-ocn/ \
-      or @skin_no_ocn
+      @make=SiSU_Env::ProcessingSettings.new(@md)
+      if @make.build.ocn?
+        ocn_class='ocn'
+        if @ocn.to_i==0
+          @ocn.gsub(/^(\d+|)$/,
+            %{<label class="#{ocn_class}"><a name="#{@ocn}">&nbsp;</a></label>})
+        else
+          @ocn.gsub(/^(\d+|)$/,
+            %{<label class="#{ocn_class}"><a name="#{@ocn}" href="##{@ocn}" class="lnk#{ocn_class}">\\1</a></label>})
+        end
+      else
         ocn_class='ocn_off'
         @ocn.gsub(/^(\d+|)$/,
-        %{<label class="#{ocn_class}">&nbsp;</label>})
-      elsif @ocn.to_i==0
-        @ocn.gsub(/^(\d+|)$/,
-        %{<label class="#{ocn_class}"><a name="#{@ocn}">&nbsp;</a></label>})
-      else
-        ocn_class='ocn'
-        @ocn.gsub(/^(\d+|)$/,
-        %{<label class="#{ocn_class}"><a name="#{@ocn}" href="##{@ocn}" class="lnk#{ocn_class}">\\1</a></label>})
+          %{<label class="#{ocn_class}">&nbsp;</label>})
       end
     end
     def name
@@ -95,24 +90,74 @@ module SiSU_HTML_Format
       %{<a href="##{@ocn}">}
     end
   end
-  class Head_information
+  class HeadInformation
+    require_relative 'css'                              # css.rb
     require_relative 'shared_xml'                       # shared_xml.rb
     include SiSU_Viz
     attr_reader :md,:rdf,:vz
     def initialize(md)
       @md=md
       # DublinCore 1 - title
-      @vz=SiSU_Env::Get_init.instance.skin
-      @css=SiSU_Env::CSS_stylesheet.new(md)
+      @vz=SiSU_Env::GetInit.instance.skin
       @seg_name_html=(SiSU_HTML::Source::Seg.new.seg_name_html || [])
       @seg_name_html_tracker=(SiSU_HTML::Source::Seg.new.seg_name_html_tracker || [])
-      @toc,@index='toc','index'
       @metalink='#metadata'
       @tocband_scroll,@tocband_segtoc=nil,nil
+      @stylesheet=SiSU_Style::CSS_HeadInfo.new(md).stylesheet
+      @o_str ||=SiSU_Env::ProcessingSettings.new(md).output_dir_structure
+      @index='index'
+      @toc="#{@md.file.output_path.html_seg.dir}/#{@md.file.base_filename.html_segtoc}"
+    end
+    def url_path_image_sys
+      (@o_str.dump_or_redirect?) \
+      ? './image'
+      : "#{Xx[:html_relative2]}_sisu/image_sys"
+    end
+    def icon
+      def up
+        'arrow_up_red.png'
+      end
+      def next
+        'arrow_next_red.png'
+      end
+      def previous
+        'arrow_prev_red.png'
+      end
+      def dot_clear
+        'dot_clear.png'
+      end
+      def dot_white
+        'dot_white.png'
+      end
+      def dot
+        dot_white
+      end
+      self
+    end
+    def png_nav
+      def toc
+        %{<img border="0" width="22" height="22" src="#{url_path_image_sys}/#{icon.up}" alt="TOC" />}
+      end
+      def pre
+        %{<img border="0" width="22" height="22" src="#{url_path_image_sys}/#{icon.previous}" alt="&lt;&lt;&nbsp;previous" />}
+      end
+      def nxt
+        %{<img border="0" width="22" height="22" src="#{url_path_image_sys}/#{icon.next}" alt="next&nbsp;&gt;&gt;" />}
+      end
+      def dot_toc
+        %{<img border="0" width="100%" height="20" src="#{url_path_image_sys}/#{icon.dot}" alt="&#094;" />}
+      end
+      def dot_pre
+        %{<img border="0" width="100%" height="20" src="#{url_path_image_sys}/#{icon.dot}" alt="&lt;" />}
+      end
+      def dot_nxt
+        %{<img border="0" width="100%" height="20" src="#{url_path_image_sys}/#{icon.dot}" alt="&gt;" />}
+      end
+      self
     end
     def doc_types #used in toc & seg_nav_band
       scroll=seg=''
-      wgt=Widget.new(@md)
+      wgt=SiSU_HTML_Format::Widget.new(@md)
       %{
 <table summary="segment navigation available documents types: toc,doc,pdf,concordance" border="0" cellpadding="3" cellspacing="0">
 <tr>
@@ -122,7 +167,7 @@ module SiSU_HTML_Format
 </tr></table>}
     end
     def rdf
-      SiSU_XML_tags::RDF.new(md)
+      SiSU_XML_Tags::RDF.new(md)
     end
     def doc_type
       %{<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
@@ -149,13 +194,15 @@ module SiSU_HTML_Format
 </html>}
     end
   end
-  class Widget < Head_information
+  class Widget < HeadInformation
     def initialize(md)
       super(md)
       @md=md
-      @cf_defaults=SiSU_Env::Info_processing_flag.new
-      @env=SiSU_Env::Info_env.new(@md.fns)
-      @file=SiSU_Env::SiSU_file.new(@md)
+      @cf_defaults=SiSU_Env::InfoProcessingFlag.new
+      @env=SiSU_Env::InfoEnv.new(md.fns)
+      @file=SiSU_Env::FileOp.new(md)
+      @o_str ||=SiSU_Env::ProcessingSettings.new(md).output_dir_structure
+      @make=SiSU_Env::ProcessingSettings.new(@md)
     end
     def home
       %{<td align="center" bgcolor=#{@vz.color_band2}>
@@ -176,27 +223,34 @@ module SiSU_HTML_Format
     end
     def seg(text)
       %{<td align="center" bgcolor="#99CC66">
-  <a href="#{@md.fn[:toc]}" target="_top" #{@vz.js_doc}>
+  <a href="#{@md.file.base_filename.html_segtoc}" target="_top" #{@vz.js_doc}>
     #{text}
   </a>
 </td>
 }
     end
     def search
-      env=SiSU_Env::Info_env.new(@md.fns,@md)
-      env.widget.search_form('sisusearch',nil,nil,true)
+      if @make.build.html_search_form?
+        env=SiSU_Env::InfoEnv.new(@md.fns,@md)
+        env.widget.search_form('sisusearch',nil,nil,true)
+      else ''
+      end
     end
     def manifest
-      manifest_lnk=if @file.output_dir_structure.by_language_code? \
-      or @file.output_dir_structure.by_filetype?
-        "#{Xx[:html_relative1]}manifest/#{@file.base_filename.manifest}"
-      else @file.base_filename.manifest
-      end
+      if @make.build.links_to_manifest? \
+      and not @o_str.dump_or_redirect?
+        manifest_lnk=if @file.output_dir_structure.by_language_code? \
+        or @file.output_dir_structure.by_filetype?
+          "#{Xx[:html_relative1]}manifest/#{@file.base_filename.manifest}"
+        else @file.base_filename.manifest
+        end
         %{<td align="center" bgcolor=#{@vz.color_band2}>
   <a href="#{manifest_lnk}" target="_top" #{@vz.js_manifest}>
     #{@vz.nav_txt_manifest}
   </a>
 </td>}
+      else ''
+      end
     end
     def pdf #retired 2.7.9
       pdf=if @md.programs[:pdf] \
@@ -253,7 +307,7 @@ module SiSU_HTML_Format
       if @md.concord_make \
       and @md.wc_words < 300000 #max word count for display of concordance here as would now be a large file
   %{<td align="center" bgcolor=#{@vz.color_band2}>
-    <a href="#{@md.fn[:concordance]}" target="_top" #{@vz.js_concordance}>
+    <a href="#{@md.file.base_filename.html_concordance}" target="_top" #{@vz.js_concordance}>
       #{text}
     </a>
   </td>}
@@ -263,44 +317,49 @@ module SiSU_HTML_Format
   end
   class XML
   end
-  class Head_toc < Head_information
+  class HeadToc < HeadInformation
     def initialize(md)
       super(md)
       @md=md
+      @o_str ||=SiSU_Env::ProcessingSettings.new(md).output_dir_structure
+      @make=SiSU_Env::ProcessingSettings.new(@md)
     end
     def scroll_head_navigation_band
-      pdf=if @md.programs[:pdf]
-        <<WOK
+      if @make.build.html_top_band?
+        search_and_manifest=<<WOK
 <td align="center" width="60%">
-  #{make_seg_scroll_pdf}
+  #{make_scroll_search_form_and_manifest_link}
 </td>
 WOK
-      else ''
-      end
-      %{<table summary="table of contents scroll navigation band" id="toc" width="100%" bgcolor=#{@vz.color_band1}>
+        %{<table summary="table of contents scroll navigation band" id="toc" width="100%" bgcolor=#{@vz.color_band1}>
 <tr><td width="20%">
   #{@vz.banner_band}
-</td>#{pdf}
+</td>#{search_and_manifest}
 <td width="20%">
   &nbsp;
 #{@vz.table_close}
 <p />}
+      else ''
+      end
     end
     def concordance_navigation_band(type='')
-      %{<table summary="concordance navigation band" id="toc" width="100%" bgcolor=#{@vz.color_band1}>
+      if @make.build.html_top_band?
+        %{<table summary="concordance navigation band" id="toc" width="100%" bgcolor=#{@vz.color_band1}>
 <tr><td width="20%">
  #{@vz.banner_band}
 </td>
 <td width="20%" align="right">
   &nbsp;<a href="toc.html" target="_top" alt="-&gt;">
-      #{@vz.png_nav_toc}
+      #{png_nav.toc}
     </a>&nbsp;
 #{@vz.table_close}
 <p />}
+      else ''
+      end
     end
     def seg_head_navigation_band(type='')
       firstseg=%{<a href="#{@md.firstseg}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top" alt="-&gt;">
-      #{@vz.png_nav_nxt}
+      #{png_nav.nxt}
     </a>} if @md.firstseg =~/\S+/
       %{<table summary="table of contents segment navigation band" id="toc" width="100%" bgcolor=#{@vz.color_band1}>
 <tr><td width="20%">
@@ -312,45 +371,26 @@ WOK
 <td width="5%" align="right">
   &nbsp;#{firstseg}&nbsp;
 #{@vz.table_close}
-<p />}
-    end
-    def seg_head_navigation_band_bottom(type='') #retired 2.7.9
-      if type=~/pdf/
-        @tocband_segtoc=make_scroll_seg_pdf
-      end
-      firstseg=%{<a href="#{@md.firstseg}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top" alt="-&gt;">
-      #{@vz.png_nav_nxt}
-    </a>} if @md.firstseg =~/\S+/
-      %{<table summary="table of contents segment navigation band" id="toc" width="100%" bgcolor=#{@vz.color_band1}>
-<tr><td width="20%">
- &nbsp;
-</td>
-<td width="75%" align="center">
-  #{@tocband_segtoc}
-</td>
-<td width="5%" align="right">
-  &nbsp;#{firstseg}&nbsp;
-#{@vz.table_close}
 <p />}
     end
     def manifest_link(text)
-#     @file=SiSU_Env::SiSU_file.new(@md) if @md
+#     @file=SiSU_Env::FileOp.new(@md) if @md
   %{<font size=2>
-    <a href="#{@md.fn[:manifest]}" target="_top" #{@vz.js_manifest}>#{text}</a>
+    <a href="#{@md.file.base_filename.manifest}" target="_top" #{@vz.js_manifest}>#{text}</a>
   </font>}
     end
     def concordance_link(text)
       if @md.concord_make
   %{<font size=2>
-    <a href="#{@md.fn[:concordance]}" target="_top" #{@vz.js_concordance}>
+    <a href="#{@md.file.base_filename.html_concordance}" target="_top" #{@vz.js_concordance}>
       #{text}
     </a>
   </font>}
       else ''
       end
     end
-    def make_seg_scroll_pdf
-      wgt=Widget.new(@md)
+    def make_scroll_search_form_and_manifest_link
+      wgt=SiSU_HTML_Format::Widget.new(@md)
       scroll=%{<td align="center" bgcolor=#{@vz.color_band2}>
   #{@vz.nav_txt_doc_link}
 </td>
@@ -363,7 +403,7 @@ WOK
     end
     def make_scroll_seg_pdf
       manifest=scroll=seg=''
-      wgt=Widget.new(@md)
+      wgt=SiSU_HTML_Format::Widget.new(@md)
       seg=%{<td align="center" bgcolor=#{@vz.color_band2}>
   #{@vz.nav_txt_toc_link}
 </td>
@@ -377,7 +417,7 @@ WOK
     end
     def make_concordance
       manifest=scroll=seg=''
-      wgt=Widget.new(@md)
+      wgt=SiSU_HTML_Format::Widget.new(@md)
       %{<table summary="toc scroll and segment with pdf" border="0" cellpadding="3" cellspacing="0">
 <tr>
 <td align="center" bgcolor=#{@vz.color_band2}>
@@ -386,7 +426,7 @@ WOK
 </tr></table>}
     end
     def head
-      rdf=SiSU_XML_tags::RDF.new(@md)
+      rdf=SiSU_XML_Tags::RDF.new(@md)
       %{#{doc_type}
 <head>
   <title>
@@ -394,7 +434,7 @@ WOK
   </title>
 <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
 #{rdf.metatag_html}
-#{@css.html}#{@css.html_seg}
+#{@stylesheet.css_head}
 </head>
 #{@vz.color_body}
 <a name="top" id="top"></a>
@@ -406,7 +446,7 @@ WOK
       if @md.concord_make
       %{#{@vz.margin_css}
   <h4 class="toc">
-    <a href="./#{@md.fn[:concordance]}" #{@vz.js_concordance}>
+    <a href="./#{@md.file.base_filename.html_concordance}" #{@vz.js_concordance}>
       <i>Concordance</i>
     </a>
   </h4>
@@ -417,7 +457,7 @@ WOK
       end
     end
     def links_guide_vertical_open
-#     @file=SiSU_Env::SiSU_file.new(@md) if @md
+#     @file=SiSU_Env::FileOp.new(@md) if @md
       url=((defined? @vz.url_hp) && @vz.url_hp =~/^https?:\/\/\S+$/ ? @vz.url_hp : @vz.url_home)
       %{
 <div id="vertical_links">
@@ -431,14 +471,14 @@ WOK
      Quick Ref.:
   </li>
   <li class="ref">
-    <a href="#{@md.fn[:manifest]}" alt="Document Manifest" target="_top">
+    <a href="#{@md.file.base_filename.manifest}" alt="Document Manifest" target="_top">
       Manifest
     </a>
   </li>
 <!- quick ref -!>}
     end
     def links_guide_horizontal_open
-#     @file=SiSU_Env::SiSU_file.new(@md) if @md
+#     @file=SiSU_Env::FileOp.new(@md) if @md
       url=((defined? @vz.url_hp) && @vz.url_hp =~/^https?:\/\/\S+$/ ? @vz.url_hp : @vz.url_home)
       %{
 <div id="horizontal_links">
@@ -452,7 +492,7 @@ WOK
      Quick Ref.:
   </li>
   <li class="ref">
-    <a href="#{@md.fn[:manifest]}" alt="Document Manifest" target="_top">
+    <a href="#{@md.file.base_filename.manifest}" alt="Document Manifest" target="_top">
       Manifest
     </a>
   </li>
@@ -529,12 +569,15 @@ WOK
 #{@vz.table_close}}
     end
     def manifest #check structure
-      manifest=manifest_link(@vz.nav_txt_manifest)
-      %{#{@vz.margin_txt_3}
+      if not @o_str.dump_or_redirect?
+        manifest=manifest_link(@vz.nav_txt_manifest)
+        %{#{@vz.margin_txt_3}
   #{@vz.paragraph_font_small}
    #{manifest}
     </font>
 #{@vz.table_close}}
+      else ''
+      end
     end
     def concordance #check structure
       concord=concordance_link(@vz.nav_txt_concordance)
@@ -553,10 +596,6 @@ WOK
   </h4>
 #{@vz.table_close}}
     end
-    def seg_metadata
-      @metalink=%{./#{@md.fn[:metadata]}}
-      metadata
-    end
     def seg_tail
       %{
 <div class="main_column">
@@ -621,101 +660,83 @@ WOK
 }
     end
   end
-  class Head_seg < Head_information
-    def initialize(md) #(md='')
+  class HeadSeg < HeadInformation
+    def initialize(md)
       super(md)
     end
-    def head
-      rdf=SiSU_XML_tags::RDF.new(@md)
-      %{#{doc_type}
-<head>
-  <title>
-    #{@seg_name_html[@seg_name_html_tracker]} -
-    #{@md.html_title}
-  </title>
-<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
-#{rdf.metatag_html}
-#{@vz.font_css_table_file}
-</head>
-#{@vz.color_body}
-<a name="top" id="top"></a>
-<a name="up" id="up"></a>
-<a name="start" id="start"></a>
-#{@vz.js_top}}
-    end
     def title_banner(title,subtitle,creator)
     end
     def dot_control_pre_next
       pre="#{@seg_name_html[@seg_name_html_tracker-1]}#{@md.lang_code_insert}#{Sfx[:html]}"
-      up="#{@toc}#{@md.lang_code_insert}#{Sfx[:html]}"
+      up=@toc
       nxt="#{@seg_name_html[@seg_name_html_tracker+1]}#{@md.lang_code_insert}#{Sfx[:html]}"
       if nxt=~/sisu_manifest\.html/
-        @file=SiSU_Env::SiSU_file.new(@md) if @md
+        @file=SiSU_Env::FileOp.new(@md) if @md
         if @file.output_dir_structure.by_language_code? \
         or @file.output_dir_structure.by_filetype?
-          nxt.gsub!(/sisu_manifest\.html/,"../../manifest/#{@file.base_filename.manifest}")
+          nxt=nxt.gsub(/sisu_manifest\.html/,"../../manifest/#{@file.base_filename.manifest}")
         end
       end
       %{<table summary="segment hidden control pre and next" width="100%" border="0" cellpadding="0" bgcolor=#{@vz.color_grey_pale} align="center">
 <tr><td align="left">
   <a href="#{pre}" target="_top" #{@vz.js_prev}>
-    #{@vz.png_nav_dot_pre}
+    #{png_nav.dot_pre}
   </a>
 </td>
 <td align="center">
   <a href="#{up}" target="_top" #{@vz.js_toc}>
-    #{@vz.png_nav_dot_toc}
+    #{png_nav.dot_toc}
   </a>
 </td>
 <td align="right">
   <a href="#{nxt}" target="_top" #{@vz.js_next}>
-    #{@vz.png_nav_dot_nxt}
+    #{png_nav.dot_nxt}
   </a>
 #{@vz.table_close}}
     end
     def dot_control_pre
       pre="#{@seg_name_html[@seg_name_html_tracker-2]}#{@md.lang_code_insert}#{Sfx[:html]}"
-      up="#{@toc}#{@md.lang_code_insert}#{Sfx[:html]}"
-      nxt="#{@md.fn[:toc]}"
+      up=@toc
+      nxt="#{@md.file.base_filename.html_segtoc}"
       %{<table summary="segment hidden control pre" width="100%" border="0" cellpadding="0" bgcolor=#{@vz.color_grey_pale} align="center">
 <tr><td align="left">
   <a href="#{pre}" target="_top" #{@vz.js_prev}>
-    #{@vz.png_nav_dot_pre}
+    #{png_nav.dot_pre}
   </a>
 </td>
 <td align="center">
   <a href="#{up}" target="_top" #{@vz.js_toc}>
-    #{@vz.png_nav_dot_toc}
+    #{png_nav.dot_toc}
   </a>
 </td>
 <td align="right">
   <a href="#{nxt}" target="_top" #{@vz.js_next}>
-    #{@vz.png_nav_dot_nxt}
+    #{png_nav.dot_nxt}
   </a>
 #{@vz.table_close}}
     end
     def toc_nav(f_pre=false,f_nxt=false,use=1)
       pre=nxt=''
       toc=%{<td align="center" bgcolor=#{@vz.color_band1}>
-  <a href="#{@toc}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top" #{@vz.js_toc}>
-    #{@vz.png_nav_toc}
+  <a href="#{@toc}" target="_top" #{@vz.js_toc}>
+    #{png_nav.toc}
   </a>
 </td>}
       pre=%{<td align="center" bgcolor=#{@vz.color_band1}>
   <a href="#{@seg_name_html[@seg_name_html_tracker-use]}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top" #{@vz.js_prev}>
-    #{@vz.png_nav_pre}
+    #{png_nav.pre}
   </a>
 </td>} if f_pre==true
       nxt=%{<td align="center" bgcolor=#{@vz.color_band1}>
   <a href="#{@seg_name_html[@seg_name_html_tracker+1]}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top" #{@vz.js_next}>
-    #{@vz.png_nav_nxt}
+    #{png_nav.nxt}
   </a>
 </td>} if f_nxt==true
       if nxt =~/sisu_manifest.html/
-        @file=SiSU_Env::SiSU_file.new(@md) if @md
+        @file=SiSU_Env::FileOp.new(@md) if @md
         if @file.output_dir_structure.by_language_code? \
         or @file.output_dir_structure.by_filetype?
-          nxt.gsub!(/sisu_manifest\.html/,"../../manifest/#{@file.base_filename.manifest}")
+          nxt=nxt.gsub(/sisu_manifest\.html/,"../../manifest/#{@file.base_filename.manifest}")
         end
       end
       %{<table summary="segment navigation pre/next" border="0" cellpadding="3" cellspacing="0">
@@ -738,7 +759,7 @@ WOK
     end
     def manifest_link(text)
   %{<font size=2>
-    <a href="#{@md.fn[:manifest]}" target="_top" #{@vz.js_manifest}>
+    <a href="#{@md.file.base_filename.manifest}" target="_top" #{@vz.js_manifest}>
       #{text}
     </a>
   </font>}
@@ -746,7 +767,7 @@ WOK
     def concordance_link(text)
       if @md.concord_make
   %{<font size=2>
-    <a href="#{@md.fn[:concordance]}" target="_top" #{@vz.js_concordance}>
+    <a href="#{@md.file.base_filename.html_concordance}" target="_top" #{@vz.js_concordance}>
       #{text}
     </a>
   </font>}
@@ -771,7 +792,7 @@ WOK
   <font size="2">}
     end
     def heading_advert_local_1
-      dir=SiSU_Env::Info_env.new(@fns)
+      dir=SiSU_Env::InfoEnv.new(@fns)
       %{  <center>
 <table summary="image" border="0" cellpadding="3" cellspacing="0" align="center">
 <tr><td align="center" bgcolor="white">
@@ -783,7 +804,7 @@ WOK
 </center>}
     end
     def heading_advert_local_2
-      dir=SiSU_Env::Info_env.new(@fns)
+      dir=SiSU_Env::InfoEnv.new(@fns)
       %{  <center>
 <table summary="image" border="0" cellpadding="3" cellspacing="0" align="center">
 <tr><td align="center" bgcolor="white">
@@ -795,7 +816,7 @@ WOK
 </center>}
     end
     def heading_advert_external
-      dir=SiSU_Env::Info_env.new(@fns)
+      dir=SiSU_Env::InfoEnv.new(@fns)
       %{  <center>
 <table summary="image" border="0" cellpadding="3" cellspacing="0" align="center">
 <tr><td align="center" bgcolor="white">
@@ -864,27 +885,9 @@ WOK
 %{
 </div>
 } #revisit
-    end
-    def head
-      rdf=SiSU_XML_tags::RDF.new(@md)
-      %{#{doc_type}
-<head>
-  <title>
-    #{@seg_name_html[@seg_name_html_tracker]} -
-    #{@md.html_title}
-  </title>
-<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
-#{rdf.metatag_html}
-#{@css.html}
-</head>
-#{@vz.color_body}
-<a name="top" id="top"></a>
-<a name="up" id="up"></a>
-<a name="start" id="start"></a>
-#{@vz.js_top}}
     end
     def head_seg
-      rdf=SiSU_XML_tags::RDF.new(@md)
+      rdf=SiSU_XML_Tags::RDF.new(@md)
       %{#{doc_type}
 <head>
   <title>
@@ -893,7 +896,7 @@ WOK
   </title>
 <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
 #{rdf.metatag_html}
-#{@css.html_seg}
+#{@stylesheet.css_head_seg}
 </head>
 #{@vz.color_body}
 <a name="top" id="top"></a>
@@ -901,10 +904,6 @@ WOK
 <a name="start" id="start"></a>
 #{@vz.js_top}}
     end
-    def toc_metadata
-      @metalink=%{./#{@md.fn[:meatadata]}}
-      toc_metadata
-    end
     def title_banner(title,subtitle,creator)
       %{
 <div class="summary">
@@ -927,7 +926,7 @@ WOK
 }
     end
   end
-  class Head_scroll < Head_toc
+  class HeadScroll < HeadToc
     def initialize(md)
       super(md)
     end
@@ -944,8 +943,8 @@ WOK
 #{@vz.table_close}}
     end
   end
-  class Format_text_object
-    @vz=SiSU_Env::Get_init.instance.skin
+  class FormatTextObject
+    @vz=SiSU_Env::GetInit.instance.skin
     attr_accessor :md,:t_o,:txt,:ocn,:format,:table,:link,:linkname,:paranum,:p_num,:headname,:banner,:url
     def initialize(md,t_o)
       @md,@t_o=md,t_o
@@ -960,12 +959,12 @@ WOK
         @lnk_url        =t_o[:lnk_url]        || nil
         @lnk_txt        =t_o[:lnk_txt]        || nil
         @format         =t_o[:format]         || nil
-      elsif t_o.class.inspect =~/^(?:#<)?SiSU_document_structure/
+      elsif t_o.class.inspect =~/^(?:#<)?SiSU_DAL_DocumentStructure/
         @dob=t_o if defined? t_o.is
         @named=nametags_seg(@dob)
         @txt=((defined? t_o.obj) ? t_o.obj : nil)
         @ocn=((defined? t_o.ocn) ? t_o.ocn.to_s : nil)
-        @headname=((t_o.is=='heading' and defined? t_o.name) ? t_o.name : nil)
+        @headname=((t_o.is==:heading and defined? t_o.name) ? t_o.name : nil)
       else
         if @md.opt.cmd =~/M/
           p t_o.class
@@ -974,10 +973,11 @@ WOK
       end
       @headnamed= (@headname ? %{<a name="h#{@headname}" id="h#{@headname}"></a>} : nil)
       if @txt and not @txt.empty?
-        @txt.gsub!(/#{Mx[:mk_o]}[-~]##{Mx[:mk_c]}/,'')
+        @txt=@txt.gsub(/#{Mx[:mk_o]}[-~]##{Mx[:mk_c]}/,'')
       end
-      @p_num=Paragraph_number.new(@md,@ocn)
-      @vz=SiSU_Env::Get_init.instance.skin
+      @p_num=ParagraphNumber.new(@md,@ocn)
+      @vz=SiSU_Env::GetInit.instance.skin
+      @make=SiSU_Env::ProcessingSettings.new(@md)
     end
     def nametags_scroll(dob)
       tags=''
@@ -1000,9 +1000,9 @@ WOK
       tags
     end
     def headname #check whether used
-      hn=if @t_o.is =='heading' \
+      hn=if @t_o.is ==:heading \
       and not @t_o.name.empty? #determine use
-        hn=if @t_o.is =='heading'; %{<a name="h#{@t_o.name}" id="h#{@t_o.name}"></a>}
+        hn=if @t_o.is ==:heading; %{<a name="h#{@t_o.name}" id="h#{@t_o.name}"></a>}
         else %{<a name="#{@t_o.name}" id="#{@t_o.name}"></a>}
         end
       else nil
@@ -1074,15 +1074,15 @@ WOK
     end
     def table
       @txt=if @t_o.obj !~/^<table\s/
-        table=SiSU_HTML_shared::Table_html.new(@t_o) #move, make happen earlier
+        table=SiSU_HTML_Shared::TableHTML.new(@t_o) #move, make happen earlier
         @txt=table.table.obj
       else @txt
       end
       para_form_css('p','norm')
     end
     def break
-      @txt.gsub!(/#{Mx[:br_page_new]}|#{Mx[:br_page]}/,'<hr /><br />')
-      @txt.gsub!(/#{Mx[:br_obj]}/,'<hr style="width:30%" /><br />')
+      @txt=@txt.gsub(/#{Mx[:br_page_new]}|#{Mx[:br_page]}/,'<hr /><br />').
+        gsub(/#{Mx[:br_obj]}/,'<hr style="width:30%" /><br />')
       para_form_css('p','norm')
     end
     def format(tag,attrib)
@@ -1120,8 +1120,11 @@ WOK
       heading_normal('h6','norm')
     end
     def title_heading(tag,attrib)
+      cl=(@make.build.html_minitoc?) \
+      ? 'content'
+      : 'content0'
       %{
-<div class="content">
+<div class="#{cl}">
 <#{tag} class="#{attrib}">
     #{@named}#{@txt}
   </#{tag}>
@@ -1141,7 +1144,7 @@ WOK
       ''
     end
     def seg_heading_sub(tag,attrib)
-      @txt.gsub!(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
+      @txt=@txt.gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
       %{
 <div class="substance">
   #{@p_num.ocn_display}
@@ -1176,15 +1179,16 @@ WOK
   </div>'
     end
     def gsub_body #fix
-      case @txt
+      @txt=case @txt
       when /^\((i+|iv|v|vi+|ix|x|xi+)\)/
-        @txt.gsub!(/^\((i+|iv|v|vi+|ix|x|xi+)\)/,'<b>(\1)</b>')
+        @txt.gsub(/^\((i+|iv|v|vi+|ix|x|xi+)\)/,'<b>(\1)</b>')
       when /^\(?(\d|[a-z])+\)/
-        @txt.gsub!(/^\((\d+|[a-z])+\)/,'<b>(\1)</b>')
+        @txt.gsub(/^\((\d+|[a-z])+\)/,'<b>(\1)</b>')
       when /^\s*\d{1,3}\.\s/
-        @txt.gsub!(/^\s*(\d+\.)/,'<b>\1</b>')
+        @txt.gsub(/^\s*(\d+\.)/,'<b>\1</b>')
       when /^\s*[A-Z]\.\s/
-        @txt.gsub!(/^\s*([A-Z]\.)/,'<b>\1</b>')
+        @txt.gsub(/^\s*([A-Z]\.)/,'<b>\1</b>')
+      else @txt
       end
     end
     def bold_para
@@ -1197,8 +1201,8 @@ WOK
 #{@vz.table_close}}
     end
     def bold_heading
-      @txt.gsub!(/[1-9]~(\S+)/,'<a name="\1"></a>')
-      @txt.gsub!(/[1-9]~/,'')
+      @txt=@txt.gsub(/[1-9]~(\S+)/,'<a name="\1"></a>').
+        gsub(/[1-9]~/,'')
       %{<p class="bold">
     #{@txt}
   </p>
@@ -1219,13 +1223,13 @@ WOK
       %{<p class="centerbold">#{@txt}</p>\n}
     end
   end
-  class Format_scroll < Format_text_object
+  class FormatScroll < FormatTextObject
     def initialize(md,txt)
       super(md,txt)
-      @vz=SiSU_Env::Get_init.instance.skin
+      @vz=SiSU_Env::GetInit.instance.skin
     end
   end
-  class Format_seg < Format_text_object
+  class FormatSeg < FormatTextObject
     def initialize(md,txt)
       super(md,txt)
     end
@@ -1286,8 +1290,8 @@ WOK
 }
     end
     def clean(txt)
-      txt.gsub!(/#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}/,'')
-      txt.gsub!(/#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]}/,'')
+      txt=txt.gsub(/#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}/,'').
+        gsub(/#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]}/,'')
       txt
     end
     def subtoc_lev(tag,attrib)
@@ -1300,9 +1304,9 @@ WOK
       note=''
       if txt =~/(#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})/m # had \s* at end
         note=$1
-        note.gsub!(/[\n\s]+/m,' ')
-        txt.gsub!(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
-        txt.gsub!(/<a[\n\s]+name="-\d+"[\n\s]+href="#_\d+">&nbsp;<sup>\d+<\/sup>&nbsp;/m,'')
+        note=note.gsub(/[\n\s]+/m,' ')
+        txt=txt.gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ').
+          gsub(/<a[\n\s]+name="-\d+"[\n\s]+href="#_\d+">&nbsp;<sup>\d+<\/sup>&nbsp;/m,'')
       end
       %{<#{tag} class="#{attrib}">
     <a href="##{@ocn}"><i>#{txt}</i></a> #{note}
@@ -1315,7 +1319,7 @@ WOK
       subtoc_lev('h6','subtoc') if @txt
     end
     def heading_sub(tag,attrib)
-      @txt.gsub!(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
+      @txt=@txt.gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
       %{
 <div class="substance">
   #{@p_num.ocn_display}
@@ -1364,7 +1368,7 @@ WOK
       "<center>#{@txt}</center>"
     end
   end
-  class Format_toc < Format_text_object
+  class FormatToc < FormatTextObject
     def initialize(md,txt)
       super(md,txt)
     end
@@ -1407,7 +1411,7 @@ WOK
       lev('h0','toc')
     end
     def strip_endnotes(txt)
-      txt.gsub!(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
+      txt=txt.gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
       txt
     end
     def mini_lev1
@@ -1455,7 +1459,7 @@ WOK
 }
     end
   end
-  class Format_str
+  class FormatStr
     def initialize(md,str)
       @str=str
     end
