@@ -64,7 +64,7 @@ module SiSU_Manpage
   include SiSU_Param
   include SiSU_Viz
   require_relative 'manpage_format'                     # manpage_format.rb
-    include SiSU_Manpage_format
+    include SiSU_ManpageFormat
   require_relative 'shared_metadata'                    # shared_metadata.rb
   require_relative 'shared_txt'                         # shared_txt.rb
   pwd=Dir.pwd
@@ -81,7 +81,7 @@ module SiSU_Manpage
     def read
       begin
         @md=SiSU_Param::Parameters.new(@opt).get
-        @env=SiSU_Env::Info_env.new(@opt.fns)
+        @env=SiSU_Env::InfoEnv.new(@opt.fns)
         path=@env.path.output_tell
         tool=(@opt.cmd =~/[MVv]/) \
         ?  "#{@env.program.text_editor} #{@md.file.output_path.manpage.dir}/#{@md.file.base_filename.manpage}"
@@ -93,8 +93,8 @@ module SiSU_Manpage
         SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@md.file.output_path.manpage.dir}/#{@md.file.base_filename.manpage}").flow if @opt.cmd =~/[MV]/
         @dal_array=SiSU_DAL::Source.new(@opt).get # dal file drawn here
         SiSU_Manpage::Source::Scroll.new(@md,@dal_array).songsheet
-        SiSU_Env::Info_skin.new(@md).select #watch
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+        SiSU_Env::InfoSkin.new(@md).select #watch
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
       end
     end
@@ -102,12 +102,12 @@ module SiSU_Manpage
     class Scroll <Source
       require_relative 'defaults'                       # defaults.rb
       require_relative 'shared_txt'                     # shared_txt.rb
-        include SiSU_text_utils
+        include SiSU_TextUtils
       @@endnotes={ para: [], end: [] }
       def initialize(md,data)
         @md,@data=md,data
         @brace_url=SiSU_Viz::Skin.new.url_decoration
-        @vz=SiSU_Env::Get_init.instance.skin
+        @vz=SiSU_Env::GetInit.instance.skin
         @tab="\t"
         @br="\n"
         @@dostype='unix endnotes'
@@ -134,21 +134,21 @@ module SiSU_Manpage
         end
         notes=@n.flatten
         notes.each do |e|
-          util=if e.to_s =~/^\[[\d*+]+\]:/; SiSU_text_utils::Wrap.new(e.to_s,78,4,1)
-          else                              SiSU_text_utils::Wrap.new(e.to_s,78,0,1)
+          util=if e.to_s =~/^\[[\d*+]+\]:/; SiSU_TextUtils::Wrap.new(e.to_s,78,4,1)
+          else                              SiSU_TextUtils::Wrap.new(e.to_s,78,0,1)
           end
           wrap=util.line_wrap
-          if wrap =~ /^\s*[\d*+]+\s+.+?\s*\Z/m
-            wrap.gsub!(/(^|&nbsp;|#{Mx[:nbsp]}|\s|\*)\\\*/,'\1\\\\\*') #man page requires
-            wrap.gsub!(/\s\.(\S+)/,' \\.\1')
-            wrap.gsub!(/^\s*([\d*+]+)\s+(.+?)\s*\Z/m, <<GSUB
+          wrap=if wrap =~ /^\s*[\d*+]+\s+.+?\s*\Z/m
+            wrap.gsub(/(^|&nbsp;|#{Mx[:nbsp]}|\s|\*)\\\*/,'\1\\\\\*'). #man page requires
+              gsub(/\s\.(\S+)/,' \\.\1').
+              gsub(/^\s*([\d*+]+)\s+(.+?)\s*\Z/m, <<GSUB
 .TP
 .BI \\1.
 \\2
 GSUB
                       )
           else
-            wrap.gsub!(/^\s*(.+)\Z/m, <<GSUB
+            wrap.gsub(/^\s*(.+)\Z/m, <<GSUB
 \\1
 GSUB
                       )
@@ -159,11 +159,11 @@ GSUB
         end
       end
       def manpage_metadata
-        @manpage[:metadata]=Metadata::Summary.new(@md).manpage.metadata
+        @manpage[:metadata]=SiSU_Metadata::Summary.new(@md).manpage.metadata
       end
       def manpage_tail
-        SiSU_Env::Info_skin.new(@md).select
-        vz=SiSU_Env::Get_init.instance.skin
+        SiSU_Env::InfoSkin.new(@md).select
+        vz=SiSU_Env::GetInit.instance.skin
         generator="Generated by: #{@md.sisu_version[:project]} #{@md.sisu_version[:version]} of #{@md.sisu_version[:date_stamp]} (#{@md.sisu_version[:date]})"  if @md.sisu_version[:version]
         lastdone="Last Generated on: #{Time.now}"
         rubyv="Ruby version: #{@md.ruby_version}"
@@ -176,7 +176,7 @@ GSUB
 .TP
 Other versions of this document:
 .TP
-manifest: <#{vz.url_root_http}/#{@md.fnb}/#{@md.fn[:manifest]}>
+  manifest: <#{@md.file.output_path.digest.url}/#{@md.file.base_filename.digest}>
 .TP
 at: <#{vz.url_site}>
 .TP
@@ -192,35 +192,35 @@ at: <#{vz.url_site}>
 WOK
       end
       def manpage_structure(dob='',hname='') #% Used to extract the structure of a document
-        if dob.is=='heading'
+        if dob.is==:heading
           lv=dob.ln
           n=dob.ln - 1
           n3=dob.ln + 2
         else lv=nil
         end
-        wrapped=if dob.is=='para' \
-        or dob.is=='heading'
+        wrapped=if dob.is==:para \
+        || dob.is==:heading
           paragraph=dob.obj
-          if dob.is=='para'
+          if dob.is==:para
             if dob.indent =~/[1-9]/ \
             and dob.indent == dob.hang
               util=if dob.bullet_
-                SiSU_text_utils::Wrap.new("* #{paragraph}",78,dob.indent.to_i*2)
-              else SiSU_text_utils::Wrap.new(paragraph,78,dob.indent.to_i*2)
+                SiSU_TextUtils::Wrap.new("* #{paragraph}",78,dob.indent.to_i*2)
+              else SiSU_TextUtils::Wrap.new(paragraph,78,dob.indent.to_i*2)
               end
             elsif dob.hang =~/[0-9]/ \
             and dob.indent != dob.hang                     # NOT yet implemented
-              util=SiSU_text_utils::Wrap.new(paragraph,78,dob.indent.to_i*2)
+              util=SiSU_TextUtils::Wrap.new(paragraph,78,dob.indent.to_i*2)
             else
               util=if dob.bullet_
-                SiSU_text_utils::Wrap.new("* #{paragraph}",78,0)
-              else SiSU_text_utils::Wrap.new(paragraph,78,0)
+                SiSU_TextUtils::Wrap.new("* #{paragraph}",78,0)
+              else SiSU_TextUtils::Wrap.new(paragraph,78,0)
               end
             end
-          else util=SiSU_text_utils::Wrap.new(paragraph,78,0)
+          else util=SiSU_TextUtils::Wrap.new(paragraph,78,0)
           end
           w=util.line_wrap
-          w.gsub!(/^(\\\.)/,' \1')
+          w=w.gsub(/^(\\\.)/,' \1')
           w
         end
         if lv
@@ -234,7 +234,7 @@ WOK
           end
         else
           @manpage[:body] << if  wrapped =~/^\.BI\s/ # main text, contents, body KEEP
-            '.TP' << @br << wrapped.gsub!(/^\.BI\s/,'.B ') # sleight ... simpler output
+            '.TP' << @br << wrapped.gsub(/^\.BI\s/,'.B ') # sleight ... simpler output (check gsub!)
           else
             '.br' << @br << wrapped
           end
@@ -250,7 +250,7 @@ WOK
         @@endnotes[:para]=[]
       end
       def markup(data)                                                       # Used for major markup instructions
-        dir=SiSU_Env::Info_env.new(@md.fns)
+        dir=SiSU_Env::InfoEnv.new(@md.fns)
         @data_mod,@endnotes,@level,@cont,@copen,@manpage_contents_close=Array.new(6){[]}
         (0..6).each { |x| @cont[x]=@level[x]=false }
         (4..6).each { |x| @manpage_contents_close[x]='' }
@@ -259,88 +259,88 @@ WOK
         fix=[]
         manpage_metadata
         data.each do |dob|
-          if dob.is=='comment' \
-          or dob.is=='heading_insert'
+          if dob.is==:comment \
+          || dob.is==:heading_insert
             dob.obj=''
           end
-          dob.obj.gsub!(/.+?<-#>/,'')                                           # remove dummy headings (used by html) #check
-          dob.obj.gsub!(/#{Mx[:fa_superscript_o]}(.+?)#{Mx[:fa_superscript_c]}/,'^\1^')
-          dob.obj.gsub!(/#{Mx[:fa_subscript_o]}(.+?)#{Mx[:fa_subscript_c]}/,'[\1]')
-          dob.obj.gsub!(/#{Mx[:fa_insert_o]}(.+?)#{Mx[:fa_insert_c]}/,'++\1++')
-          dob.obj.gsub!(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,'--\1--')
-          dob.obj.gsub!(/#{Mx[:fa_cite_o]}(.+?)#{Mx[:fa_cite_c]}/,'"\1"')
-          dob.obj.gsub!(/#{Mx[:fa_monospace_o]}(.+?)#{Mx[:fa_monospace_c]}/,'\1')
-          dob.obj.gsub!(/\A\s*#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}#{Mx[:br_line]}([,.:!?](?: |$))?/m,"#{Mx[:br_line]}.I \\1\\2#{Mx[:br_line]}")
-          dob.obj.gsub!(/\s*#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}([,.:!?](?: |$))?/m,"#{Mx[:br_line]}.I \\1\\2#{Mx[:br_line]}")
-          dob.obj.gsub!(/\A\s*#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}([,.:!?](?: |$))?#{Mx[:br_line]}/m,"#{Mx[:br_line]}.BI \\1\\2#{Mx[:br_line]}")
-          dob.obj.gsub!(/\s*#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}([,.:!?](?: |$))?/,"#{Mx[:br_line]}.B \\1\\2#{Mx[:br_line]}")
-          dob.obj.gsub!(/\s*#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}([,.:!?](?: |$))?/,"#{Mx[:br_line]}.I \\1\\2#{Mx[:br_line]}")
-          unless dob.is=='code'
-            dob.obj.gsub!(/(?:^|\s)#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}([,.:!?](?: |$))?/,"\\1 #{@brace_url.txt_open}\\2#{@brace_url.txt_close}\\3")
-            dob.obj.gsub!(/(^|#{Mx[:gl_c]}|\s)#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}([,.:!?](?: |$))?/,"\\1#{@brace_url.txt_open}\\2#{@brace_url.txt_close}\\3")
+          dob.obj=dob.obj.gsub(/.+?<-#>/,'').                                           # remove dummy headings (used by html) #check
+            gsub(/#{Mx[:fa_superscript_o]}(.+?)#{Mx[:fa_superscript_c]}/,'^\1^').
+            gsub(/#{Mx[:fa_subscript_o]}(.+?)#{Mx[:fa_subscript_c]}/,'[\1]').
+            gsub(/#{Mx[:fa_insert_o]}(.+?)#{Mx[:fa_insert_c]}/,'++\1++').
+            gsub(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,'--\1--').
+            gsub(/#{Mx[:fa_cite_o]}(.+?)#{Mx[:fa_cite_c]}/,'"\1"').
+            gsub(/#{Mx[:fa_monospace_o]}(.+?)#{Mx[:fa_monospace_c]}/,'\1').
+            gsub(/\A\s*#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}#{Mx[:br_line]}([,.:!?](?: |$))?/m,"#{Mx[:br_line]}.I \\1\\2#{Mx[:br_line]}").
+            gsub(/\s*#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}([,.:!?](?: |$))?/m,"#{Mx[:br_line]}.I \\1\\2#{Mx[:br_line]}").
+            gsub(/\A\s*#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}([,.:!?](?: |$))?#{Mx[:br_line]}/m,"#{Mx[:br_line]}.BI \\1\\2#{Mx[:br_line]}").
+            gsub(/\s*#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}([,.:!?](?: |$))?/,"#{Mx[:br_line]}.B \\1\\2#{Mx[:br_line]}").
+            gsub(/\s*#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}([,.:!?](?: |$))?/,"#{Mx[:br_line]}.I \\1\\2#{Mx[:br_line]}")
+          unless dob.is==:code
+            dob.obj=dob.obj.gsub(/(?:^|\s)#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}([,.:!?](?: |$))?/,"\\1 #{@brace_url.txt_open}\\2#{@brace_url.txt_close}\\3").
+              gsub(/(^|#{Mx[:gl_c]}|\s)#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}([,.:!?](?: |$))?/,"\\1#{@brace_url.txt_open}\\2#{@brace_url.txt_close}\\3")
             @manpage[:endnotes]=extract_endnotes(dob.obj)
-            dob.obj.gsub!(/#{Mx[:en_a_o]}([\d*+]+)\s*(?:.+?)#{Mx[:en_a_c]}/m,'[^\1]') # endnote marker marked up
-            dob.obj.gsub!(/#{Mx[:en_b_o]}([\d*+]+)\s*(?:.+?)#{Mx[:en_b_c]}/m,'[^\1]') # endnote marker marked up
-            dob.obj.gsub!(/#{Mx[:gl_o]}#amp#{Mx[:gl_c]}/,'&') ##{Mx[:gl_o]}#095#{Mx[:gl_c]}
-            dob.obj.gsub!(/#{Mx[:gl_o]}#033#{Mx[:gl_c]}/,'!')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#035#{Mx[:gl_c]}/,'#')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#042#{Mx[:gl_c]}/,'*')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#045#{Mx[:gl_c]}/,'-')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#092#{Mx[:gl_c]}/,'\e')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#047#{Mx[:gl_c]}/,'/')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#095#{Mx[:gl_c]}/,'_')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#123#{Mx[:gl_c]}/,'{')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#125#{Mx[:gl_c]}/,'}')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#169#{Mx[:gl_c]}/,'©')
+            dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}([\d*+]+)\s*(?:.+?)#{Mx[:en_a_c]}/m,'[^\1]'). # endnote marker marked up
+              gsub(/#{Mx[:en_b_o]}([\d*+]+)\s*(?:.+?)#{Mx[:en_b_c]}/m,'[^\1]'). # endnote marker marked up
+              gsub(/#{Mx[:gl_o]}#amp#{Mx[:gl_c]}/,'&'). ##{Mx[:gl_o]}#095#{Mx[:gl_c]}
+              gsub(/#{Mx[:gl_o]}#033#{Mx[:gl_c]}/,'!').
+              gsub(/#{Mx[:gl_o]}#035#{Mx[:gl_c]}/,'#').
+              gsub(/#{Mx[:gl_o]}#042#{Mx[:gl_c]}/,'*').
+              gsub(/#{Mx[:gl_o]}#045#{Mx[:gl_c]}/,'-').
+              gsub(/#{Mx[:gl_o]}#092#{Mx[:gl_c]}/,'\e').
+              gsub(/#{Mx[:gl_o]}#047#{Mx[:gl_c]}/,'/').
+              gsub(/#{Mx[:gl_o]}#095#{Mx[:gl_c]}/,'_').
+              gsub(/#{Mx[:gl_o]}#123#{Mx[:gl_c]}/,'{').
+              gsub(/#{Mx[:gl_o]}#125#{Mx[:gl_c]}/,'}').
+              gsub(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~').
+              gsub(/#{Mx[:gl_o]}#169#{Mx[:gl_c]}/,'©')
           else
-            dob.obj.gsub!(/\\/,'\e')
-            dob.obj.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})\s*/,"\n\n")                                   # watch
+            dob.obj=dob.obj.gsub(/\\/,'\e').
+              gsub(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})\s*/,"\n\n")                                   # watch
             #dob.obj.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})+\s*/,"\n")                                   # watch
           end
-          dob.obj.gsub!(/(^|&nbsp;|#{Mx[:nbsp]}|\s|\*)\\\*/,'\1\\\\\*') #man page requires
-          dob.obj.gsub!(/┆/,'|')
-          dob.obj.gsub!(/\s\.(\S+)/,' \\.\1')
-          dob.obj.gsub!(/(\n\.)(\S\S\S+)/m,'\1\\.\2')
-          dob.obj.gsub!(/-/,'\-') #manpages use this
-          dob.obj.gsub!(/&#126;/,'~') if dob.obj #manpages use this
+          dob.obj=dob.obj.gsub(/(^|&nbsp;|#{Mx[:nbsp]}|\s|\*)\\\*/,'\1\\\\\*'). #man page requires
+            gsub(/┆/,'|').
+            gsub(/\s\.(\S+)/,' \\.\1').
+            gsub(/(\n\.)(\S\S\S+)/m,'\1\\.\2').
+            gsub(/-/,'\-') #manpages use this
+          dob.obj=dob.obj.gsub(/&#126;/,'~') if dob.obj #manpages use this
           if dob.is =~/block|group|verse|alt|code/
-            if dob.is =='code'
-              dob.obj.gsub!(/(^|[^}])_([<>])/m,'\1\2') # _> _<
-              dob.obj.gsub!(/(^|[^}])_([<>])/m,'\1\2') # _<_<
-              dob.obj.gsub!(/\A(.+)?\Z/m,".nf\n\n\\1\n\n.fi")
+            if dob.is ==:code
+              dob.obj=dob.obj.gsub(/(^|[^}])_([<>])/m,'\1\2'). # _> _<
+                gsub(/(^|[^}])_([<>])/m,'\1\2'). # _<_<
+                gsub(/\A(.+)?\Z/m,".nf\n\n\\1\n\n.fi")
             end
           end
           #dob.obj.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})+\s*/m,"\n.br\n")                                   # watch
-          dob.obj.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})+\s*/m,"\n\n")                                   # watch
+          dob.obj=dob.obj.gsub(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})+\s*/m,"\n\n")                                   # watch
           blit=dob.obj.scan(/\[[^\]]+\]|[^\[]+/)
           blit_array=[]
           blit.each do |x|
-            if x =~/^\[/
-              x.gsub!(/\s+/,' \ ') #manpages use this
+            x=if x =~/^\[/
+              x.gsub(/\s+/,' \ ') #manpages use this
             else x
             end
             blit_array << x
           end
           dob.obj=blit_array.join
-          dob.obj.gsub!(/#{Mx[:gl_o]}:name#\S+?#{Mx[:gl_c]}/mi,'') #added
-          #dob.obj.gsub!(/\s\\\s+(#{Mx[:br_line]}|#{Mx[:br_nl]})/,'\1') #a messy solution
-          dob.obj.gsub!(/#{Mx[:br_page]}\s*|#{Mx[:br_page_new]}/,'')                                         # remove page breaks
-          dob.obj.gsub!(/(^|#{Mx[:gl_c]}|\s)#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'\1\2')
-          dob.obj.gsub!(/<a href=".+?">(.+?)<\/a>/m,'\1')
-          dob.obj.gsub!(/#{Mx[:mk_o]}name#\S+?#{Mx[:mk_c]}/,'')                                     # remove name links
-          dob.obj.gsub!(/&nbsp;|#{Mx[:nbsp]}/,' ')                                          # decide on
-          dob.obj.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}\s*(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}#{Mx[:url_o]}\S+?#{Mx[:url_c]}/,'    [ \1 ]') #"[ #{dir.url.images_local}\/\\1 ]")
-          dob.obj.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}\s*(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}image/,'    [ \1 ]') #"[ #{dir.url.images_local}\/\\1 ]")
-          dob.obj.gsub!(/^(?:^|[^_\\])#{Mx[:lnk_o]}\s*\S+?\.(?:png|jpg|gif)\s+.+?"(.*?)"\s*#{Mx[:lnk_c]}\S+/,'[image: "\1"]')
+          dob.obj=dob.obj.gsub(/#{Mx[:gl_o]}:name#\S+?#{Mx[:gl_c]}/mi,''). #added
+          #gsub(/\s\\\s+(#{Mx[:br_line]}|#{Mx[:br_nl]})/,'\1'). #a messy solution
+            gsub(/#{Mx[:br_page]}\s*|#{Mx[:br_page_new]}/,'').                                         # remove page breaks
+            gsub(/(^|#{Mx[:gl_c]}|\s)#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'\1\2').
+            gsub(/<a href=".+?">(.+?)<\/a>/m,'\1').
+            gsub(/#{Mx[:mk_o]}name#\S+?#{Mx[:mk_c]}/,'').                                     # remove name links
+            gsub(/&nbsp;|#{Mx[:nbsp]}/,' ').                                          # decide on
+            gsub(/(?:^|[^_\\])#{Mx[:lnk_o]}\s*(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}#{Mx[:url_o]}\S+?#{Mx[:url_c]}/,'    [ \1 ]'). #"[ #{dir.url.images_local}\/\\1 ]")
+            gsub(/(?:^|[^_\\])#{Mx[:lnk_o]}\s*(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}image/,'    [ \1 ]'). #"[ #{dir.url.images_local}\/\\1 ]")
+            gsub(/^(?:^|[^_\\])#{Mx[:lnk_o]}\s*\S+?\.(?:png|jpg|gif)\s+.+?"(.*?)"\s*#{Mx[:lnk_c]}\S+/,'[image: "\1"]')
           wordlist=dob.obj.scan(/\S+/)
           if dob.obj !~/(^#{Rx[:meta]}|#{Mx[:br_eof]}|#{Mx[:br_endnotes]})/
             if dob.obj =~@regx #/.+?<~\d+;\w\d+;\w\d+>.*/ #watch change
               paranum=dob.obj[@regx,3]
-              @p_num=SiSU_Manpage_format::Paragraph_number.new(paranum)
+              @p_num=SiSU_ManpageFormat::ParagraphNumber.new(paranum)
             end
-            x=SiSU_Manpage_format::Format_text_object.new(@md,dob)
-            if dob.is=='heading'
+            x=SiSU_ManpageFormat::FormatTextObject.new(@md,dob)
+            if dob.is==:heading
               manpage_structure(dob)
               dob.obj=case dob.ln
               when 1; x.heading_body1
@@ -350,7 +350,7 @@ WOK
               when 5; x.heading_body5
               when 6; x.heading_body6
               end
-            elsif dob.is=='para'
+            elsif dob.is==:para
               manpage_structure(dob)
             else
               if dob.obj =~/#{table_message}/
@@ -362,14 +362,14 @@ WOK
               dob.obj=''
             end
             if dob.obj
-              dob.obj.gsub!(/\s(\[)/m,' \ \1')
-              dob.obj.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})\s*/,"\n\n")                                   # watch
-              dob.obj.gsub!(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~')
-              dob.obj.gsub!(/#{Mx[:gl_o]}#123#{Mx[:gl_c]}/,'{')
-              dob.obj.gsub!(/#{Mx[:pa_o]}\S+#{Mx[:pa_c]}/,' ')
-              unless dob.is =='code'
-                dob.obj.gsub!(/<!.+!>/,' ')
-                dob.obj.gsub!(/<:\S+>/,' ')
+              dob.obj=dob.obj.gsub(/\s(\[)/m,' \ \1').
+                gsub(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})\s*/,"\n\n").                                   # watch
+                gsub(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~').
+                gsub(/#{Mx[:gl_o]}#123#{Mx[:gl_c]}/,'{').
+                gsub(/#{Mx[:pa_o]}\S+#{Mx[:pa_c]}/,' ')
+              unless dob.is ==:code
+                dob.obj=dob.obj.gsub(/<!.+!>/,' ').
+                  gsub(/<:\S+>/,' ')
               end
             end
             dob
@@ -386,11 +386,11 @@ WOK
         elsif defined? @md.date.published \
         and @md.date.published
           @md.date.published
-        else SiSU_Env::Info_date.new.year #date missing decide on action
+        else SiSU_Env::InfoDate.new.year #date missing decide on action
         end
         manpage_name,manpage_synopsis='',''
         manpg={}
-        proj=SiSU_Env::Info_version.instance.get_version
+        proj=SiSU_Env::InfoVersion.instance.get_version
         manpage[:open] = %{.TH "#{@md.fnb}" "#{@md.make.manpage['section']}" "#{date}" "#{proj[:version]}" "#{@md.title.main}"#{@md.make.manpage['name']}#{@md.make.manpage['synopsis']}}
         content << manpage[:open]
         content << manpage[:head]
@@ -409,14 +409,14 @@ WOK
         @md,@content=md,content
       end
       def manpage                                                            #%manpage output
-        SiSU_Env::SiSU_file.new(@md).mkdir
-        filename_manpage=SiSU_Env::SiSU_file.new(@md).write_file.manpage
+        SiSU_Env::FileOp.new(@md).mkdir
+        filename_manpage=SiSU_Env::FileOp.new(@md).write_file.manpage
         @sisu=[]
         @content.each do |para|                                                # this is a hack
           if para.class==Array \
           and para.length > 0
             para.each do |line|
-              line.gsub!(/\s+$/m,'')
+              line=line.gsub(/\s+$/m,'')
               filename_manpage.puts line           #unix manpage
             end
           else filename_manpage.puts para          #unix manpage # /^([*=-]|\.){5}/
