@@ -64,7 +64,7 @@ module SiSU_Particulars
   require_relative 'param'                              # param.rb
     include SiSU_Param
   require_relative 'dal'                                # dal.rb
-  class Combined_singleton
+  class CombinedSingleton
     include Singleton
     def get_all(opt)
       @opt=opt
@@ -132,23 +132,23 @@ module SiSU_Particulars
       begin
         @md=SiSU_Param::Parameters.new(@opt).get
         self
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       end
     end
     attr_accessor :opt,:env,:file
     def set_env
       begin
-        @env=SiSU_Env::Info_env.new(@opt.fns)
+        @env=SiSU_Env::InfoEnv.new(@opt.fns)
         self
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       end
     end
     def set_file
       begin
         set_md unless @md
-        @file=SiSU_Env::SiSU_file.new(@md)
+        @file=SiSU_Env::FileOp.new(@md)
         self
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       end
     end
     attr_accessor :opt,:dal_array
@@ -156,35 +156,35 @@ module SiSU_Particulars
       begin
         @dal_array=@dal_array=SiSU_DAL::Source.new(@md).get
         self
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       end
     end
     def set_sst_idx
       begin
         @sst_idx=SiSU_DAL::Source.new(@md).get_idx_sst
         self
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       end
     end
     def set_tex_idx
       begin
         @tex_idx=SiSU_DAL::Source.new(@md).get_idx_tex
         self
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       end
     end
     def set_html_idx
       begin
         @html_idx=SiSU_DAL::Source.new(@md).get_idx_html
         self
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       end
     end
     def set_xhtml_idx
       begin
         @xhtml_idx=SiSU_DAL::Source.new(@md).get_idx_xhtml
         self
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       end
     end
     attr_accessor :nametags_map
@@ -193,7 +193,7 @@ module SiSU_Particulars
         opt=@md ? @md : @opt
         @nametags_map=SiSU_DAL::Source.new(opt).get_map_nametags
         self
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       end
     end
     attr_accessor :ocn_htmlseg_map
@@ -201,7 +201,7 @@ module SiSU_Particulars
       begin
         @ocn_htmlseg_map=SiSU_DAL::Source.new(@md).get_map_ocn_htmlseg
         self
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       end
     end
   end
