@@ -62,7 +62,7 @@ module SiSU_Plaintext
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env
   require_relative 'plaintext_format'                   # plaintext_format.rb
-    include SiSU_Plaintext_format
+    include SiSU_PlaintextFormat
   require_relative 'shared_metadata'                    # shared_metadata.rb
   require_relative 'shared_txt'                         # shared_txt.rb
   include SiSU_Param
@@ -80,7 +80,7 @@ module SiSU_Plaintext
     def read
       begin
         md=SiSU_Param::Parameters.new(@opt).get
-        env=SiSU_Env::Info_env.new(@opt.fns)
+        env=SiSU_Env::InfoEnv.new(@opt.fns)
         unless @opt.cmd =~/q/
           path=env.path.output_tell
           tool=(@opt.cmd =~/[MVv]/) \
@@ -102,8 +102,8 @@ module SiSU_Plaintext
         end
         #wrap_width=(defined? md.make.plaintext_wrap) ? md.make.plaintext_wrap : 78
         SiSU_Plaintext::Source::Scroll.new(dal_array,md,wrap_width).songsheet
-        SiSU_Env::Info_skin.new(md).select #watch
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+        SiSU_Env::InfoSkin.new(md).select #watch
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
       end
     end
@@ -111,11 +111,11 @@ module SiSU_Plaintext
     class Scroll <Source
       require_relative 'defaults'                       # defaults.rb
       require_relative 'shared_txt'                     # shared_txt.rb
-      include SiSU_text_utils
+      include SiSU_TextUtils
       @@endnotes={ para: [], end: [] }
       def initialize(data,md,wrap_width)
         @data,@md,@wrap_width=data,md,wrap_width
-        @env=SiSU_Env::Info_env.new(@md.fns)
+        @env=SiSU_Env::InfoEnv.new(@md.fns)
         @brace_url=SiSU_Viz::Skin.new.url_decoration
         @tab="\t"
         @@endnotes_=case md.opt.mod.inspect
@@ -152,16 +152,16 @@ module SiSU_Plaintext
         notes=@n.flatten
         notes.each do |e|
           util=(e.to_s =~/^\[[\d*+]+\]:/) \
-          ? (SiSU_text_utils::Wrap.new(e.to_s,@wrap_width,4,1))
-          : (SiSU_text_utils::Wrap.new(e.to_s,@wrap_width,1,1))
+          ? (SiSU_TextUtils::Wrap.new(e.to_s,@wrap_width,4,1))
+          : (SiSU_TextUtils::Wrap.new(e.to_s,@wrap_width,1,1))
           wrap=util.line_wrap
-          if wrap =~ /^\s*[\d*+]+\s+.+?\s*\Z/m
-            wrap.gsub!(/^(\s*)([\d*+]+)\s+(.+?)\s*\Z/m, <<GSUB
+          wrap=if wrap =~ /^\s*[\d*+]+\s+.+?\s*\Z/m
+            wrap.gsub(/^(\s*)([\d*+]+)\s+(.+?)\s*\Z/m, <<GSUB
 \\1[\\2]: \\3
 GSUB
                       )
           else
-            wrap.gsub!(/^(.+)\Z/m, <<GSUB
+            wrap.gsub(/^(.+)\Z/m, <<GSUB
 \\1
 GSUB
                       )
@@ -172,11 +172,11 @@ GSUB
         @@endnotes
       end
       def plaintext_metadata
-        array=Metadata::Summary.new(@md).plaintext.metadata
+        array=SiSU_Metadata::Summary.new(@md).plaintext.metadata
         array.each do |meta|
           tag,inf=meta.scan(/^.+?:\s|.+/)
           if tag and inf
-            util=SiSU_text_utils::Wrap.new(inf,@wrap_width,15,1)
+            util=SiSU_TextUtils::Wrap.new(inf,@wrap_width,15,1)
             txt=util.line_wrap
             @plaintext[:metadata] <<<<WOK
 
@@ -186,9 +186,9 @@ WOK
         end
       end
       def plaintext_tail
-        SiSU_Env::Info_skin.new(@md).select
-#       env=SiSU_Env::Info_env.new(@md.fns)
-        vz=SiSU_Env::Get_init.instance.skin
+        SiSU_Env::InfoSkin.new(@md).select
+#       env=SiSU_Env::InfoEnv.new(@md.fns)
+        vz=SiSU_Env::GetInit.instance.skin
         base_url="#{@env.url.root}/#{@md.fnb}"
         generator="Generated by: #{@md.sisu_version[:project]} #{@md.sisu_version[:version]} of #{@md.sisu_version[:date_stamp]} (#{@md.sisu_version[:date]})"  if @md.sisu_version[:version]
         lastdone="Last Generated on: #{Time.now}"
@@ -200,12 +200,12 @@ WOK
         @plaintext[:tail] <<<<WOK
 #{@br}
 plaintext (plain text):
-   #{base_url}/#{@md.fn[:plain]}#{@br}
+   #{@md.file.output_path.txt.url}/#{@md.file.base_filename.txt}#{@br}
 Other versions of this document: #{@br}
 manifest:
-   #{base_url}/#{@md.fn[:manifest]}#{@br}
+   #{@md.file.output_path.manifest.url}/#{@md.file.base_filename.manifest}#{@br}
 at:
-   #{@env.url.root}#{@br}
+   #{@md.file.output_path.base.url}#{@br}
 
 #{sc}
 * #{generator}
@@ -216,32 +216,32 @@ WOK
       end
       def plaintext_structure(dob='',p_num='') #% Used to extract the structure of a document
         lv=n=n3=nil
-        if dob.is=='heading'
+        if dob.is==:heading
           lv=dob.ln
           n=lv - 1
           n3=lv + 2
         end
         util=nil
-        wrapped=if dob.is =='para' \
-        or dob.is=='heading'
-          if dob.is=='para'
+        wrapped=if dob.is ==:para \
+        or dob.is==:heading
+          if dob.is==:para
             if dob.hang \
             and dob.hang =~/[0-9]/ \
             and dob.indent != dob.hang
-              util=SiSU_text_utils::Wrap.new(dob.obj,@wrap_width,dob.indent.to_i*2,dob.hang.to_i*2)
-              #util=SiSU_text_utils::Wrap.new(dob.obj,@wrap_width,dob.hang.to_i*2,0)
+              util=SiSU_TextUtils::Wrap.new(dob.obj,@wrap_width,dob.indent.to_i*2,dob.hang.to_i*2)
+              #util=SiSU_TextUtils::Wrap.new(dob.obj,@wrap_width,dob.hang.to_i*2,0)
             elsif dob.indent =~/[1-9]/
               util=if dob.bullet_
-                SiSU_text_utils::Wrap.new("* #{dob.obj}",@wrap_width,dob.indent.to_i*2)
-              else SiSU_text_utils::Wrap.new(dob.obj,@wrap_width,dob.indent.to_i*2)
+                SiSU_TextUtils::Wrap.new("* #{dob.obj}",@wrap_width,dob.indent.to_i*2)
+              else SiSU_TextUtils::Wrap.new(dob.obj,@wrap_width,dob.indent.to_i*2)
               end
             else
               util=if dob.bullet_
-                SiSU_text_utils::Wrap.new("* #{dob.obj}",@wrap_width,0)
-              else SiSU_text_utils::Wrap.new(dob.obj,@wrap_width,0)
+                SiSU_TextUtils::Wrap.new("* #{dob.obj}",@wrap_width,0)
+              else SiSU_TextUtils::Wrap.new(dob.obj,@wrap_width,0)
               end
             end
-          else util=SiSU_text_utils::Wrap.new(dob.obj,@wrap_width,0)
+          else util=SiSU_TextUtils::Wrap.new(dob.obj,@wrap_width,0)
           end
           util.line_wrap
         end
@@ -270,7 +270,7 @@ WOK
         @@endnotes[:para]=[]
       end
       def markup(data)                                                       # Used for major markup instructions
-        dir=SiSU_Env::Info_env.new(@md.fns)
+        dir=SiSU_Env::InfoEnv.new(@md.fns)
         @data_mod,@endnotes,@level,@cont,@copen,@plaintext_contents_close=Array.new(6){[]}
         (0..6).each { |x| @cont[x]=@level[x]=false }
         (4..6).each { |x| @plaintext_contents_close[x]='' }
@@ -279,89 +279,89 @@ WOK
         table_message='[table omitted, see other document formats]'
         fix=[]
         data.each do |dob|
-          dob.obj.gsub!(/#{Mx[:gr_o]}Th?#{Mx[:tc_p]}.+/um,"#{@br}#{table_message}") #fix
-          dob.obj.gsub!(/.+?#{Mx[:gl_o]}-##{Mx[:gl_c]}/,'')                              # remove dummy headings (used by html) #check also [~-]#
-          dob.obj.gsub!(/#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}/,
-            "#{Px[:bold_o]}\\1#{Px[:bold_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}/,
-            "#{Px[:italics_o]}\\1#{Px[:italics_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}/,
-            "#{Px[:underscore_o]}\\1#{Px[:underscore_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_subscript_o]}(.+?)#{Mx[:fa_subscript_c]}/,
-            "#{Px[:subscript_o]}\\1#{Px[:subscript_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_superscript_o]}(.+?)#{Mx[:fa_superscript_c]}/,
-            "#{Px[:superscript_o]}\\1#{Px[:superscript_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_insert_o]}(.+?)#{Mx[:fa_insert_c]}/,
-            "#{Px[:insert_o]}\\1#{Px[:insert_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_cite_o]}(.+?)#{Mx[:fa_cite_c]}/,
-            "#{Px[:cite_o]}\\1#{Px[:cite_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,
-            "#{Px[:strike_o]}\\1#{Px[:strike_c]}")
-          dob.obj.gsub!(/#{Mx[:fa_monospace_o]}(.+?)#{Mx[:fa_monospace_c]}/,
-            "#{Px[:monospace_o]}\\1#{Px[:monospace_c]}")
-          unless dob.is=='code'
-            dob.obj.gsub!(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:rel_o]}\S+?#{Mx[:rel_c]}/,'\1')
-            dob.obj.gsub!(/#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'\1')
-            dob.obj.gsub!(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,'\1 [link: <\2>]')
-            dob.obj.gsub!(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}image/,'\1 [link: local image]')
-            dob.obj.gsub!(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,"#{@brace_url.txt_open}\\1#{@brace_url.txt_close}")
+          dob.obj=dob.obj.gsub(/#{Mx[:gr_o]}Th?#{Mx[:tc_p]}.+/um,"#{@br}#{table_message}"). #fix
+            gsub(/.+?#{Mx[:gl_o]}-##{Mx[:gl_c]}/,'').                              # remove dummy headings (used by html) #check also [~-]#
+            gsub(/#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}/,
+              "#{Px[:bold_o]}\\1#{Px[:bold_c]}").
+            gsub(/#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}/,
+              "#{Px[:italics_o]}\\1#{Px[:italics_c]}").
+            gsub(/#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}/,
+              "#{Px[:underscore_o]}\\1#{Px[:underscore_c]}").
+            gsub(/#{Mx[:fa_subscript_o]}(.+?)#{Mx[:fa_subscript_c]}/,
+              "#{Px[:subscript_o]}\\1#{Px[:subscript_c]}").
+            gsub(/#{Mx[:fa_superscript_o]}(.+?)#{Mx[:fa_superscript_c]}/,
+              "#{Px[:superscript_o]}\\1#{Px[:superscript_c]}").
+            gsub(/#{Mx[:fa_insert_o]}(.+?)#{Mx[:fa_insert_c]}/,
+              "#{Px[:insert_o]}\\1#{Px[:insert_c]}").
+            gsub(/#{Mx[:fa_cite_o]}(.+?)#{Mx[:fa_cite_c]}/,
+              "#{Px[:cite_o]}\\1#{Px[:cite_c]}").
+            gsub(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,
+              "#{Px[:strike_o]}\\1#{Px[:strike_c]}").
+            gsub(/#{Mx[:fa_monospace_o]}(.+?)#{Mx[:fa_monospace_c]}/,
+              "#{Px[:monospace_o]}\\1#{Px[:monospace_c]}")
+          unless dob.is==:code
+            dob.obj=dob.obj.gsub(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:rel_o]}\S+?#{Mx[:rel_c]}/,'\1').
+              gsub(/#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'\1').
+              gsub(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,'\1 [link: <\2>]').
+              gsub(/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}image/,'\1 [link: local image]').
+              gsub(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,"#{@brace_url.txt_open}\\1#{@brace_url.txt_close}")
             extract_endnotes(dob)
-            dob.obj.gsub!(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'[^\1]') # endnote marker marked up
-            dob.obj.gsub!(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'[^\1]') # endnote marker marked up
-            dob.obj.gsub!(/#{Mx[:gl_o]}(?:#lt|#060)#{Mx[:gl_c]}/,'<')
-            dob.obj.gsub!(/#{Mx[:gl_o]}(?:#gt|#062)#{Mx[:gl_c]}/,'>')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#(?:038|amp)#{Mx[:gl_c]}/,'&')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#033#{Mx[:gl_c]}/,'!')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#035#{Mx[:gl_c]}/,'#')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#042#{Mx[:gl_c]}/,'*')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#045#{Mx[:gl_c]}/,'-')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#047#{Mx[:gl_c]}/,'/')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#095#{Mx[:gl_c]}/,'_')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#123#{Mx[:gl_c]}/,'{')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#125#{Mx[:gl_c]}/,'}')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#169#{Mx[:gl_c]}/,'©')
-            dob.obj.gsub!(/#{Mx[:gl_o]}#092#{Mx[:gl_c]}/,'\\')
+            dob.obj=dob.obj.gsub(/#{Mx[:en_a_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_a_c]}/,'[^\1]'). # endnote marker marked up
+              gsub(/#{Mx[:en_b_o]}([\d*+]+)\s+(?:.+?)#{Mx[:en_b_c]}/,'[^\1]'). # endnote marker marked up
+              gsub(/#{Mx[:gl_o]}(?:#lt|#060)#{Mx[:gl_c]}/,'<').
+              gsub(/#{Mx[:gl_o]}(?:#gt|#062)#{Mx[:gl_c]}/,'>').
+              gsub(/#{Mx[:gl_o]}#(?:038|amp)#{Mx[:gl_c]}/,'&').
+              gsub(/#{Mx[:gl_o]}#033#{Mx[:gl_c]}/,'!').
+              gsub(/#{Mx[:gl_o]}#035#{Mx[:gl_c]}/,'#').
+              gsub(/#{Mx[:gl_o]}#042#{Mx[:gl_c]}/,'*').
+              gsub(/#{Mx[:gl_o]}#045#{Mx[:gl_c]}/,'-').
+              gsub(/#{Mx[:gl_o]}#047#{Mx[:gl_c]}/,'/').
+              gsub(/#{Mx[:gl_o]}#095#{Mx[:gl_c]}/,'_').
+              gsub(/#{Mx[:gl_o]}#123#{Mx[:gl_c]}/,'{').
+              gsub(/#{Mx[:gl_o]}#125#{Mx[:gl_c]}/,'}').
+              gsub(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~').
+              gsub(/#{Mx[:gl_o]}#169#{Mx[:gl_c]}/,'©').
+              gsub(/#{Mx[:gl_o]}#092#{Mx[:gl_c]}/,'\\')
           end
-          if dob.of=='block'                                   # watch
-            dob.obj.gsub!(/#{Mx[:gl_o]}●#{Mx[:gl_c]}/,"* ")
-            dob.obj.gsub!(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,"\n")
-          else dob.obj.gsub!(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,"\n\n")
+          dob.obj=if dob.of==:block                                   # watch
+            dob.obj.gsub(/#{Mx[:gl_o]}●#{Mx[:gl_c]}/,"* ").
+              gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,"\n")
+          else dob.obj.gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,"\n\n")
           end
-          if dob.is=='code'
-            dob.obj.gsub!(/(^|[^}])_([<>])/m,'\1\2') # _> _<
-            dob.obj.gsub!(/(^|[^}])_([<>])/m,'\1\2') # _<_<
+          if dob.is==:code
+            dob.obj=dob.obj.gsub(/(^|[^}])_([<>])/m,'\1\2'). # _> _<
+              gsub(/(^|[^}])_([<>])/m,'\1\2') # _<_<
           end
-          dob.obj.gsub!(/#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'\1')
-          dob.obj.gsub!(/<a href=".+?">(.+?)<\/a>/m,'\1')
-          dob.obj.gsub!(/#{Mx[:mk_o]}:name#(\S+?)#{Mx[:mk_c]}/,'')                       # remove name links
-          dob.obj.gsub!(/&nbsp;|#{Mx[:nbsp]}/,' ')                                       # decide on
-          dob.obj.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}#{Mx[:url_o]}\S+?#{Mx[:url_c]}/,'    [ \1 ]') #"[ #{dir.url.images_local}\/\\1 ]")
-          dob.obj.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}image/,'    [ \1 ]')
-          dob.obj.gsub!(/(?:^|[^_\\])\{\s*\S+?\.(?:png|jpg|gif)\s+.+?"(.*?)"\s*\}\S+/,'[image: "\1"]')
+          dob.obj=dob.obj.gsub(/#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,'\1').
+            gsub(/<a href=".+?">(.+?)<\/a>/m,'\1').
+            gsub(/#{Mx[:mk_o]}:name#(\S+?)#{Mx[:mk_c]}/,'').                       # remove name links
+            gsub(/&nbsp;|#{Mx[:nbsp]}/,' ').                                       # decide on
+            gsub(/(?:^|[^_\\])#{Mx[:lnk_o]}(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}#{Mx[:url_o]}\S+?#{Mx[:url_c]}/,'    [ \1 ]'). #"[ #{dir.url.images_local}\/\\1 ]")
+            gsub(/(?:^|[^_\\])#{Mx[:lnk_o]}(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}image/,'    [ \1 ]').
+            gsub(/(?:^|[^_\\])\{\s*\S+?\.(?:png|jpg|gif)\s+.+?"(.*?)"\s*\}\S+/,'[image: "\1"]')
           wordlist=dob.obj.scan(/\S+/)
           if dob.obj !~/(^#{Rx[:meta]}|#{Mx[:br_eof]}|#{Mx[:br_endnotes]})/
             #if defined? dob.ocn and dob.ocn.to_s =~/\d+/
             #  paranum=dob.ocn.to_s
-            #  @p_num=SiSU_Plaintext_format::Paragraph_number.new(paranum)
+            #  @p_num=SiSU_PlaintextFormat::ParagraphNumber.new(paranum)
             #end
             p_num=''
             if @env.plaintext_ocn?
               if defined? dob.ocn \
               and not dob.ocn.nil?
-                p_num=SiSU_Plaintext_format::Paragraph_number.new(dob.ocn).display
+                p_num=SiSU_PlaintextFormat::ParagraphNumber.new(dob.ocn).display
               end
             end
-            if dob.is=='heading' \
-            or dob.is=='para'
+            if dob.is==:heading \
+            or dob.is==:para
               plaintext_structure(dob,p_num)
-            elsif dob.is=='group' \
-            or dob.is=='block' \
-            or dob.is=='verse' \
-            or dob.is=='code' \
-            or dob.is=='table'
+            elsif dob.is==:group \
+            or dob.is==:block \
+            or dob.is==:verse \
+            or dob.is==:code \
+            or dob.is==:table
               @plaintext[:body] << dob.obj + p_num << @br
-            elsif dob.is=='break'
+            elsif dob.is==:break
               sp=' '
               ln='-'
               @plaintext[:body] <<=if dob.obj==Mx[:br_page] \
@@ -372,9 +372,11 @@ WOK
               end # following empty line (@br) missing, fix
             end
             dob='' if (dob.obj =~/<a name="n\d+">/ \
-            and dob.obj =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/) # -endnote
-            dob.obj.gsub!(/<!.+!>/,' ') if dob ## Clean Prepared Text
-            dob.obj.gsub!(/<:\S+>/,' ') if dob ## Clean Prepared Text
+              and dob.obj =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/) # -endnote
+            if dob ## Clean Prepared Text
+              dob.obj=dob.obj.gsub(/<!.+!>/,' ').
+                gsub(/<:\S+>/,' ')
+            end
           end
         end
         @plaintext
@@ -401,7 +403,7 @@ WOK
         @content,@md=content,md
       end
       def plaintext                                                            #%plaintext output
-        file_plaintext=SiSU_Env::SiSU_file.new(@md).write_file.txt
+        file_plaintext=SiSU_Env::FileOp.new(@md).write_file.txt
         @sisu=[]
         emptyline=0
         @content.each do |para|                                                # this is a hack
