@@ -56,11 +56,11 @@
  ** Description: plaintext formatting template
 
 =end
-module SiSU_Plaintext_format
+module SiSU_PlaintextFormat
   require_relative 'param'                              # param.rb
     include SiSU_Param
   include SiSU_Viz
-  class Paragraph_number
+  class ParagraphNumber
     def initialize(paranum)
       @paranum=/(\d+)/m.match(paranum.to_s)[1]
     end
@@ -74,7 +74,7 @@ module SiSU_Plaintext_format
       @paranum.gsub(/(\d+)/,'"#\1"')
     end
   end
-  class Format_text_object
+  class FormatTextObject
     def initialize(md,t_o)
       @md,@t_o=md,t_o
       if t_o.class==Hash
@@ -86,10 +86,10 @@ module SiSU_Plaintext_format
         p caller
       end
       rgx=/^#{Rx[:lv]}/
-      @txt.gsub!(rgx,'') if @txt =~rgx
+      @txt=@txt.gsub(rgx,'') if @txt =~rgx
       rgx=/#{Mx[:en_a_o]}[\d*+]+\s+(.+?)#{Mx[:en_a_c]}/
-      @txt.gsub!(rgx,'\1') if @txt =~rgx
-      @vz=SiSU_Env::Get_init.instance.skin
+      @txt=@txt.gsub(rgx,'\1') if @txt =~rgx
+      @vz=SiSU_Env::GetInit.instance.skin
     end
     def scr_endnote_body
       "<endnote>#{@txt}</endnote> "
