@@ -63,11 +63,11 @@ module SiSU_Remote
   class Put
     def initialize(opt)
       @opt=opt
-      @dir=SiSU_Env::Info_env.new(@opt.fns)
+      @dir=SiSU_Env::InfoEnv.new(@opt.fns)
       @put=(@opt.fns =~/\.ssm\.sst$/) \
       ? @opt.fns.gsub(/(.+)?\.ssm\.sst$/,'\1.ssm')
       : @opt.fns
-      @remote=SiSU_Env::Info_remote.new(@opt)
+      @remote=SiSU_Env::InfoRemote.new(@opt)
     end
     def rsync
       SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->',@put).dark_grey_title_hi unless @opt.cmd =~/q/
@@ -124,9 +124,9 @@ module SiSU_Remote
             imagedir=base_uri + '/_sisu/image' #check on
             doc_skin_dir = /((?:https?|file):\/\/\S+?)\/[^\/]+?\.sst$/.match(url).captures.join + '/_sisu/skin/doc'
             downloaded_file=File.new("#{fnb}.-sst",'w+')
-            image_download_url=SiSU_Assemble::Remote_image.new.image(imagedir)
+            image_download_url=SiSU_Assemble::RemoteImage.new.image(imagedir)
             images=[]
-            skin=SiSU_Assemble::Remote_image.new.image(doc_skin_dir)
+            skin=SiSU_Assemble::RemoteImage.new.image(doc_skin_dir)
             f.collect.each do |r|                            # work area
               unless r =~/^%+\s/
                 skin << r.scan(@rgx_skin).uniq if r =~@rgx_skin
@@ -139,19 +139,18 @@ module SiSU_Remote
             end
             if skin \
             and skin.length > 0
-              SiSU_Assemble::Remote_image.new.download_doc_skin(skin)
+              SiSU_Assemble::RemoteImage.new.download_doc_skin(skin)
             end
             if images \
             and images.length > 1
-              images.flatten!
-              images.uniq!
+              images=images.flatten.uniq
               images.delete_if {|x| x =~/https?:\/\// }
-              images.sort!
+              images=images.sort
               @msg,@msgs='downloading images:', [ images.join(',') ]
               @tell.call.warn unless @opt.cmd =~/q/
               image_info=image_download_url + images
-              SiSU_Assemble::Remote_image.new.download_images(image_info)
-              #SiSU_Assemble::Remote_image.new.download_images(image_download_url,images)
+              SiSU_Assemble::RemoteImage.new.download_images(image_info)
+              #SiSU_Assemble::RemoteImage.new.download_images(image_download_url,images)
               @msg,@msgs='downloading done',nil
               @tell.call.warn unless @opt.cmd =~/q/
             end
@@ -166,7 +165,7 @@ module SiSU_Remote
       if get_p.length > 0                                     #% remote sisupod
          require 'net/http'
         for requested_pod in get_p
-          pod_info=Remote_download.new(requested_pod)
+          pod_info=RemoteDownload.new(requested_pod)
           Net::HTTP.start(pod_info.pod.site) do |http|
             resp=http.get("#{pod_info.pod.path}/#{pod_info.pod.name_source}")
             open(pod_info.pod.name,'wb') do |file|
@@ -177,7 +176,7 @@ module SiSU_Remote
       end
     end
   end
-  class Remote_download
+  class RemoteDownload
     def initialize(requested_file)
       @requested_file=requested_file
     end
