@@ -68,7 +68,7 @@ module SiSU_Screen
     def initialize(cmd,*txt)
       @cmd,@txt=cmd,txt
       @color_instruct=txt[0]
-      flag=SiSU_Env::Info_processing_flag.new
+      flag=SiSU_Env::InfoProcessingFlag.new
       if @cmd
         if flag.color                                                              #set default colors on or off -c acts as toggle against this default, if default is off -c turns on, if default is on -c turns off
           @use_color=if @cmd =~/c/; false
@@ -206,7 +206,7 @@ module SiSU_Screen
     def sisu
     end
     def rescue
-      %{\t   #{@cX.orange}Rescued#{@cX.off} #{@cX.grey}An#{@cX.off} #{@cX.fuschia}ERROR#{@cX.off} #{@cX.grey}occurred, message:"#{@cX.off} #{@cX.fuschia}#{@txt[0]}#{@cX.off} #{@cX.grey}#{@txt[1]}#{@cX.off} #{@cX.brown}#{@txt[2]}#{@cX.off}}
+      puts %{\t   #{@cX.orange}Rescued#{@cX.off} #{@cX.grey}#{yield if block_given?}\n\t   An#{@cX.off} #{@cX.fuschia}ERROR#{@cX.off} #{@cX.grey}occurred, message:#{@cX.off} #{@cX.fuschia}#{@txt[0]}#{@cX.off} #{@cX.grey}#{@txt[1]}#{@cX.off} #{@cX.brown}#{@txt[2]}#{@cX.off}}
     end
     def warn
       puts "\t  #{@cX.brown}#{@txt[0]}#{@cX.off} #{@cX.grey}#{@txt[1]}#{@cX.off}"
