@@ -56,7 +56,7 @@
  ** Description: system environment, resource control and configuration details
 
 =end
-module Metadata
+module SiSU_Metadata
   class Summary
     attr_accessor :tag,:inf,:class,:attrib
     def initialize(md,display_heading=false)
@@ -65,9 +65,9 @@ module Metadata
     end
     def metadata_base
       meta,tag=[],[]
-      dir=SiSU_Env::Info_env.new(@md.fns)
+      dir=SiSU_Env::InfoEnv.new(@md.fns)
       base_html="#{dir.url.root}/#{@md.fnb}"
-      l=SiSU_Env::Standardise_language.new(@md.opt.lng).language
+      l=SiSU_Env::StandardiseLanguage.new(@md.opt.lng).language
       language=l[:n]
       tr=SiSU_Translate::Source.new(@md,language)
       @attrib='md'
@@ -434,7 +434,7 @@ module Metadata
             @md.creator.author_detail.each do |n|
               x += "#{n[:the]}, #{n[:others]}; "
             end
-            x.gsub!(/;\s*$/,'')
+            x=x.gsub(/;\s*$/,'')
             ' :author: ' + x
           else nil
           end
@@ -446,7 +446,7 @@ module Metadata
             @md.creator.contributor_detail.each do |n|
               x += "#{n[:the]}, #{n[:others]}; "
             end
-            x.gsub!(/;\s*$/,'')
+            x=x.gsub(/;\s*$/,'')
             ' :contributor: ' + x
           else nil
           end
@@ -458,7 +458,7 @@ module Metadata
             @md.creator.illustrator_detail.each do |n|
               x += "#{n[:the]}, #{n[:others]}; "
             end
-            x.gsub!(/;\s*$/,'')
+            x=x.gsub(/;\s*$/,'')
             ' :illustrator: ' + x
           else nil
           end
@@ -470,7 +470,7 @@ module Metadata
             @md.creator.photographer_detail.each do |n|
               x += "#{n[:the]}, #{n[:others]}; "
             end
-            x.gsub!(/;\s*$/,'')
+            x=x.gsub(/;\s*$/,'')
             ' :photographer: ' + x
           else nil
           end
@@ -482,7 +482,7 @@ module Metadata
             @md.creator.translator_detail.each do |n|
               x += "#{n[:the]}, #{n[:others]}; "
             end
-            x.gsub!(/;\s*$/,'')
+            x=x.gsub(/;\s*$/,'')
             ' :translator: ' + x
           else nil
           end
@@ -494,7 +494,7 @@ module Metadata
             @md.creator.audio_detail.each do |n|
               x += "#{n[:the]}, #{n[:others]}; "
             end
-            x.gsub!(/;\s*$/,'')
+            x=x.gsub(/;\s*$/,'')
             ' :audio: ' + x
           else nil
           end
@@ -506,7 +506,7 @@ module Metadata
             @md.creator.digitized_by_detail.each do |n|
               x += "#{n[:the]}, #{n[:others]}; "
             end
-            x.gsub!(/;\s*$/,'')
+            x=x.gsub(/;\s*$/,'')
             ' :digitized_by: ' + x
           else nil
           end
@@ -518,7 +518,7 @@ module Metadata
             @md.creator.prepared_by_detail.each do |n|
               x += "#{n[:the]}, #{n[:others]}; "
             end
-            x.gsub!(/;\s*$/,'')
+            x=x.gsub(/;\s*$/,'')
             ' :prepared_by: ' + x
           else nil
           end
@@ -736,107 +736,107 @@ module Metadata
       def utf8
         if @s \
         and @s.class==String
-          @s.gsub!(/<br(?: \/)?>/u,Mx[:br_paragraph])
-          @s.gsub!(/</um,'&#60;') # '&lt;'   # &#060;
-          @s.gsub!(/</um,'&#60;') # '&lt;'   # &#060;
-          @s.gsub!(/>/um,'&#62;') # '&gt;'   # &#062;
-          @s.gsub!(/¢/um,'&#162;') # '&cent;'   # &#162;
-          @s.gsub!(/£/um,'&#163;') # '&pound;'  # &#163;
-          @s.gsub!(/¥/um,'&#165;') # '&yen;'    # &#165;
-          @s.gsub!(/§/um,'&#167;') # '&sect;'   # &#167;
-          @s.gsub!(/©/um,'&#169;') # '&copy;'   # &#169;
-          @s.gsub!(/ª/um,'&#170;') # '&ordf;'   # &#170;
-          @s.gsub!(/«/um,'&#171;') # '&laquo;'  # &#171;
-          @s.gsub!(/®/um,'&#174;') # '&reg;'    # &#174;
-          @s.gsub!(/°/um,'&#176;') # '&deg;'    # &#176;
-          @s.gsub!(/±/um,'&#177;') # '&plusmn;' # &#177;
-          @s.gsub!(/²/um,'&#178;') # '&sup2;'   # &#178;
-          @s.gsub!(/³/um,'&#179;') # '&sup3;'   # &#179;
-          @s.gsub!(/µ/um,'&#181;') # '&micro;'  # &#181;
-          @s.gsub!(/¶/um,'&#182;') # '&para;'   # &#182;
-          @s.gsub!(/¹/um,'&#185;') # '&sup1;'   # &#185;
-          @s.gsub!(/º/um,'&#186;') # '&ordm;'   # &#186;
-          @s.gsub!(/»/um,'&#187;') # '&raquo;'  # &#187;
-          @s.gsub!(/¼/um,'&#188;') # '&frac14;' # &#188;
-          @s.gsub!(/½/um,'&#189;') # '&frac12;' # &#189;
-          @s.gsub!(/¾/um,'&#190;') # '&frac34;' # &#190;
-          @s.gsub!(/×/um,'&#215;') # '&times;'  # &#215;
-          @s.gsub!(/÷/um,'&#247;') # '&divide;' # &#247;
-          @s.gsub!(/¿/um,'&#191;') # '&iquest;' # &#191;
-          @s.gsub!(/À/um,'&#192;') # '&Agrave;' # &#192;
-          @s.gsub!(/Á/um,'&#193;') # '&Aacute;' # &#193;
-          @s.gsub!(/Â/um,'&#194;') # '&Acirc;'  # &#194;
-          @s.gsub!(/Ã/um,'&#195;') # '&Atilde;' # &#195;
-          @s.gsub!(/Ä/um,'&#196;') # '&Auml;'   # &#196;
-          @s.gsub!(/Å/um,'&#197;') # '&Aring;'  # &#197;
-          @s.gsub!(/Æ/um,'&#198;') # '&AElig;'  # &#198;
-          @s.gsub!(/Ç/um,'&#199;') # '&Ccedil;' # &#199;
-          @s.gsub!(/È/um,'&#200;') # '&Egrave;' # &#200;
-          @s.gsub!(/É/um,'&#201;') # '&Eacute;' # &#201;
-          @s.gsub!(/Ê/um,'&#202;') # '&Ecirc;'  # &#202;
-          @s.gsub!(/Ë/um,'&#203;') # '&Euml;'   # &#203;
-          @s.gsub!(/Ì/um,'&#204;') # '&Igrave;' # &#204;
-          @s.gsub!(/Í/um,'&#205;') # '&Iacute;' # &#205;
-          @s.gsub!(/Î/um,'&#206;') # '&Icirc;'  # &#206;
-          @s.gsub!(/Ï/um,'&#207;') # '&Iuml;'   # &#207;
-          @s.gsub!(/Ð/um,'&#208;') # '&ETH;'    # &#208;
-          @s.gsub!(/Ñ/um,'&#209;') # '&Ntilde;' # &#209;
-          @s.gsub!(/Ò/um,'&#210;') # '&Ograve;' # &#210;
-          @s.gsub!(/Ó/um,'&#211;') # '&Oacute;' # &#211;
-          @s.gsub!(/Ô/um,'&#212;') # '&Ocirc;'  # &#212;
-          @s.gsub!(/Õ/um,'&#213;') # '&Otilde;' # &#213;
-          @s.gsub!(/Ö/um,'&#214;') # '&Ouml;'   # &#214;
-          @s.gsub!(/Ø/um,'&#216;') # '&Oslash;' # &#216;
-          @s.gsub!(/Ù/um,'&#217;') # '&Ugrave;' # &#217;
-          @s.gsub!(/Ú/um,'&#218;') # '&Uacute;' # &#218;
-          @s.gsub!(/Û/um,'&#219;') # '&Ucirc;'  # &#219;
-          @s.gsub!(/Ü/um,'&#220;') # '&Uuml;'   # &#220;
-          @s.gsub!(/Ý/um,'&#221;') # '&Yacute;' # &#221;
-          @s.gsub!(/Þ/um,'&#222;') # '&THORN;'  # &#222;
-          @s.gsub!(/ß/um,'&#223;') # '&szlig;'  # &#223;
-          @s.gsub!(/à/um,'&#224;') # '&agrave;' # &#224;
-          @s.gsub!(/á/um,'&#225;') # '&aacute;' # &#225;
-          @s.gsub!(/â/um,'&#226;') # '&acirc;'  # &#226;
-          @s.gsub!(/ã/um,'&#227;') # '&atilde;' # &#227;
-          @s.gsub!(/ä/um,'&#228;') # '&auml;'   # &#228;
-          @s.gsub!(/å/um,'&#229;') # '&aring;'  # &#229;
-          @s.gsub!(/æ/um,'&#230;') # '&aelig;'  # &#230;
-          @s.gsub!(/ç/um,'&#231;') # '&ccedil;' # &#231;
-          @s.gsub!(/è/um,'&#232;') # '&egrave;' # &#232;
-          @s.gsub!(/é/um,'&#233;') # '&acute;'  # &#233;
-          @s.gsub!(/ê/um,'&#234;') # '&circ;'   # &#234;
-          @s.gsub!(/ë/um,'&#235;') # '&euml;'   # &#235;
-          @s.gsub!(/ì/um,'&#236;') # '&igrave;' # &#236;
-          @s.gsub!(/í/um,'&#237;') # '&acute;'  # &#237;
-          @s.gsub!(/î/um,'&#238;') # '&icirc;'  # &#238;
-          @s.gsub!(/ï/um,'&#239;') # '&iuml;'   # &#239;
-          @s.gsub!(/ð/um,'&#240;') # '&eth;'    # &#240;
-          @s.gsub!(/ñ/um,'&#241;') # '&ntilde;' # &#241;
-          @s.gsub!(/ò/um,'&#242;') # '&ograve;' # &#242;
-          @s.gsub!(/ó/um,'&#243;') # '&oacute;' # &#243;
-          @s.gsub!(/ô/um,'&#244;') # '&ocirc;'  # &#244;
-          @s.gsub!(/õ/um,'&#245;') # '&otilde;' # &#245;
-          @s.gsub!(/ö/um,'&#246;') # '&ouml;'   # &#246;
-          @s.gsub!(/ø/um,'&#248;') # '&oslash;' # &#248;
-          @s.gsub!(/ù/um,'&#250;') # '&ugrave;' # &#250;
-          @s.gsub!(/ú/um,'&#251;') # '&uacute;' # &#251;
-          @s.gsub!(/û/um,'&#252;') # '&ucirc;'  # &#252;
-          @s.gsub!(/ü/um,'&#253;') # '&uuml;'   # &#253;
-          @s.gsub!(/þ/um,'&#254;') # '&thorn;'  # &#254;
-          @s.gsub!(/ÿ/um,'&#255;') # '&yuml;'   # &#255;
-          @s.gsub!(/‘/um,'&#8216;') # '&lsquo;' # &#8216;
-          @s.gsub!(/’/um,'&#8217;') # '&rsquo;' # &#8217;
-          @s.gsub!(/“/um,'&#8220;') # &ldquo;   # &#8220;
-          @s.gsub!(/”/um,'&#8221;') # &rdquo;   # &#8221;
-          @s.gsub!(/–/um,'&#8211;') # &ndash;   # &#8211;
-          @s.gsub!(/—/um,'&#8212;') # &mdash;   # &#8212;
-          @s.gsub!(/∝/um,'&#8733;') # &prop;    # &#8733;
-          @s.gsub!(/∞/um,'&#8734;') # &infin;   # &#8734;
-          @s.gsub!(/™/um,'&#8482;') # &trade;   # &#8482;
-          @s.gsub!(/✠/um,'&#10016;') # &cross;  # &#10016;
-          @s.gsub!(/ /um,' ')       # space identify
-          @s.gsub!(/ /um,' ')       # space identify
-          @s.gsub!(/#{Mx[:br_paragraph]}/u,'<br />')
+          @s=@s.gsub(/<br(?: \/)?>/u,Mx[:br_paragraph]).
+            gsub(/</um,'&#60;'). # '&lt;'   # &#060;
+            gsub(/</um,'&#60;'). # '&lt;'   # &#060;
+            gsub(/>/um,'&#62;'). # '&gt;'   # &#062;
+            gsub(/¢/um,'&#162;'). # '&cent;'   # &#162;
+            gsub(/£/um,'&#163;'). # '&pound;'  # &#163;
+            gsub(/¥/um,'&#165;'). # '&yen;'    # &#165;
+            gsub(/§/um,'&#167;'). # '&sect;'   # &#167;
+            gsub(/©/um,'&#169;'). # '&copy;'   # &#169;
+            gsub(/ª/um,'&#170;'). # '&ordf;'   # &#170;
+            gsub(/«/um,'&#171;'). # '&laquo;'  # &#171;
+            gsub(/®/um,'&#174;'). # '&reg;'    # &#174;
+            gsub(/°/um,'&#176;'). # '&deg;'    # &#176;
+            gsub(/±/um,'&#177;'). # '&plusmn;' # &#177;
+            gsub(/²/um,'&#178;'). # '&sup2;'   # &#178;
+            gsub(/³/um,'&#179;'). # '&sup3;'   # &#179;
+            gsub(/µ/um,'&#181;'). # '&micro;'  # &#181;
+            gsub(/¶/um,'&#182;'). # '&para;'   # &#182;
+            gsub(/¹/um,'&#185;'). # '&sup1;'   # &#185;
+            gsub(/º/um,'&#186;'). # '&ordm;'   # &#186;
+            gsub(/»/um,'&#187;'). # '&raquo;'  # &#187;
+            gsub(/¼/um,'&#188;'). # '&frac14;' # &#188;
+            gsub(/½/um,'&#189;'). # '&frac12;' # &#189;
+            gsub(/¾/um,'&#190;'). # '&frac34;' # &#190;
+            gsub(/×/um,'&#215;'). # '&times;'  # &#215;
+            gsub(/÷/um,'&#247;'). # '&divide;' # &#247;
+            gsub(/¿/um,'&#191;'). # '&iquest;' # &#191;
+            gsub(/À/um,'&#192;'). # '&Agrave;' # &#192;
+            gsub(/Á/um,'&#193;'). # '&Aacute;' # &#193;
+            gsub(/Â/um,'&#194;'). # '&Acirc;'  # &#194;
+            gsub(/Ã/um,'&#195;'). # '&Atilde;' # &#195;
+            gsub(/Ä/um,'&#196;'). # '&Auml;'   # &#196;
+            gsub(/Å/um,'&#197;'). # '&Aring;'  # &#197;
+            gsub(/Æ/um,'&#198;'). # '&AElig;'  # &#198;
+            gsub(/Ç/um,'&#199;'). # '&Ccedil;' # &#199;
+            gsub(/È/um,'&#200;'). # '&Egrave;' # &#200;
+            gsub(/É/um,'&#201;'). # '&Eacute;' # &#201;
+            gsub(/Ê/um,'&#202;'). # '&Ecirc;'  # &#202;
+            gsub(/Ë/um,'&#203;'). # '&Euml;'   # &#203;
+            gsub(/Ì/um,'&#204;'). # '&Igrave;' # &#204;
+            gsub(/Í/um,'&#205;'). # '&Iacute;' # &#205;
+            gsub(/Î/um,'&#206;'). # '&Icirc;'  # &#206;
+            gsub(/Ï/um,'&#207;'). # '&Iuml;'   # &#207;
+            gsub(/Ð/um,'&#208;'). # '&ETH;'    # &#208;
+            gsub(/Ñ/um,'&#209;'). # '&Ntilde;' # &#209;
+            gsub(/Ò/um,'&#210;'). # '&Ograve;' # &#210;
+            gsub(/Ó/um,'&#211;'). # '&Oacute;' # &#211;
+            gsub(/Ô/um,'&#212;'). # '&Ocirc;'  # &#212;
+            gsub(/Õ/um,'&#213;'). # '&Otilde;' # &#213;
+            gsub(/Ö/um,'&#214;'). # '&Ouml;'   # &#214;
+            gsub(/Ø/um,'&#216;'). # '&Oslash;' # &#216;
+            gsub(/Ù/um,'&#217;'). # '&Ugrave;' # &#217;
+            gsub(/Ú/um,'&#218;'). # '&Uacute;' # &#218;
+            gsub(/Û/um,'&#219;'). # '&Ucirc;'  # &#219;
+            gsub(/Ü/um,'&#220;'). # '&Uuml;'   # &#220;
+            gsub(/Ý/um,'&#221;'). # '&Yacute;' # &#221;
+            gsub(/Þ/um,'&#222;'). # '&THORN;'  # &#222;
+            gsub(/ß/um,'&#223;'). # '&szlig;'  # &#223;
+            gsub(/à/um,'&#224;'). # '&agrave;' # &#224;
+            gsub(/á/um,'&#225;'). # '&aacute;' # &#225;
+            gsub(/â/um,'&#226;'). # '&acirc;'  # &#226;
+            gsub(/ã/um,'&#227;'). # '&atilde;' # &#227;
+            gsub(/ä/um,'&#228;'). # '&auml;'   # &#228;
+            gsub(/å/um,'&#229;'). # '&aring;'  # &#229;
+            gsub(/æ/um,'&#230;'). # '&aelig;'  # &#230;
+            gsub(/ç/um,'&#231;'). # '&ccedil;' # &#231;
+            gsub(/è/um,'&#232;'). # '&egrave;' # &#232;
+            gsub(/é/um,'&#233;'). # '&acute;'  # &#233;
+            gsub(/ê/um,'&#234;'). # '&circ;'   # &#234;
+            gsub(/ë/um,'&#235;'). # '&euml;'   # &#235;
+            gsub(/ì/um,'&#236;'). # '&igrave;' # &#236;
+            gsub(/í/um,'&#237;'). # '&acute;'  # &#237;
+            gsub(/î/um,'&#238;'). # '&icirc;'  # &#238;
+            gsub(/ï/um,'&#239;'). # '&iuml;'   # &#239;
+            gsub(/ð/um,'&#240;'). # '&eth;'    # &#240;
+            gsub(/ñ/um,'&#241;'). # '&ntilde;' # &#241;
+            gsub(/ò/um,'&#242;'). # '&ograve;' # &#242;
+            gsub(/ó/um,'&#243;'). # '&oacute;' # &#243;
+            gsub(/ô/um,'&#244;'). # '&ocirc;'  # &#244;
+            gsub(/õ/um,'&#245;'). # '&otilde;' # &#245;
+            gsub(/ö/um,'&#246;'). # '&ouml;'   # &#246;
+            gsub(/ø/um,'&#248;'). # '&oslash;' # &#248;
+            gsub(/ù/um,'&#250;'). # '&ugrave;' # &#250;
+            gsub(/ú/um,'&#251;'). # '&uacute;' # &#251;
+            gsub(/û/um,'&#252;'). # '&ucirc;'  # &#252;
+            gsub(/ü/um,'&#253;'). # '&uuml;'   # &#253;
+            gsub(/þ/um,'&#254;'). # '&thorn;'  # &#254;
+            gsub(/ÿ/um,'&#255;'). # '&yuml;'   # &#255;
+            gsub(/‘/um,'&#8216;'). # '&lsquo;' # &#8216;
+            gsub(/’/um,'&#8217;'). # '&rsquo;' # &#8217;
+            gsub(/“/um,'&#8220;'). # &ldquo;   # &#8220;
+            gsub(/”/um,'&#8221;'). # &rdquo;   # &#8221;
+            gsub(/–/um,'&#8211;'). # &ndash;   # &#8211;
+            gsub(/—/um,'&#8212;'). # &mdash;   # &#8212;
+            gsub(/∝/um,'&#8733;'). # &prop;    # &#8733;
+            gsub(/∞/um,'&#8734;'). # &infin;   # &#8734;
+            gsub(/™/um,'&#8482;'). # &trade;   # &#8482;
+            gsub(/✠/um,'&#10016;'). # &cross;  # &#10016;
+            gsub(/ /um,' ').       # space identify
+            gsub(/ /um,' ').       # space identify
+            gsub(/#{Mx[:br_paragraph]}/u,'<br />')
         end
         @s
       end
@@ -855,7 +855,7 @@ module Metadata
 WOK
       end
       def metadata
-        Metadata::Summary.new(@md).metadata_base
+        SiSU_Metadata::Summary.new(@md).metadata_base
       end
       self
     end
@@ -872,7 +872,7 @@ WOK
 WOK
       end
       def metadata
-        Metadata::Summary.new(@md).metadata_base
+        SiSU_Metadata::Summary.new(@md).metadata_base
       end
       self
     end
@@ -890,7 +890,7 @@ WOK
 WOK
       end
       def metadata
-        Metadata::Summary.new(@md).metadata_base
+        SiSU_Metadata::Summary.new(@md).metadata_base
       end
       self
     end
@@ -902,7 +902,7 @@ WOK
 </p>}
       end
       def metadata
-        Metadata::Summary.new(@md,true).metadata_base
+        SiSU_Metadata::Summary.new(@md,true).metadata_base
       end
       self
     end
@@ -910,32 +910,32 @@ WOK
       def meta_para
         url_brace=SiSU_Viz::Skin.new.url_decoration
         if @inf.class==String
-          @inf.gsub!(/</,'&lt;'); @inf.gsub!(/>/,'&gt;')
-          @inf.gsub!(/&lt;br(?: \/)?&gt;/,'<br />')
+          @inf=@inf.gsub(/</,'&lt;').gsub(/>/,'&gt;').
+            gsub(/&lt;br(?: \/)?&gt;/,'<br />')
           if @inf =~/&/
             inf_array=[]
             word=@inf.scan(/\S+|\n/)
             word.each do |w| # _ - / # | : ! ^ ~
-              w.gsub!(/&nbsp;/,'&#160;')
+              w=w.gsub(/&nbsp;/,'&#160;')
               if w !~/&\S{2,7}?;/
-                w.gsub!(/&/,'&amp;')
+                w=w.gsub(/&/,'&amp;')
               end
               inf_array << w
             end
             @inf=inf_array.join(' ')
           end
-          @inf.gsub!(/#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,
-            '<text:a xlink:type="simple" xlink:href="\1">\1</text:a>') #http ftp matches escaped, no decoration
-          @inf.gsub!(/(#{Mx[:lnk_c]})#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,
-            '\1<text:a xlink:type="simple" xlink:href="\2">\2</text:a>') #special case \{ e.g. \}http://url
-          if @inf =~/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/
-            @inf.gsub!(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,
+          @inf=@inf.gsub(/#{Mx[:url_o]}_(\S+?)#{Mx[:url_c]}/,
+              '<text:a xlink:type="simple" xlink:href="\1">\1</text:a>'). #http ftp matches escaped, no decoration
+            gsub(/(#{Mx[:lnk_c]})#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,
+              '\1<text:a xlink:type="simple" xlink:href="\2">\2</text:a>') #special case \{ e.g. \}http://url
+          @inf=if @inf =~/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/
+            @inf.gsub(/#{Mx[:url_o]}(\S+?)#{Mx[:url_c]}/,
               %{#{url_brace.xml_open}<text:a xlink:type="simple" xlink:href="\\1">\\1</text:a>#{url_brace.xml_close}}) #http ftp matches with decoration
           else
-            @inf.gsub!(/(https?:\/\/[^<>()'"\s]+)/,
+            @inf.gsub(/(https?:\/\/[^<>()'"\s]+)/,
               %{#{url_brace.xml_open}<text:a xlink:type="simple" xlink:href="\\1">\\1</text:a>#{url_brace.xml_close}}) #http ftp matches with decoration
           end
-          @inf.gsub!(/([a-zA-Z0-9._-]+@[a-zA-Z0-9._-]+)/,
+          @inf=@inf.gsub(/([a-zA-Z0-9._-]+@[a-zA-Z0-9._-]+)/,
             %{#{url_brace.xml_open}<text:a xlink:type="simple" xlink:href="mailto:\\1">\\1</text:a>#{url_brace.xml_close}}) if @inf !~/http:\/\// # improve upon, document crash where url contains '@' symbol
         end
         <<WOK
@@ -943,7 +943,7 @@ WOK
 WOK
       end
       def metadata
-        Metadata::Summary.new(@md).metadata_base
+        SiSU_Metadata::Summary.new(@md).metadata_base
       end
       self
     end
@@ -955,7 +955,7 @@ WOK
 WOK
       end
       def metadata
-        Metadata::Summary.new(@md).metadata_base
+        SiSU_Metadata::Summary.new(@md).metadata_base
       end
       self
     end
@@ -969,12 +969,12 @@ WOK
 WOK
       end
       def metadata
-        Metadata::Summary.new(@md).metadata_base
+        SiSU_Metadata::Summary.new(@md).metadata_base
       end
       self
     end
   end
-  class TeX_metadata
+  class TeX_Metadata
     def initialize(md)
       @md=md
       @br="\\\\\n"
@@ -985,23 +985,23 @@ WOK
 }
     end
     def spec_char(inf)
-      SiSU_TeX_Pdf::Special_characters.new(@md,inf).special_characters
+      SiSU_TeX_Pdf::SpecialCharacters.new(@md,inf).special_characters
     end
     def word_break_points(inf)
-      SiSU_TeX_Pdf::Special_characters.new(@md,inf).special_word_break_points
+      SiSU_TeX_Pdf::SpecialCharacters.new(@md,inf).special_word_break_points
     end
     def number_break_points(inf)
-      SiSU_TeX_Pdf::Special_characters.new(@md,inf).special_number_break_points
+      SiSU_TeX_Pdf::SpecialCharacters.new(@md,inf).special_number_break_points
     end
     def metadata_tex
       meta=[]
-      dir=SiSU_Env::Info_env.new(@md.fns)
+      dir=SiSU_Env::InfoEnv.new(@md.fns)
       base_html="#{dir.url.root}/#{@md.fnb}"
-      l=SiSU_Env::Standardise_language.new(@md.opt.lng).language
+      l=SiSU_Env::StandardiseLanguage.new(@md.opt.lng).language
       language=l[:n]
       tr=SiSU_Translate::Source.new(@md,language)
       tag="Document Manifest @"
-      inf="#{@br}#{base_html}/#{@md.fn[:manifest]}"
+      inf="#{@br}#{@md.file.output_path.manifest.url}/#{@md.file.base_filename.manifest}"
       meta << meta_para(tag,inf)
       if defined? @md.title.full \
       and @md.title.full=~/\S+/
