@@ -57,7 +57,7 @@
  ** Description: system environment, resource control and configuration details
 
 =end
-module SiSU_sem
+module SiSU_Sem
   require_relative 'param'                              # param.rb
   class Tags
     def initialize(para,md)
