@@ -56,10 +56,10 @@
  ** Description: shared html parts
 
 =end
-module SiSU_XHTML_shared
+module SiSU_XHTML_Shared
   require_relative 'defaults'                           # defaults.rb
   require_relative 'xhtml_table'                        # xhtml_table.rb
-  class Table_xhtml < SiSU_XHTML_table::Table_xhtml
+  class TableXHTML < SiSU_XHTML_Table::TableXHTML
   end
 end
 __END__
