@@ -62,7 +62,7 @@ module SiSU_Sitemaps
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env
   require_relative 'shared_xml'                         # shared_xml.rb
-    include SiSU_XML_munge
+    include SiSU_XML_Munge
   class Source
     def initialize(opt)
       @opt=opt
@@ -72,25 +72,25 @@ module SiSU_Sitemaps
     end
     def songsheet
       begin
-        @sys=SiSU_Env::System_call.new
-        fn_set_lang=SiSU_Env::Standardise_language.new(@opt.lng).language
-        @fn=SiSU_Env::Env_call.new(@opt.fns).lang(fn_set_lang[:c])
+        @sys=SiSU_Env::SystemCall.new
+        fn_set_lang=SiSU_Env::StandardiseLanguage.new(@opt.lng).language
+        @fn=SiSU_Env::EnvCall.new(@opt.fns).lang(fn_set_lang[:c])
         if @opt.cmd =~/Y/
           @md=SiSU_Param::Parameters.new(@opt).get
-          @trans=SiSU_XML_munge::Trans.new(@md) #check @md is required
-          @env=SiSU_Env::Info_env.new(@md.fns)
-#         @file=SiSU_Env::SiSU_file.new(@md)
-          @rdf=SiSU_XML_tags::RDF.new(@md)
+          @trans=SiSU_XML_Munge::Trans.new(@md) #check @md is required
+          @env=SiSU_Env::InfoEnv.new(@md.fns)
+#         @file=SiSU_Env::FileOp.new(@md)
+          @rdf=SiSU_XML_Tags::RDF.new(@md)
           @fnb_utf8_xml=@md.fnb.dup
           @trans.char_enc.utf8(@fnb_utf8_xml) if @sys.locale =~/utf-?8/i #% utf8
           output_map(sitemap)
         elsif @opt.mod.inspect =~/--sitemaps/
           @sitemap_idx_fn='sitemapindex.xml'
-          @env=SiSU_Env::Info_env.new
+          @env=SiSU_Env::InfoEnv.new
           output_idx(sitemap_index)
           SiSU_Screen::Ansi.new(@opt.cmd,"sitemap index:","#{@env.path.output}/#{@sitemap_idx_fn}").result unless @opt.cmd =~/q/
         end
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
       end
     end
@@ -105,8 +105,8 @@ module SiSU_Sitemaps
       filename=@fn[:sitemap]
       touch_path=@md.file.output_path.sitemaps.dir
       touch_filename=@fn[:sitemap_touch]
-      SiSU_Env::SiSU_file.new(@md).make_path(path)
-      file=SiSU_Env::SiSU_file.new(@md).make_file(path,filename)
+      SiSU_Env::FileOp.new(@md).make_path(path)
+      file=SiSU_Env::FileOp.new(@md).make_file(path,filename)
       file << sitemap
       if FileTest.file?("#{touch_path}/#{touch_filename}")
         FileUtils::rm("#{touch_path}/#{touch_filename}")
