@@ -61,7 +61,7 @@ def brick(port,get='')
   cgidir=if get=~/pwd/; Dir.pwd
   else                  '/usr/lib/cgi-bin'  # @env.path.cgi
   end
-  port=SiSU_Env::Info_port.new.webrick
+  port=SiSU_Env::InfoPort.new.webrick
   begin
     s=HTTPServer.new(
       Port:         port,
@@ -75,7 +75,7 @@ def brick(port,get='')
     s.mount('/cgi-bin', HTTPServlet::FileHandler, cgi_dir, { FancyIndexing: true })
     trap("INT"){ s.shutdown }
     s.start
-  rescue; SiSU_Errors::Info_error.new($!,$@,'-W',nil).error #fix
+  rescue; SiSU_Errors::InfoError.new($!,$@,'-W',nil).error #fix
   ensure
   end
 end
@@ -86,8 +86,8 @@ begin                                                                          #
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env; include SiSU_Screen
   @cX=SiSU_Screen::Ansi.new('yes').cX
-  @env=SiSU_Env::Info_env.new
-  port=SiSU_Env::Info_port.new
+  @env=SiSU_Env::InfoEnv.new
+  port=SiSU_Env::InfoPort.new
   @argv=$*
   @host=@env.url.webrick
   host='localhost'
@@ -168,7 +168,7 @@ WOK
   brick(@port,get)
 rescue;
   require_relative 'sysenv'                             # sysenv.rb
-  SiSU_Errors::Info_error.new($!,$@,'-W',nil).error #fix
+  SiSU_Errors::InfoError.new($!,$@,'-W',nil).error #fix
 ensure
 end
 __END__
