@@ -57,11 +57,11 @@
    ** Notes: tidy -xml index.xml >> index.tidy
 
 =end
-module SiSU_XML_format
+module SiSU_XML_Format
   require_relative 'param'                              # param.rb
     include SiSU_Param
   include SiSU_Viz
-  class Paragraph_number
+  class ParagraphNumber
     def initialize(md,paranum)
       @md=md
       @paranum=(paranum ? (/(\d+)/m.match(paranum)[1]) : nil)
@@ -84,7 +84,7 @@ module SiSU_XML_format
       p_num_goto
     end
   end
-  class Head_information
+  class HeadInformation
     def initialize #dc rdf
       @full_title=@subtitle=@author=@subject=@description=@publisher=@contributor=@date=@type=@format=@identifier=@source=@language=@relation=@coverage=@rights=@copyright=@owner=@keywords=''
       @md=@@md
@@ -193,7 +193,7 @@ module SiSU_XML_format
       @copyright=%{<meta name="copyright" content="#{@md.rights.copyright.all}" />\n} if @md.rights.copyright.all # possibly redundant see dc.rights
       @owner=%{<meta name="owner" content="#{@md.owner}" />\n} if @md.owner
       @keywords=%{<meta name="keywords" content="#{@md.keywords}" />\n} if @md.keywords
-      @vz=SiSU_Env::Get_init.instance.skin #margin,paragraph,table,banner,url,png,txt,color,font,nav_txt,nav_png,credits,js,php
+      @vz=SiSU_Env::GetInit.instance.skin #margin,paragraph,table,banner,url,png,txt,color,font,nav_txt,nav_png,credits,js,php
       @index='index'
     end
     def toc_head_escript #embedded script in this case PHP
@@ -274,7 +274,7 @@ module SiSU_XML_format
 WOK
     end
   end
-  class Format_text_object
+  class FormatTextObject
     attr_accessor :md,:txt,:format,:paranum,:p_num,:para_id,:headname,:font
    def initialize(md,dob)
       @md,@dob=md,dob
@@ -282,19 +282,19 @@ WOK
         @paranum=/(\d+)/m.match(@dob[:ocn])[1]
         @headname=''
         @headname=%{<a name="h#{dob.name}"></a>} if defined? dob.name
-        @p_num=SiSU_XML_format::Paragraph_number.new(@md,dob.ocn)
+        @p_num=SiSU_XML_Format::ParagraphNumber.new(@md,dob.ocn)
       end
       rgx=/^[1-6-]~{1,2}/ #watch
       @lnk_url=@lnk_url.gsub(rgx,'') if @lnk_url =~rgx
       rgx=/~\{\d+\s+(.+?)\}~/
       @lnk_url=@lnk_url.gsub(rgx,'\1') if @lnk_url =~rgx
-      @vz=SiSU_Env::Get_init.instance.skin
+      @vz=SiSU_Env::GetInit.instance.skin
     end
     def scr_endnote_body
       "<endnote>#{@txt}</endnote> "
     end
   end
-  class Format_scroll < Format_text_object
+  class FormatScroll < FormatTextObject
     def initialize(md,dob)
       super(md,dob)
     end
@@ -327,33 +327,26 @@ WOK
       %{<p class="paranum"><font size="1" color="#777777">&nbsp;&nbsp;#{@dob.ocn}</font></p>\n}
     end
   end
-  class Paragraph_number
+  class ParagraphNumber
     def initialize(md,ocn)
       @md,@ocn=md,ocn.to_s
       @ocn ||=''
-      vz=SiSU_Env::Get_init.instance.skin
-      @skin_no_ocn=if not ocn
-        true
-      elsif defined? vz.ocn_display_off \
-      and vz.ocn_display_off==true
-        true
-      else false
-      end
     end
     def ocn_display
-      if @md.markup.inspect =~/no_ocn/ \
-      or @md.opt.mod.inspect =~/--no-ocn/ \
-      or @skin_no_ocn
+      @make=SiSU_Env::ProcessingSettings.new(@md)
+      if @make.build.ocn?
+        ocn_class='ocn'
+        if @ocn.to_i==0
+          @ocn.gsub(/^(\d+|)$/,
+            %{<label class="#{ocn_class}"><a name="#{@ocn}">&nbsp;</a></label>})
+        else
+          @ocn.gsub(/^(\d+|)$/,
+            %{<label class="#{ocn_class}"><a name="#{@ocn}">\\1</a></label>})
+        end
+      else
         ocn_class='ocn_off'
         @ocn.gsub(/^(\d+|)$/,
-        %{<label class="#{ocn_class}">&nbsp;</label>})
-      elsif @ocn.to_i==0
-        @ocn.gsub(/^(\d+|)$/,
-        %{<label class="#{ocn_class}"><a name="#{@ocn}">&nbsp;</a></label>})
-      else
-        ocn_class='ocn'
-        @ocn.gsub(/^(\d+|)$/,
-        %{<label class="#{ocn_class}"><a name="#{@ocn}">\\1</a></label>})
+          %{<label class="#{ocn_class}">&nbsp;</label>})
       end
     end
     def name
@@ -366,15 +359,15 @@ WOK
       %{<a href="##{@ocn}">}
     end
   end
-  class Head_information
+  class HeadInformation
     include SiSU_Viz
     attr_reader :md,:sfx,:pdf,:rdf,:vz
     def initialize(md)
       @md=md
-      @rdf=SiSU_XML_tags::RDF.new(md)
+      @rdf=SiSU_XML_Tags::RDF.new(md)
       # DublinCore 1 - title
-      @vz=SiSU_Env::Get_init.instance.skin
-      @css=SiSU_Env::CSS_stylesheet.new(md)
+      @vz=SiSU_Env::GetInit.instance.skin
+      @stylesheet=SiSU_Style::CSS_HeadInfo.new(md).stylesheet
       @seg_name_html=(SiSU_HTML::Source::Seg.new.seg_name_html || [])
       @seg_name_html_tracker=(SiSU_HTML::Source::Seg.new.seg_name_html_tracker || [])
       @index='index'
@@ -406,92 +399,9 @@ WOK
 </html>}
     end
   end
-  class Widget < Head_information
-    def initialize(md)
-      super(md)
-      @md=md
-      @cf_defaults=SiSU_Env::Info_processing_flag.new
-    end
-    def home
-      %{<td align="center" bgcolor=#{@vz.color_band2}>
-  <a href="../index.html" target="_top">
-  #{@vz.png_homepage}</a>
-</td>
-}
-    end
-    def scroll(text)
-      if @md.fns =~ /\.(?:-|ssm\.)?sst$/
-        scroll=%{<td align="center" bgcolor=#{@vz.color_band2}>
-  <a href="#{@md.fn[:doc]}" target="_top" #{@vz.js_doc}>
-    #{text}
-  </a>
-</td>
-}
-      end
-    end
-    def seg(text)
-      %{<td align="center" bgcolor="#99CC66">
-  <a href="#{@md.fn[:toc]}" target="_top" #{@vz.js_doc}>
-    #{text}
-  </a>
-</td>
-}
-    end
-    def search
-      env=SiSU_Env::Info_env.new(@md.fns,@md)
-      env.widget.search_form('sisusearch',nil,nil,true)
-    end
-    def manifest
-      %{<td align="center" bgcolor=#{@vz.color_band2}>
-  <a href="#{@md.fn[:manifest]}" target="_top" #{@vz.js_manifest}>
-    #{@vz.nav_txt_manifest}
-  </a>
-</td>}
-    end
-    def pdf
-      pdf=if @md.programs[:pdf] \
-      and @cf_defaults.cf_0 =~/p/
-        %{
-<td align="center" bgcolor=#{@vz.color_band2}>
-  <a href="#{@md.fn[:pdf_p]}" target="_top" #{@vz.js_portrait}>
-    #{@vz.nav_txt_pdf_portrait}
-  </a>
-</td>
-<td align="center" bgcolor=#{@vz.color_band2}>
-  <a href="#{@md.fn[:pdf_l]}" target="_top" #{@vz.js_landscape}>
-    #{@vz.nav_txt_pdf_landscape}
-  </a>
-</td>
-}
-      else ''
-      end
-    end
-    def odf
-      odf=if @cf_defaults.cf_0 =~/o/
-        %{
-<td align="center" bgcolor=#{@vz.color_band2}>
-  <a href="#{@md.fn[:odf]}" target="_top" #{@vz.js_odf}>
-    #{@vz.nav_txt_odf}
-  </a>
-</td>}
-      else ''
-      end
-    end
-    def concordance(text)
-      if @md.concord_make \
-      and @md.wc_words < 300000 #max word count for display of concordance here as would now be a large file
-  %{<td align="center" bgcolor=#{@vz.color_band2}>
-    <a href="#{@md.fn[:concordance]}" target="_top" #{@vz.js_concordance}>
-      #{text}
-    </a>
-  </td>}
-      else ''
-      end
-    end
-  end
   class XML
   end
-  class Head_toc < Head_information
+  class HeadToc < HeadInformation
     def initialize(md)
       super(md)
       @md=md
@@ -571,21 +481,6 @@ WOK
 #{@vz.table_close}
 <p />}
     end
-    def manifest_link(text)
-  %{<font size=2>
-    <a href="#{@md.fn[:manifest]}" target="_top" #{@vz.js_manifest}>#{text}</a>
-  </font>}
-    end
-    def concordance_link(text)
-      if @md.concord_make
-  %{<font size=2>
-    <a href="#{@md.fn[:concordance]}" target="_top" #{@vz.js_concordance}>
-      #{text}
-    </a>
-  </font>}
-      else ''
-      end
-    end
     def make_seg_scroll_pdf
       wgt=Widget.new(@md)
       scroll=%{<td align="center" bgcolor=#{@vz.color_band2}>
@@ -642,67 +537,13 @@ WOK
 <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
 #{@rdf.rdftoc}
 #{@rdf.metatag_html}
-#{@css.html}
+#{@stylesheet.css_head}
 </head>
 #{@vz.color_body}
 <a name="top" id="top"></a>
 <a name="up" id="up"></a>
 <a name="start" id="start"></a>
 #{@vz.js_top}}
-    end
-    def concordance
-      if @md.concord_make
-      %{#{@vz.margin_css}
-  <h4 class="toc">
-    <a href="./#{@md.fn[:concordance]}" #{@vz.js_concordance}>
-      <i>Concordance</i>
-    </a>
-  </h4>
-#{@vz.table_close}}
-      else
-      %{#{@vz.margin_css}
-#{@vz.table_close}}
-      end
-    end
-    def links_guide_vertical_open #???
-      url=(((defined? @vz.url_hp) && @vz.url_hp =~/^https?:\/\/\S+$/) ? @vz.url_hp : @vz.url_home)
-      %{
-<div id="vertical_links">
-  <ul id="vertical">
-  <li class="refbold">
-    <a href="#{url}" #{@vz.js_home}>
-      #{@vz.txt_hp}
-    </a>
-  </li>
-  <li class="ref">
-     Quick Ref.:
-  </li>
-  <li class="ref">
-    <a href="#{@md.fn[:manifest]}" target="_top">
-      Manifest
-    </a>
-  </li>
-<!- quick ref -!>}
-    end
-    def links_guide_horizontal_open #???
-      url=(((defined? @vz.url_hp) && @vz.url_hp =~/^https?:\/\/\S+$/) ? @vz.url_hp : @vz.url_home)
-      %{
-<div id="horizontal_links">
-  <ul id="horizontal">
-  <li class="refbold">
-    <a href="#{url}" #{@vz.js_home}>
-      #{@vz.txt_hp}
-    </a>
-  </li>
-  <li class="ref">
-     Quick Ref.:
-  </li>
-  <li class="ref">
-    <a href="#{@md.fn[:manifest]}" target="_top">
-      Manifest
-    </a>
-  </li>
-<!- quick ref -!>}
     end
     def links_guide_open(type='horizontal')
       if type=='vertical'; links_guide_vertical_open
@@ -795,10 +636,6 @@ WOK
   </h4>
 #{@vz.table_close}}
     end
-    def seg_metadata
-      @metalink=%{./#{@md.fn[:metadata]}}
-      metadata
-    end
     def seg_tail
       %{
 <div class="main_column">
@@ -864,7 +701,7 @@ WOK
 }
     end
   end
-  class Head_seg < Head_information
+  class HeadSeg < HeadInformation
     def initialize(md) #(md='')
       super(md)
     end
@@ -904,24 +741,6 @@ WOK
   <a href="#{@seg_name_html[@seg_name_html_tracker+1]}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top" #{@vz.js_next}>
     #{@vz.png_nav_dot_nxt}
   </a>
-#{@vz.table_close}}
-    end
-    def dot_control_pre
-      %{<table summary="segment hidden control pre" width="100%" border="0" cellpadding="0" bgcolor=#{@vz.color_grey_pale} align="center">
-<tr><td align="left">
-  <a href="#{@seg_name_html[@seg_name_html_tracker-2]}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top" #{@vz.js_prev}>
-    #{@vz.png_nav_dot_pre}
-  </a>
-</td>
-<td align="center">
-  <a href="#{@index}#{@md.lang_code_insert}#{Sfx[:xhtml]}" target="_top" #{@vz.js_toc}>
-    #{@vz.png_nav_dot_toc}
-  </a>
-</td>
-<td align="right">
-  <a href="#{@md.fn[:toc]}" target="_top" #{@vz.js_next}>
-    #{@vz.png_nav_dot_nxt}
-  </a>
 #{@vz.table_close}}
     end
     def toc_nav(f_pre=false,f_nxt=false,use=1)
@@ -959,27 +778,10 @@ WOK
     def toc_pre2
       toc_nav(true,false,2).dup
     end
-    def manifest_link(text)
-  %{<font size=2>
-    <a href="#{@md.fn[:manifest]}" target="_top" #{@vz.js_manifest}>
-      #{text}
-    </a>
-  </font>}
-    end
-    def concordance_link(text)
-      if @md.concord_make
-  %{<font size=2>
-    <a href="#{@md.fn[:concordance]}" target="_top" #{@vz.js_concordance}>
-      #{text}
-    </a>
-  </font>}
-      else ''
-      end
-    end
     def doc_types #used in seg_nav_band ###
       scroll=seg=''
       wgt=Widget.new(@md)
-      #dir=SiSU_Env::Info_env.new(@md.fns)
+      #dir=SiSU_Env::InfoEnv.new(@md.fns)
       x=if @md.concord_make
         %{
 <table summary="segment navigation available documents types: toc,doc,pdf,concordance" border="0" cellpadding="3" cellspacing="0">
@@ -1025,7 +827,7 @@ WOK
   <font size="2">}
     end
     def header_advert_local_1
-      dir=SiSU_Env::Info_env.new(@fns)
+      dir=SiSU_Env::InfoEnv.new(@fns)
       %{  <center>
 <table summary="image" border="0" cellpadding="3" cellspacing="0" align="center">
 <tr><td align="center" bgcolor="white">
@@ -1037,7 +839,7 @@ WOK
 </center>}
     end
     def header_advert_local_2
-      dir=SiSU_Env::Info_env.new(@fns)
+      dir=SiSU_Env::InfoEnv.new(@fns)
       %{  <center>
 <table summary="image" border="0" cellpadding="3" cellspacing="0" align="center">
 <tr><td align="center" bgcolor="white">
@@ -1049,7 +851,7 @@ WOK
 </center>}
     end
     def header_advert_external
-      dir=SiSU_Env::Info_env.new(@fns)
+      dir=SiSU_Env::InfoEnv.new(@fns)
       %{  <center>
 <table summary="image" border="0" cellpadding="3" cellspacing="0" align="center">
 <tr><td align="center" bgcolor="white">
@@ -1129,7 +931,7 @@ WOK
 <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
 #{@rdf.rdfseg}
 #{@rdf.metatag_html}
-#{@css.html}
+#{@stylesheet.css_head}
 </head>
 #{@vz.color_body}
 <a name="top" id="top"></a>
@@ -1137,10 +939,6 @@ WOK
 <a name="start" id="start"></a>
 #{@vz.js_top}}
     end
-    def toc_metadata
-      @metalink=%{./#{@md.fn[:meatadata]}}
-      toc_metadata
-    end
     def title_banner(title,subtitle,creator)
       %{
 <div class="summary">
@@ -1163,7 +961,7 @@ WOK
 }
     end
   end
-  class Head_scroll < Head_toc
+  class HeadScroll < HeadToc
     def initialize(md) #(md='')
       super(md)
     end
@@ -1197,8 +995,8 @@ WOK
 #{@vz.paragraph_txt}}
     end
   end
-  class Format_text_object
-    @vz=SiSU_Env::Get_init.instance.skin
+  class FormatTextObject
+    @vz=SiSU_Env::GetInit.instance.skin
     attr_accessor :md,:dob,:txt,:ocn,:format,:table,:link,:linkname,:paranum,:p_num,:headname,:banner,:url
     def initialize(md,t_o)
       @md,@t_o=md,t_o
@@ -1221,7 +1019,7 @@ WOK
         @ocn=if defined? t_o.ocn; t_o.ocn.to_s
         else nil
         end
-        @headname=if t_o.is=='heading' and defined? t_o.name; t_o.name
+        @headname=if t_o.is==:heading and defined? t_o.name; t_o.name
         else nil
         end
       else
@@ -1233,7 +1031,7 @@ WOK
       end
       if defined? @t_o.ocn
         ocn=((@t_o.ocn.to_s =~/\d+/) ? @t_o.ocn : nil)
-        @p_num=Paragraph_number.new(@md,ocn)
+        @p_num=ParagraphNumber.new(@md,ocn)
       end
       if @format and not @format.empty?
         if @format=~/^\d:(\S+)/ #need more reliable marker #if @format =~ /#{Rx[:lv]}/
@@ -1244,7 +1042,7 @@ WOK
         end
       end
       @dob=t_o if defined? t_o.is
-      @vz=SiSU_Env::Get_init.instance.skin
+      @vz=SiSU_Env::GetInit.instance.skin
     end
     def endnote_body
       %{
@@ -1372,17 +1170,18 @@ WOK
     end
     def gsub_body
 #fix
-      case @txt
+      @txt=case @txt
       when /^\s*\((i+|iv|v|vi+|ix|x|xi+)\)/
-        @txt.gsub!(/^\((i+|iv|v|vi+|ix|x|xi+)\)/,'<b>(\1)</b>')
-        @txt.gsub!(/^(#{Mx[:pa_o]}i[1-9]#{Mx[:pa_c]})\s*\((i+|iv|v|vi+|ix|x|xi+)\)/,'\1<b>(\2)</b>')
+        @txt.gsub(/^\((i+|iv|v|vi+|ix|x|xi+)\)/,'<b>(\1)</b>').
+          gsub(/^(#{Mx[:pa_o]}i[1-9]#{Mx[:pa_c]})\s*\((i+|iv|v|vi+|ix|x|xi+)\)/,'\1<b>(\2)</b>')
       when /^\s*\(?(\d|[a-z])+\)/
-        @txt.gsub!(/^\((\d+|[a-z])+\)/,'<b>(\1)</b>')
-        @txt.gsub!(/^(#{Mx[:pa_o]}i[1-9]#{Mx[:pa_c]})\s*\((\d+|[a-z])+\)/,'\1<b>(\2)</b>')
+        @txt.gsub(/^\((\d+|[a-z])+\)/,'<b>(\1)</b>').
+          gsub(/^(#{Mx[:pa_o]}i[1-9]#{Mx[:pa_c]})\s*\((\d+|[a-z])+\)/,'\1<b>(\2)</b>')
       when /^\s*\d{1,3}\.\s/
-        @txt.gsub!(/^\s*(\d+\.)/,'<b>\1</b>')
+        @txt.gsub(/^\s*(\d+\.)/,'<b>\1</b>')
       when /^\s*[A-Z]\.\s/
-        @txt.gsub!(/^\s*([A-Z]\.)/,'<b>\1</b>')
+        @txt.gsub(/^\s*([A-Z]\.)/,'<b>\1</b>')
+      else @txt
       end
     end
     def bold_para
@@ -1395,8 +1194,8 @@ WOK
 #{@vz.table_close}}
     end
     def bold_header
-      @txt.gsub!(/[1-9]~(\S+)/,'<a name="\1"></a>')
-      @txt.gsub!(/[1-9]~/,'')
+      @txt=@txt.gsub(/[1-9]~(\S+)/,'<a name="\1"></a>').
+        gsub(/[1-9]~/,'')
       %{<p class="bold">
     #{@txt}
   </p>
@@ -1417,13 +1216,13 @@ WOK
       %{<p class="centerbold">#{@txt}</p>\n}
     end
   end
-  class Format_scroll < Format_text_object
+  class FormatScroll < FormatTextObject
     def initialize(md,txt)
       super(md,txt)
-      @vz=SiSU_Env::Get_init.instance.skin
+      @vz=SiSU_Env::GetInit.instance.skin
     end
   end
-  class Format_seg < Format_text_object
+  class FormatSeg < FormatTextObject
     def initialize(md,txt)
       super(md,txt)
     end
@@ -1492,9 +1291,9 @@ WOK
       note=''
       if txt =~/(#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]}\s*)/m
         note=$1
-        note.gsub!(/[\n\s]+/m,' ')
-        txt.gsub!(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
-        txt.gsub!(/<a[\n\s]+name="-\d+"[\n\s]+href="#_\d+">&nbsp;<sup>\d+<\/sup>&nbsp;/m,'')
+        note=note.gsub(/[\n\s]+/m,' ')
+        txt=txt.gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ').
+          gsub(/<a[\n\s]+name="-\d+"[\n\s]+href="#_\d+">&nbsp;<sup>\d+<\/sup>&nbsp;/m,'')
       end
       %{<#{tag} class="#{attrib}">
     <a href="##{@ocn}"><i>#{txt}</i></a> #{note}
@@ -1508,7 +1307,7 @@ WOK
     end
     #% para sisu
     def header_sub(tag,attrib)
-      @txt.gsub!(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
+      @txt=@txt.gsub(/(?:#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}|#{Mx[:en_b_o]}.+?#{Mx[:en_b_c]})\s*/m,' ')
       %{
 <div class="substance">
   #{@p_num.ocn_display}
@@ -1557,7 +1356,7 @@ WOK
       "<center>#{@txt}</center>"
     end
   end
-  class Format_toc < Format_text_object
+  class FormatToc < FormatTextObject
     def initialize(md,txt)
       super(md,txt)
     end
