@@ -56,7 +56,7 @@
  ** Description: SiSU information Structuring Universe, processing
 
 =end
-module SiSU_XML_scaffold
+module SiSU_XML_Scaffold
   require_relative 'particulars'                        # particulars.rb
     include SiSU_Particulars
   require_relative 'dal'                                # dal.rb
@@ -66,14 +66,14 @@ module SiSU_XML_scaffold
   class Source
     def initialize(opt)
       @opt=opt
-      @particulars=SiSU_Particulars::Combined_singleton.instance.get_all(opt)
+      @particulars=SiSU_Particulars::CombinedSingleton.instance.get_all(opt)
       @sp='  '
     end
     def read
       begin
         @md,@dal_array=@particulars.md,@particulars.dal_array
-        SiSU_XML_scaffold::Source::Scroll.new(@dal_array,@md).songsheet
-      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+        SiSU_XML_Scaffold::Source::Scroll.new(@dal_array,@md).songsheet
+      rescue; SiSU_Errors::InfoError.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
       end
     end
@@ -110,13 +110,13 @@ module SiSU_XML_scaffold
       def structure_outline(data)
         puts "\ninfo outline --->\n\n"
         data.each do |o|
-          puts "#{o.ocn} #{o.ln} #{o.obj}" if o.is =~/^heading/
+          puts "#{o.ocn} #{o.ln} #{o.obj}" if (o.is ==:heading || o.is ==:heading_insert)
         end
       end
       def structure_simple(data)
         puts "\nheading outline --->\n\n"
         data.each_with_index do |o,i|
-          if o.is =~ /^heading/; puts "<#{@s[o.ln]}>#{o.ocn} #{o.ln} #{o.obj}</#{@s[o.ln]}>"
+          if  (o.is ==:heading || o.is ==:heading_insert); puts "<#{@s[o.ln]}>#{o.ocn} #{o.ln} #{o.obj}</#{@s[o.ln]}>"
           end
         end
       end
@@ -125,7 +125,7 @@ module SiSU_XML_scaffold
         h=[0,false,false,false]
         puts "<#{@s[0]}>"
         data.each_with_index do |o,i|
-          if o.is =~/^heading/
+          if  (o.is ==:heading || o.is ==:heading_insert)
             case o.ln
             when 1
               structure_build_tag_close(o.ln,h)
